package com.contrarywind.view;

import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.Rect;
import android.graphics.Typeface;
import android.os.Handler;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import com.contrarywind.adapter.WheelAdapter;
import com.contrarywind.interfaces.IPickerViewData;
import com.contrarywind.listener.LoopViewGestureListener;
import com.contrarywind.listener.OnItemSelectedListener;
import com.contrarywind.timer.InertiaTimerTask;
import com.contrarywind.timer.MessageHandler;
import com.contrarywind.timer.SmoothScrollTimerTask;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.TimeUnit;
/* loaded from: classes.dex */
public class WheelView extends View {
    private static final float SCALE_CONTENT = 0.8f;
    private static final String[] TIME_NUM = {"00", "01", "02", "03", "04", "05", "06", "07", "08", "09"};
    private static final int VELOCITY_FLING = 5;
    private float CENTER_CONTENT_OFFSET;
    private WheelAdapter adapter;
    private float centerY;
    private Context context;
    private int dividerColor;
    private DividerType dividerType;
    private int dividerWidth;
    private int drawCenterContentStart;
    private int drawOutContentStart;
    private float firstLineY;
    private GestureDetector gestureDetector;
    private Handler handler;
    private int initPosition;
    private boolean isAlphaGradient;
    private boolean isCenterLabel;
    private boolean isLoop;
    private boolean isOptions;
    private float itemHeight;
    private int itemsVisible;
    private String label;
    private float lineSpacingMultiplier;
    private ScheduledExecutorService mExecutor;
    private ScheduledFuture<?> mFuture;
    private int mGravity;
    private int mOffset;
    private int maxTextHeight;
    private int maxTextWidth;
    private int measuredHeight;
    private int measuredWidth;
    private OnItemSelectedListener onItemSelectedListener;
    private Paint paintCenterText;
    private Paint paintIndicator;
    private Paint paintOuterText;
    private int preCurrentIndex;
    private float previousY;
    private int radius;
    private float secondLineY;
    private int selectedItem;
    private long startTime;
    private int textColorCenter;
    private int textColorOut;
    private int textSize;
    private int textXOffset;
    private float totalScrollY;
    private Typeface typeface;
    private int widthMeasureSpec;

    /* loaded from: classes.dex */
    public enum ACTION {
        CLICK,
        FLING,
        DAGGLE
    }

    /* loaded from: classes.dex */
    public enum DividerType {
        FILL,
        WRAP,
        CIRCLE
    }

    public WheelView(Context context) {
        this(context, null);
    }

    public WheelView(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.isOptions = false;
        this.isCenterLabel = true;
        this.mExecutor = Executors.newSingleThreadScheduledExecutor();
        this.typeface = Typeface.MONOSPACE;
        this.lineSpacingMultiplier = 1.6f;
        this.itemsVisible = 11;
        this.mOffset = 0;
        this.previousY = 0.0f;
        this.startTime = 0L;
        this.mGravity = 17;
        this.drawCenterContentStart = 0;
        this.drawOutContentStart = 0;
        this.isAlphaGradient = false;
        this.textSize = getResources().getDimensionPixelSize(R.dimen.pickerview_textsize);
        DisplayMetrics dm = getResources().getDisplayMetrics();
        float density = dm.density;
        if (density >= 1.0f) {
            if (1.0f > density || density >= 2.0f) {
                if (2.0f <= density && density < 3.0f) {
                    this.CENTER_CONTENT_OFFSET = 6.0f;
                } else if (density >= 3.0f) {
                    this.CENTER_CONTENT_OFFSET = 2.5f * density;
                }
            } else {
                this.CENTER_CONTENT_OFFSET = 4.0f;
            }
        } else {
            this.CENTER_CONTENT_OFFSET = 2.4f;
        }
        if (attrs != null) {
            TypedArray a2 = context.obtainStyledAttributes(attrs, R.styleable.pickerview, 0, 0);
            this.mGravity = a2.getInt(R.styleable.pickerview_wheelview_gravity, 17);
            this.textColorOut = a2.getColor(R.styleable.pickerview_wheelview_textColorOut, -5723992);
            this.textColorCenter = a2.getColor(R.styleable.pickerview_wheelview_textColorCenter, -14013910);
            this.dividerColor = a2.getColor(R.styleable.pickerview_wheelview_dividerColor, -2763307);
            this.dividerWidth = a2.getDimensionPixelSize(R.styleable.pickerview_wheelview_dividerWidth, 2);
            this.textSize = a2.getDimensionPixelOffset(R.styleable.pickerview_wheelview_textSize, this.textSize);
            this.lineSpacingMultiplier = a2.getFloat(R.styleable.pickerview_wheelview_lineSpacingMultiplier, this.lineSpacingMultiplier);
            a2.recycle();
        }
        judgeLineSpace();
        initLoopView(context);
    }

    private void judgeLineSpace() {
        float f = this.lineSpacingMultiplier;
        if (f < 1.0f) {
            this.lineSpacingMultiplier = 1.0f;
        } else if (f > 4.0f) {
            this.lineSpacingMultiplier = 4.0f;
        }
    }

    private void initLoopView(Context context) {
        this.context = context;
        this.handler = new MessageHandler(this);
        GestureDetector gestureDetector = new GestureDetector(context, new LoopViewGestureListener(this));
        this.gestureDetector = gestureDetector;
        gestureDetector.setIsLongpressEnabled(false);
        this.isLoop = true;
        this.totalScrollY = 0.0f;
        this.initPosition = -1;
        initPaints();
    }

    private void initPaints() {
        Paint paint = new Paint();
        this.paintOuterText = paint;
        paint.setColor(this.textColorOut);
        this.paintOuterText.setAntiAlias(true);
        this.paintOuterText.setTypeface(this.typeface);
        this.paintOuterText.setTextSize(this.textSize);
        Paint paint2 = new Paint();
        this.paintCenterText = paint2;
        paint2.setColor(this.textColorCenter);
        this.paintCenterText.setAntiAlias(true);
        this.paintCenterText.setTextScaleX(1.1f);
        this.paintCenterText.setTypeface(this.typeface);
        this.paintCenterText.setTextSize(this.textSize);
        Paint paint3 = new Paint();
        this.paintIndicator = paint3;
        paint3.setColor(this.dividerColor);
        this.paintIndicator.setAntiAlias(true);
        setLayerType(1, null);
    }

    private void reMeasure() {
        if (this.adapter == null) {
            return;
        }
        measureTextWidthHeight();
        int halfCircumference = (int) (this.itemHeight * (this.itemsVisible - 1));
        this.measuredHeight = (int) ((halfCircumference * 2) / 3.141592653589793d);
        this.radius = (int) (halfCircumference / 3.141592653589793d);
        this.measuredWidth = View.MeasureSpec.getSize(this.widthMeasureSpec);
        int i = this.measuredHeight;
        float f = this.itemHeight;
        this.firstLineY = (i - f) / 2.0f;
        float f2 = (i + f) / 2.0f;
        this.secondLineY = f2;
        this.centerY = (f2 - ((f - this.maxTextHeight) / 2.0f)) - this.CENTER_CONTENT_OFFSET;
        if (this.initPosition == -1) {
            if (this.isLoop) {
                this.initPosition = (this.adapter.getItemsCount() + 1) / 2;
            } else {
                this.initPosition = 0;
            }
        }
        this.preCurrentIndex = this.initPosition;
    }

    private void measureTextWidthHeight() {
        Rect rect = new Rect();
        for (int i = 0; i < this.adapter.getItemsCount(); i++) {
            String s1 = getContentText(this.adapter.getItem(i));
            this.paintCenterText.getTextBounds(s1, 0, s1.length(), rect);
            int textWidth = rect.width();
            if (textWidth > this.maxTextWidth) {
                this.maxTextWidth = textWidth;
            }
        }
        this.paintCenterText.getTextBounds("星期", 0, 2, rect);
        int height = rect.height() + 2;
        this.maxTextHeight = height;
        this.itemHeight = this.lineSpacingMultiplier * height;
    }

    public void smoothScroll(ACTION action) {
        cancelFuture();
        if (action == ACTION.FLING || action == ACTION.DAGGLE) {
            float f = this.totalScrollY;
            float f2 = this.itemHeight;
            int i = (int) (((f % f2) + f2) % f2);
            this.mOffset = i;
            if (i > f2 / 2.0f) {
                this.mOffset = (int) (f2 - i);
            } else {
                this.mOffset = -i;
            }
        }
        this.mFuture = this.mExecutor.scheduleWithFixedDelay(new SmoothScrollTimerTask(this, this.mOffset), 0L, 10L, TimeUnit.MILLISECONDS);
    }

    public final void scrollBy(float velocityY) {
        cancelFuture();
        this.mFuture = this.mExecutor.scheduleWithFixedDelay(new InertiaTimerTask(this, velocityY), 0L, 5L, TimeUnit.MILLISECONDS);
    }

    public void cancelFuture() {
        ScheduledFuture<?> scheduledFuture = this.mFuture;
        if (scheduledFuture != null && !scheduledFuture.isCancelled()) {
            this.mFuture.cancel(true);
            this.mFuture = null;
        }
    }

    public final void setCyclic(boolean cyclic) {
        this.isLoop = cyclic;
    }

    public final void setTypeface(Typeface font) {
        this.typeface = font;
        this.paintOuterText.setTypeface(font);
        this.paintCenterText.setTypeface(this.typeface);
    }

    public final void setTextSize(float size) {
        if (size > 0.0f) {
            int i = (int) (this.context.getResources().getDisplayMetrics().density * size);
            this.textSize = i;
            this.paintOuterText.setTextSize(i);
            this.paintCenterText.setTextSize(this.textSize);
        }
    }

    public final void setCurrentItem(int currentItem) {
        this.selectedItem = currentItem;
        this.initPosition = currentItem;
        this.totalScrollY = 0.0f;
        invalidate();
    }

    public final void setOnItemSelectedListener(OnItemSelectedListener OnItemSelectedListener) {
        this.onItemSelectedListener = OnItemSelectedListener;
    }

    public final void setAdapter(WheelAdapter adapter) {
        this.adapter = adapter;
        reMeasure();
        invalidate();
    }

    public void setItemsVisibleCount(int visibleCount) {
        if (visibleCount % 2 == 0) {
            visibleCount++;
        }
        this.itemsVisible = visibleCount + 2;
    }

    public void setAlphaGradient(boolean alphaGradient) {
        this.isAlphaGradient = alphaGradient;
    }

    public final WheelAdapter getAdapter() {
        return this.adapter;
    }

    public final int getCurrentItem() {
        int i;
        WheelAdapter wheelAdapter = this.adapter;
        if (wheelAdapter == null) {
            return 0;
        }
        if (this.isLoop && ((i = this.selectedItem) < 0 || i >= wheelAdapter.getItemsCount())) {
            return Math.max(0, Math.min(Math.abs(Math.abs(this.selectedItem) - this.adapter.getItemsCount()), this.adapter.getItemsCount() - 1));
        }
        return Math.max(0, Math.min(this.selectedItem, this.adapter.getItemsCount() - 1));
    }

    public final void onItemSelected() {
        if (this.onItemSelectedListener != null) {
            postDelayed(new Runnable() { // from class: com.contrarywind.view.WheelView.1
                @Override // java.lang.Runnable
                public void run() {
                    WheelView.this.onItemSelectedListener.onItemSelected(WheelView.this.getCurrentItem());
                }
            }, 200L);
        }
    }

    @Override // android.view.View
    protected void onDraw(Canvas canvas) {
        Object showText;
        int change;
        String contentText;
        float startX;
        if (this.adapter != null) {
            int min = Math.min(Math.max(0, this.initPosition), this.adapter.getItemsCount() - 1);
            this.initPosition = min;
            int change2 = (int) (this.totalScrollY / this.itemHeight);
            try {
                this.preCurrentIndex = min + (change2 % this.adapter.getItemsCount());
            } catch (ArithmeticException e) {
                Log.e("WheelView", "出错了！adapter.getItemsCount() == 0，联动数据不匹配");
            }
            if (!this.isLoop) {
                if (this.preCurrentIndex < 0) {
                    this.preCurrentIndex = 0;
                }
                if (this.preCurrentIndex > this.adapter.getItemsCount() - 1) {
                    this.preCurrentIndex = this.adapter.getItemsCount() - 1;
                }
            } else {
                if (this.preCurrentIndex < 0) {
                    this.preCurrentIndex = this.adapter.getItemsCount() + this.preCurrentIndex;
                }
                if (this.preCurrentIndex > this.adapter.getItemsCount() - 1) {
                    this.preCurrentIndex -= this.adapter.getItemsCount();
                }
            }
            float itemHeightOffset = this.totalScrollY % this.itemHeight;
            float f = 0.0f;
            if (this.dividerType != DividerType.WRAP) {
                if (this.dividerType != DividerType.CIRCLE) {
                    float f2 = this.firstLineY;
                    canvas.drawLine(0.0f, f2, this.measuredWidth, f2, this.paintIndicator);
                    float f3 = this.secondLineY;
                    canvas.drawLine(0.0f, f3, this.measuredWidth, f3, this.paintIndicator);
                } else {
                    this.paintIndicator.setStyle(Paint.Style.STROKE);
                    this.paintIndicator.setStrokeWidth(this.dividerWidth);
                    float startX2 = TextUtils.isEmpty(this.label) ? ((this.measuredWidth - this.maxTextWidth) / 2.0f) - 12.0f : ((this.measuredWidth - this.maxTextWidth) / 4.0f) - 12.0f;
                    if (startX2 <= 0.0f) {
                        startX2 = 10.0f;
                    }
                    float radius = Math.max((this.measuredWidth - startX2) - startX2, this.itemHeight) / 1.8f;
                    canvas.drawCircle(this.measuredWidth / 2.0f, this.measuredHeight / 2.0f, radius, this.paintIndicator);
                }
            } else {
                float startX3 = TextUtils.isEmpty(this.label) ? ((this.measuredWidth - this.maxTextWidth) / 2) - 12 : ((this.measuredWidth - this.maxTextWidth) / 4) - 12;
                if (startX3 > 0.0f) {
                    startX = startX3;
                } else {
                    startX = 10.0f;
                }
                float endX = this.measuredWidth - startX;
                float f4 = this.firstLineY;
                float f5 = startX;
                canvas.drawLine(f5, f4, endX, f4, this.paintIndicator);
                float f6 = this.secondLineY;
                canvas.drawLine(f5, f6, endX, f6, this.paintIndicator);
            }
            if (!TextUtils.isEmpty(this.label) && this.isCenterLabel) {
                int drawRightContentStart = this.measuredWidth - getTextWidth(this.paintCenterText, this.label);
                canvas.drawText(this.label, drawRightContentStart - this.CENTER_CONTENT_OFFSET, this.centerY, this.paintCenterText);
            }
            int counter = 0;
            while (true) {
                int i = this.itemsVisible;
                if (counter < i) {
                    int index = this.preCurrentIndex - ((i / 2) - counter);
                    if (this.isLoop) {
                        index = getLoopMappingIndex(index);
                        showText = this.adapter.getItem(index);
                    } else if (index < 0) {
                        showText = "";
                    } else if (index > this.adapter.getItemsCount() - 1) {
                        showText = "";
                    } else {
                        showText = this.adapter.getItem(index);
                    }
                    canvas.save();
                    double radian = ((this.itemHeight * counter) - itemHeightOffset) / this.radius;
                    float angle = (float) (90.0d - ((radian / 3.141592653589793d) * 180.0d));
                    if (angle > 90.0f) {
                        change = change2;
                    } else if (angle < -90.0f) {
                        change = change2;
                    } else {
                        if (!this.isCenterLabel && !TextUtils.isEmpty(this.label) && !TextUtils.isEmpty(getContentText(showText))) {
                            contentText = getContentText(showText) + this.label;
                        } else {
                            contentText = getContentText(showText);
                        }
                        change = change2;
                        float offsetCoefficient = (float) Math.pow(Math.abs(angle) / 90.0f, 2.2d);
                        reMeasureTextSize(contentText);
                        measuredCenterContentStart(contentText);
                        measuredOutContentStart(contentText);
                        String contentText2 = contentText;
                        float translateY = (float) ((this.radius - (Math.cos(radian) * this.radius)) - ((Math.sin(radian) * this.maxTextHeight) / 2.0d));
                        canvas.translate(f, translateY);
                        float f7 = this.firstLineY;
                        if (translateY <= f7 && this.maxTextHeight + translateY >= f7) {
                            canvas.save();
                            canvas.clipRect(f, f, this.measuredWidth, this.firstLineY - translateY);
                            canvas.scale(1.0f, ((float) Math.sin(radian)) * SCALE_CONTENT);
                            setOutPaintStyle(offsetCoefficient, angle);
                            canvas.drawText(contentText2, this.drawOutContentStart, this.maxTextHeight, this.paintOuterText);
                            canvas.restore();
                            canvas.save();
                            canvas.clipRect(f, this.firstLineY - translateY, this.measuredWidth, (int) this.itemHeight);
                            canvas.scale(1.0f, ((float) Math.sin(radian)) * 1.0f);
                            canvas.drawText(contentText2, this.drawCenterContentStart, this.maxTextHeight - this.CENTER_CONTENT_OFFSET, this.paintCenterText);
                            canvas.restore();
                        } else {
                            float offsetCoefficient2 = this.secondLineY;
                            if (translateY <= offsetCoefficient2 && this.maxTextHeight + translateY >= offsetCoefficient2) {
                                canvas.save();
                                canvas.clipRect(f, f, this.measuredWidth, this.secondLineY - translateY);
                                canvas.scale(1.0f, ((float) Math.sin(radian)) * 1.0f);
                                canvas.drawText(contentText2, this.drawCenterContentStart, this.maxTextHeight - this.CENTER_CONTENT_OFFSET, this.paintCenterText);
                                canvas.restore();
                                canvas.save();
                                canvas.clipRect(0.0f, this.secondLineY - translateY, this.measuredWidth, (int) this.itemHeight);
                                canvas.scale(1.0f, ((float) Math.sin(radian)) * SCALE_CONTENT);
                                setOutPaintStyle(offsetCoefficient, angle);
                                canvas.drawText(contentText2, this.drawOutContentStart, this.maxTextHeight, this.paintOuterText);
                                canvas.restore();
                            } else {
                                if (translateY >= f7) {
                                    int i2 = this.maxTextHeight;
                                    if (i2 + translateY <= offsetCoefficient2) {
                                        float Y = i2 - this.CENTER_CONTENT_OFFSET;
                                        canvas.drawText(contentText2, this.drawCenterContentStart, Y, this.paintCenterText);
                                        this.selectedItem = this.preCurrentIndex - ((this.itemsVisible / 2) - counter);
                                    }
                                }
                                canvas.save();
                                canvas.clipRect(0, 0, this.measuredWidth, (int) this.itemHeight);
                                canvas.scale(1.0f, ((float) Math.sin(radian)) * SCALE_CONTENT);
                                setOutPaintStyle(offsetCoefficient, angle);
                                canvas.drawText(contentText2, this.drawOutContentStart + (this.textXOffset * offsetCoefficient), this.maxTextHeight, this.paintOuterText);
                                canvas.restore();
                            }
                        }
                        canvas.restore();
                        this.paintCenterText.setTextSize(this.textSize);
                        counter++;
                        change2 = change;
                        f = 0.0f;
                    }
                    canvas.restore();
                    counter++;
                    change2 = change;
                    f = 0.0f;
                } else {
                    return;
                }
            }
        }
    }

    private void setOutPaintStyle(float offsetCoefficient, float angle) {
        int multiplier = 0;
        int i = this.textXOffset;
        if (i > 0) {
            multiplier = 1;
        } else if (i < 0) {
            multiplier = -1;
        }
        this.paintOuterText.setTextSkewX((angle > 0.0f ? -1 : 1) * multiplier * 0.5f * offsetCoefficient);
        int alpha = this.isAlphaGradient ? (int) (((90.0f - Math.abs(angle)) / 90.0f) * 255.0f) : 255;
        this.paintOuterText.setAlpha(alpha);
    }

    private void reMeasureTextSize(String contentText) {
        Rect rect = new Rect();
        this.paintCenterText.getTextBounds(contentText, 0, contentText.length(), rect);
        int size = this.textSize;
        for (int width = rect.width(); width > this.measuredWidth; width = rect.width()) {
            size--;
            this.paintCenterText.setTextSize(size);
            this.paintCenterText.getTextBounds(contentText, 0, contentText.length(), rect);
        }
        this.paintOuterText.setTextSize(size);
    }

    private int getLoopMappingIndex(int index) {
        if (index < 0) {
            return getLoopMappingIndex(index + this.adapter.getItemsCount());
        }
        if (index > this.adapter.getItemsCount() - 1) {
            return getLoopMappingIndex(index - this.adapter.getItemsCount());
        }
        return index;
    }

    private String getContentText(Object item) {
        if (item == null) {
            return "";
        }
        if (item instanceof IPickerViewData) {
            return ((IPickerViewData) item).getPickerViewText();
        }
        if (item instanceof Integer) {
            return getFixNum(((Integer) item).intValue());
        }
        return item.toString();
    }

    private String getFixNum(int timeNum) {
        return (timeNum < 0 || timeNum >= 10) ? String.valueOf(timeNum) : TIME_NUM[timeNum];
    }

    private void measuredCenterContentStart(String content) {
        String str;
        Rect rect = new Rect();
        this.paintCenterText.getTextBounds(content, 0, content.length(), rect);
        switch (this.mGravity) {
            case 3:
                this.drawCenterContentStart = 0;
                return;
            case 5:
                this.drawCenterContentStart = (this.measuredWidth - rect.width()) - ((int) this.CENTER_CONTENT_OFFSET);
                return;
            case 17:
                if (this.isOptions || (str = this.label) == null || str.equals("") || !this.isCenterLabel) {
                    this.drawCenterContentStart = (int) ((this.measuredWidth - rect.width()) * 0.5d);
                    return;
                } else {
                    this.drawCenterContentStart = (int) ((this.measuredWidth - rect.width()) * 0.25d);
                    return;
                }
            default:
                return;
        }
    }

    private void measuredOutContentStart(String content) {
        String str;
        Rect rect = new Rect();
        this.paintOuterText.getTextBounds(content, 0, content.length(), rect);
        switch (this.mGravity) {
            case 3:
                this.drawOutContentStart = 0;
                return;
            case 5:
                this.drawOutContentStart = (this.measuredWidth - rect.width()) - ((int) this.CENTER_CONTENT_OFFSET);
                return;
            case 17:
                if (this.isOptions || (str = this.label) == null || str.equals("") || !this.isCenterLabel) {
                    this.drawOutContentStart = (int) ((this.measuredWidth - rect.width()) * 0.5d);
                    return;
                } else {
                    this.drawOutContentStart = (int) ((this.measuredWidth - rect.width()) * 0.25d);
                    return;
                }
            default:
                return;
        }
    }

    @Override // android.view.View
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        this.widthMeasureSpec = widthMeasureSpec;
        reMeasure();
        setMeasuredDimension(this.measuredWidth, this.measuredHeight);
    }

    @Override // android.view.View
    public boolean onTouchEvent(MotionEvent event) {
        boolean eventConsumed = this.gestureDetector.onTouchEvent(event);
        boolean isIgnore = false;
        float top = (-this.initPosition) * this.itemHeight;
        float bottom = ((this.adapter.getItemsCount() - 1) - this.initPosition) * this.itemHeight;
        switch (event.getAction()) {
            case 0:
                this.startTime = System.currentTimeMillis();
                cancelFuture();
                this.previousY = event.getRawY();
                break;
            case 1:
            default:
                if (!eventConsumed) {
                    float y = event.getY();
                    int i = this.radius;
                    double L = Math.acos((i - y) / i) * this.radius;
                    float f = this.itemHeight;
                    int circlePosition = (int) (((f / 2.0f) + L) / f);
                    float extraOffset = ((this.totalScrollY % f) + f) % f;
                    this.mOffset = (int) (((circlePosition - (this.itemsVisible / 2)) * f) - extraOffset);
                    if (System.currentTimeMillis() - this.startTime > 120) {
                        smoothScroll(ACTION.DAGGLE);
                        break;
                    } else {
                        smoothScroll(ACTION.CLICK);
                        break;
                    }
                } else {
                    break;
                }
            case 2:
                float y2 = this.previousY;
                float dy = y2 - event.getRawY();
                this.previousY = event.getRawY();
                float f2 = this.totalScrollY + dy;
                this.totalScrollY = f2;
                if (!this.isLoop) {
                    float f3 = this.itemHeight;
                    if ((f2 - (f3 * 0.25f) < top && dy < 0.0f) || ((f3 * 0.25f) + f2 > bottom && dy > 0.0f)) {
                        this.totalScrollY = f2 - dy;
                        isIgnore = true;
                        break;
                    } else {
                        isIgnore = false;
                        break;
                    }
                } else {
                    break;
                }
                break;
        }
        if (!isIgnore && event.getAction() != 0) {
            invalidate();
            return true;
        }
        return true;
    }

    public int getItemsCount() {
        WheelAdapter wheelAdapter = this.adapter;
        if (wheelAdapter != null) {
            return wheelAdapter.getItemsCount();
        }
        return 0;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public void isCenterLabel(boolean isCenterLabel) {
        this.isCenterLabel = isCenterLabel;
    }

    public void setGravity(int gravity) {
        this.mGravity = gravity;
    }

    public int getTextWidth(Paint paint, String str) {
        int iRet = 0;
        if (str != null && str.length() > 0) {
            int len = str.length();
            float[] widths = new float[len];
            paint.getTextWidths(str, widths);
            for (int j = 0; j < len; j++) {
                iRet += (int) Math.ceil(widths[j]);
            }
        }
        return iRet;
    }

    public void setIsOptions(boolean options) {
        this.isOptions = options;
    }

    public void setTextColorOut(int textColorOut) {
        this.textColorOut = textColorOut;
        this.paintOuterText.setColor(textColorOut);
    }

    public void setTextColorCenter(int textColorCenter) {
        this.textColorCenter = textColorCenter;
        this.paintCenterText.setColor(textColorCenter);
    }

    public void setTextXOffset(int textXOffset) {
        this.textXOffset = textXOffset;
        if (textXOffset != 0) {
            this.paintCenterText.setTextScaleX(1.0f);
        }
    }

    public void setDividerWidth(int dividerWidth) {
        this.dividerWidth = dividerWidth;
        this.paintIndicator.setStrokeWidth(dividerWidth);
    }

    public void setDividerColor(int dividerColor) {
        this.dividerColor = dividerColor;
        this.paintIndicator.setColor(dividerColor);
    }

    public void setDividerType(DividerType dividerType) {
        this.dividerType = dividerType;
    }

    public void setLineSpacingMultiplier(float lineSpacingMultiplier) {
        if (lineSpacingMultiplier != 0.0f) {
            this.lineSpacingMultiplier = lineSpacingMultiplier;
            judgeLineSpace();
        }
    }

    public boolean isLoop() {
        return this.isLoop;
    }

    public float getTotalScrollY() {
        return this.totalScrollY;
    }

    public void setTotalScrollY(float totalScrollY) {
        this.totalScrollY = totalScrollY;
    }

    public float getItemHeight() {
        return this.itemHeight;
    }

    public int getInitPosition() {
        return this.initPosition;
    }

    @Override // android.view.View
    public Handler getHandler() {
        return this.handler;
    }
}
