package com.google.android.exoplayer2;

import android.content.Context;
import android.os.Handler;
import android.os.Looper;
import com.google.android.exoplayer2.audio.AudioCapabilities;
import com.google.android.exoplayer2.audio.AudioProcessor;
import com.google.android.exoplayer2.audio.AudioRendererEventListener;
import com.google.android.exoplayer2.audio.MediaCodecAudioRenderer;
import com.google.android.exoplayer2.drm.DrmSessionManager;
import com.google.android.exoplayer2.drm.FrameworkMediaCrypto;
import com.google.android.exoplayer2.mediacodec.MediaCodecSelector;
import com.google.android.exoplayer2.metadata.MetadataOutput;
import com.google.android.exoplayer2.metadata.MetadataRenderer;
import com.google.android.exoplayer2.text.TextOutput;
import com.google.android.exoplayer2.text.TextRenderer;
import com.google.android.exoplayer2.util.Log;
import com.google.android.exoplayer2.video.MediaCodecVideoRenderer;
import com.google.android.exoplayer2.video.VideoRendererEventListener;
import com.google.android.exoplayer2.video.spherical.CameraMotionRenderer;
import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.reflect.Constructor;
import java.util.ArrayList;
/* loaded from: classes11.dex */
public class DefaultRenderersFactory implements RenderersFactory {
    public static final long DEFAULT_ALLOWED_VIDEO_JOINING_TIME_MS = 5000;
    public static final int EXTENSION_RENDERER_MODE_OFF = 0;
    public static final int EXTENSION_RENDERER_MODE_ON = 1;
    public static final int EXTENSION_RENDERER_MODE_PREFER = 2;
    protected static final int MAX_DROPPED_VIDEO_FRAME_COUNT_TO_NOTIFY = 50;
    private static final String TAG = "DefaultRenderersFactory";
    private final long allowedVideoJoiningTimeMs;
    private final Context context;
    private final DrmSessionManager<FrameworkMediaCrypto> drmSessionManager;
    private final int extensionRendererMode;

    @Documented
    @Retention(RetentionPolicy.SOURCE)
    /* loaded from: classes11.dex */
    public @interface ExtensionRendererMode {
    }

    public DefaultRenderersFactory(Context context) {
        this(context, 0);
    }

    @Deprecated
    public DefaultRenderersFactory(Context context, DrmSessionManager<FrameworkMediaCrypto> drmSessionManager) {
        this(context, drmSessionManager, 0);
    }

    public DefaultRenderersFactory(Context context, int extensionRendererMode) {
        this(context, extensionRendererMode, (long) DEFAULT_ALLOWED_VIDEO_JOINING_TIME_MS);
    }

    @Deprecated
    public DefaultRenderersFactory(Context context, DrmSessionManager<FrameworkMediaCrypto> drmSessionManager, int extensionRendererMode) {
        this(context, drmSessionManager, extensionRendererMode, DEFAULT_ALLOWED_VIDEO_JOINING_TIME_MS);
    }

    public DefaultRenderersFactory(Context context, int extensionRendererMode, long allowedVideoJoiningTimeMs) {
        this.context = context;
        this.extensionRendererMode = extensionRendererMode;
        this.allowedVideoJoiningTimeMs = allowedVideoJoiningTimeMs;
        this.drmSessionManager = null;
    }

    @Deprecated
    public DefaultRenderersFactory(Context context, DrmSessionManager<FrameworkMediaCrypto> drmSessionManager, int extensionRendererMode, long allowedVideoJoiningTimeMs) {
        this.context = context;
        this.extensionRendererMode = extensionRendererMode;
        this.allowedVideoJoiningTimeMs = allowedVideoJoiningTimeMs;
        this.drmSessionManager = drmSessionManager;
    }

    @Override // com.google.android.exoplayer2.RenderersFactory
    public Renderer[] createRenderers(Handler eventHandler, VideoRendererEventListener videoRendererEventListener, AudioRendererEventListener audioRendererEventListener, TextOutput textRendererOutput, MetadataOutput metadataRendererOutput, DrmSessionManager<FrameworkMediaCrypto> drmSessionManager) {
        DrmSessionManager<FrameworkMediaCrypto> drmSessionManager2;
        if (drmSessionManager != null) {
            drmSessionManager2 = drmSessionManager;
        } else {
            drmSessionManager2 = this.drmSessionManager;
        }
        ArrayList<Renderer> renderersList = new ArrayList<>();
        DrmSessionManager<FrameworkMediaCrypto> drmSessionManager3 = drmSessionManager2;
        buildVideoRenderers(this.context, drmSessionManager3, this.allowedVideoJoiningTimeMs, eventHandler, videoRendererEventListener, this.extensionRendererMode, renderersList);
        buildAudioRenderers(this.context, drmSessionManager3, buildAudioProcessors(), eventHandler, audioRendererEventListener, this.extensionRendererMode, renderersList);
        buildTextRenderers(this.context, textRendererOutput, eventHandler.getLooper(), this.extensionRendererMode, renderersList);
        buildMetadataRenderers(this.context, metadataRendererOutput, eventHandler.getLooper(), this.extensionRendererMode, renderersList);
        buildCameraMotionRenderers(this.context, this.extensionRendererMode, renderersList);
        buildMiscellaneousRenderers(this.context, eventHandler, this.extensionRendererMode, renderersList);
        return (Renderer[]) renderersList.toArray(new Renderer[0]);
    }

    protected void buildVideoRenderers(Context context, DrmSessionManager<FrameworkMediaCrypto> drmSessionManager, long allowedVideoJoiningTimeMs, Handler eventHandler, VideoRendererEventListener eventListener, int extensionRendererMode, ArrayList<Renderer> out) {
        int extensionRendererIndex;
        out.add(new MediaCodecVideoRenderer(context, MediaCodecSelector.DEFAULT, allowedVideoJoiningTimeMs, drmSessionManager, false, eventHandler, eventListener, 50));
        if (extensionRendererMode == 0) {
            return;
        }
        int extensionRendererIndex2 = out.size();
        if (extensionRendererMode != 2) {
            extensionRendererIndex = extensionRendererIndex2;
        } else {
            extensionRendererIndex = extensionRendererIndex2 - 1;
        }
        try {
            Class<?> clazz = Class.forName("com.google.android.exoplayer2.ext.vp9.LibvpxVideoRenderer");
            Constructor<?> constructor = clazz.getConstructor(Boolean.TYPE, Long.TYPE, Handler.class, VideoRendererEventListener.class, Integer.TYPE);
            Renderer renderer = (Renderer) constructor.newInstance(true, Long.valueOf(allowedVideoJoiningTimeMs), eventHandler, eventListener, 50);
            int extensionRendererIndex3 = extensionRendererIndex + 1;
            try {
                out.add(extensionRendererIndex, renderer);
                Log.i(TAG, "Loaded LibvpxVideoRenderer.");
            } catch (ClassNotFoundException e) {
                extensionRendererIndex = extensionRendererIndex3;
            } catch (Exception e2) {
                e = e2;
                throw new RuntimeException("Error instantiating VP9 extension", e);
            }
        } catch (ClassNotFoundException e3) {
        } catch (Exception e4) {
            e = e4;
        }
    }

    protected void buildAudioRenderers(Context context, DrmSessionManager<FrameworkMediaCrypto> drmSessionManager, AudioProcessor[] audioProcessors, Handler eventHandler, AudioRendererEventListener eventListener, int extensionRendererMode, ArrayList<Renderer> out) {
        int extensionRendererIndex;
        int extensionRendererIndex2;
        int extensionRendererIndex3;
        out.add(new MediaCodecAudioRenderer(context, MediaCodecSelector.DEFAULT, drmSessionManager, false, eventHandler, eventListener, AudioCapabilities.getCapabilities(context), audioProcessors));
        if (extensionRendererMode == 0) {
            return;
        }
        int extensionRendererIndex4 = out.size();
        if (extensionRendererMode != 2) {
            extensionRendererIndex = extensionRendererIndex4;
        } else {
            extensionRendererIndex = extensionRendererIndex4 - 1;
        }
        try {
            Class<?> clazz = Class.forName("com.google.android.exoplayer2.ext.opus.LibopusAudioRenderer");
            Constructor<?> constructor = clazz.getConstructor(Handler.class, AudioRendererEventListener.class, AudioProcessor[].class);
            Renderer renderer = (Renderer) constructor.newInstance(eventHandler, eventListener, audioProcessors);
            extensionRendererIndex2 = extensionRendererIndex + 1;
            try {
                out.add(extensionRendererIndex, renderer);
                Log.i(TAG, "Loaded LibopusAudioRenderer.");
            } catch (ClassNotFoundException e) {
                extensionRendererIndex = extensionRendererIndex2;
                extensionRendererIndex2 = extensionRendererIndex;
                Class<?> clazz2 = Class.forName("com.google.android.exoplayer2.ext.flac.LibflacAudioRenderer");
                Constructor<?> constructor2 = clazz2.getConstructor(Handler.class, AudioRendererEventListener.class, AudioProcessor[].class);
                Renderer renderer2 = (Renderer) constructor2.newInstance(eventHandler, eventListener, audioProcessors);
                extensionRendererIndex3 = extensionRendererIndex2 + 1;
                try {
                    out.add(extensionRendererIndex2, renderer2);
                    Log.i(TAG, "Loaded LibflacAudioRenderer.");
                } catch (ClassNotFoundException e2) {
                    extensionRendererIndex2 = extensionRendererIndex3;
                    extensionRendererIndex3 = extensionRendererIndex2;
                    Class<?> clazz3 = Class.forName("com.google.android.exoplayer2.ext.ffmpeg.FfmpegAudioRenderer");
                    Constructor<?> constructor3 = clazz3.getConstructor(Handler.class, AudioRendererEventListener.class, AudioProcessor[].class);
                    Renderer renderer3 = (Renderer) constructor3.newInstance(eventHandler, eventListener, audioProcessors);
                    int extensionRendererIndex5 = extensionRendererIndex3 + 1;
                    out.add(extensionRendererIndex3, renderer3);
                    Log.i(TAG, "Loaded FfmpegAudioRenderer.");
                } catch (Exception e3) {
                    e = e3;
                    throw new RuntimeException("Error instantiating FLAC extension", e);
                }
                Class<?> clazz32 = Class.forName("com.google.android.exoplayer2.ext.ffmpeg.FfmpegAudioRenderer");
                Constructor<?> constructor32 = clazz32.getConstructor(Handler.class, AudioRendererEventListener.class, AudioProcessor[].class);
                Renderer renderer32 = (Renderer) constructor32.newInstance(eventHandler, eventListener, audioProcessors);
                int extensionRendererIndex52 = extensionRendererIndex3 + 1;
                try {
                    out.add(extensionRendererIndex3, renderer32);
                    Log.i(TAG, "Loaded FfmpegAudioRenderer.");
                } catch (ClassNotFoundException e4) {
                    extensionRendererIndex3 = extensionRendererIndex52;
                    return;
                } catch (Exception e5) {
                    e = e5;
                    throw new RuntimeException("Error instantiating FFmpeg extension", e);
                }
            } catch (Exception e6) {
                e = e6;
                throw new RuntimeException("Error instantiating Opus extension", e);
            }
        } catch (ClassNotFoundException e7) {
        } catch (Exception e8) {
            e = e8;
        }
        try {
            Class<?> clazz22 = Class.forName("com.google.android.exoplayer2.ext.flac.LibflacAudioRenderer");
            Constructor<?> constructor22 = clazz22.getConstructor(Handler.class, AudioRendererEventListener.class, AudioProcessor[].class);
            Renderer renderer22 = (Renderer) constructor22.newInstance(eventHandler, eventListener, audioProcessors);
            extensionRendererIndex3 = extensionRendererIndex2 + 1;
            out.add(extensionRendererIndex2, renderer22);
            Log.i(TAG, "Loaded LibflacAudioRenderer.");
        } catch (ClassNotFoundException e9) {
        } catch (Exception e10) {
            e = e10;
        }
        try {
            Class<?> clazz322 = Class.forName("com.google.android.exoplayer2.ext.ffmpeg.FfmpegAudioRenderer");
            Constructor<?> constructor322 = clazz322.getConstructor(Handler.class, AudioRendererEventListener.class, AudioProcessor[].class);
            Renderer renderer322 = (Renderer) constructor322.newInstance(eventHandler, eventListener, audioProcessors);
            int extensionRendererIndex522 = extensionRendererIndex3 + 1;
            out.add(extensionRendererIndex3, renderer322);
            Log.i(TAG, "Loaded FfmpegAudioRenderer.");
        } catch (ClassNotFoundException e11) {
        } catch (Exception e12) {
            e = e12;
        }
    }

    protected void buildTextRenderers(Context context, TextOutput output, Looper outputLooper, int extensionRendererMode, ArrayList<Renderer> out) {
        out.add(new TextRenderer(output, outputLooper));
    }

    protected void buildMetadataRenderers(Context context, MetadataOutput output, Looper outputLooper, int extensionRendererMode, ArrayList<Renderer> out) {
        out.add(new MetadataRenderer(output, outputLooper));
    }

    protected void buildCameraMotionRenderers(Context context, int extensionRendererMode, ArrayList<Renderer> out) {
        out.add(new CameraMotionRenderer());
    }

    protected void buildMiscellaneousRenderers(Context context, Handler eventHandler, int extensionRendererMode, ArrayList<Renderer> out) {
    }

    protected AudioProcessor[] buildAudioProcessors() {
        return new AudioProcessor[0];
    }
}
