package com.google.android.exoplayer2.metadata.id3;

import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.metadata.Metadata;
import com.google.android.exoplayer2.metadata.MetadataDecoder;
import com.google.android.exoplayer2.metadata.MetadataInputBuffer;
import com.google.android.exoplayer2.util.Log;
import com.google.android.exoplayer2.util.ParsableBitArray;
import com.google.android.exoplayer2.util.ParsableByteArray;
import com.google.android.exoplayer2.util.Util;
import java.io.UnsupportedEncodingException;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Locale;
import java9.util.concurrent.ForkJoinPool;
import kotlin.UByte;
/* loaded from: classes14.dex */
public final class Id3Decoder implements MetadataDecoder {
    private static final int FRAME_FLAG_V3_HAS_GROUP_IDENTIFIER = 32;
    private static final int FRAME_FLAG_V3_IS_COMPRESSED = 128;
    private static final int FRAME_FLAG_V3_IS_ENCRYPTED = 64;
    private static final int FRAME_FLAG_V4_HAS_DATA_LENGTH = 1;
    private static final int FRAME_FLAG_V4_HAS_GROUP_IDENTIFIER = 64;
    private static final int FRAME_FLAG_V4_IS_COMPRESSED = 8;
    private static final int FRAME_FLAG_V4_IS_ENCRYPTED = 4;
    private static final int FRAME_FLAG_V4_IS_UNSYNCHRONIZED = 2;
    public static final int ID3_HEADER_LENGTH = 10;
    private static final int ID3_TEXT_ENCODING_ISO_8859_1 = 0;
    private static final int ID3_TEXT_ENCODING_UTF_16 = 1;
    private static final int ID3_TEXT_ENCODING_UTF_16BE = 2;
    private static final int ID3_TEXT_ENCODING_UTF_8 = 3;
    private static final String TAG = "Id3Decoder";
    private final FramePredicate framePredicate;
    public static final FramePredicate NO_FRAMES_PREDICATE = new FramePredicate() { // from class: com.google.android.exoplayer2.metadata.id3.Id3Decoder$$ExternalSyntheticLambda0
        @Override // com.google.android.exoplayer2.metadata.id3.Id3Decoder.FramePredicate
        public final boolean evaluate(int i, int i2, int i3, int i4, int i5) {
            return Id3Decoder.lambda$static$0(i, i2, i3, i4, i5);
        }
    };
    public static final int ID3_TAG = Util.getIntegerCodeForString("ID3");

    /* loaded from: classes14.dex */
    public interface FramePredicate {
        boolean evaluate(int i, int i2, int i3, int i4, int i5);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ boolean lambda$static$0(int majorVersion, int id0, int id1, int id2, int id3) {
        return false;
    }

    public Id3Decoder() {
        this(null);
    }

    public Id3Decoder(FramePredicate framePredicate) {
        this.framePredicate = framePredicate;
    }

    @Override // com.google.android.exoplayer2.metadata.MetadataDecoder
    public Metadata decode(MetadataInputBuffer inputBuffer) {
        ByteBuffer buffer = inputBuffer.data;
        return decode(buffer.array(), buffer.limit());
    }

    public Metadata decode(byte[] data, int size) {
        List<Id3Frame> id3Frames = new ArrayList<>();
        ParsableByteArray id3Data = new ParsableByteArray(data, size);
        Id3Header id3Header = decodeHeader(id3Data);
        if (id3Header == null) {
            return null;
        }
        int startPosition = id3Data.getPosition();
        int frameHeaderSize = id3Header.majorVersion == 2 ? 6 : 10;
        int framesSize = id3Header.framesSize;
        if (id3Header.isUnsynchronized) {
            framesSize = removeUnsynchronization(id3Data, id3Header.framesSize);
        }
        id3Data.setLimit(startPosition + framesSize);
        boolean unsignedIntFrameSizeHack = false;
        if (!validateFrames(id3Data, id3Header.majorVersion, frameHeaderSize, false)) {
            if (id3Header.majorVersion == 4 && validateFrames(id3Data, 4, frameHeaderSize, true)) {
                unsignedIntFrameSizeHack = true;
            } else {
                Log.w(TAG, "Failed to validate ID3 tag with majorVersion=" + id3Header.majorVersion);
                return null;
            }
        }
        while (id3Data.bytesLeft() >= frameHeaderSize) {
            Id3Frame frame = decodeFrame(id3Header.majorVersion, id3Data, unsignedIntFrameSizeHack, frameHeaderSize, this.framePredicate);
            if (frame != null) {
                id3Frames.add(frame);
            }
        }
        return new Metadata(id3Frames);
    }

    private static Id3Header decodeHeader(ParsableByteArray data) {
        if (data.bytesLeft() < 10) {
            Log.w(TAG, "Data too short to be an ID3 tag");
            return null;
        }
        int id = data.readUnsignedInt24();
        if (id != ID3_TAG) {
            Log.w(TAG, "Unexpected first three bytes of ID3 tag header: " + id);
            return null;
        }
        int majorVersion = data.readUnsignedByte();
        boolean z = true;
        data.skipBytes(1);
        int flags = data.readUnsignedByte();
        int framesSize = data.readSynchSafeInt();
        if (majorVersion == 2) {
            boolean isCompressed = (flags & 64) != 0;
            if (isCompressed) {
                Log.w(TAG, "Skipped ID3 tag with majorVersion=2 and undefined compression scheme");
                return null;
            }
        } else if (majorVersion == 3) {
            boolean hasExtendedHeader = (flags & 64) != 0;
            if (hasExtendedHeader) {
                int extendedHeaderSize = data.readInt();
                data.skipBytes(extendedHeaderSize);
                framesSize -= extendedHeaderSize + 4;
            }
        } else if (majorVersion == 4) {
            boolean hasExtendedHeader2 = (flags & 64) != 0;
            if (hasExtendedHeader2) {
                int extendedHeaderSize2 = data.readSynchSafeInt();
                data.skipBytes(extendedHeaderSize2 - 4);
                framesSize -= extendedHeaderSize2;
            }
            boolean hasFooter = (flags & 16) != 0;
            if (hasFooter) {
                framesSize -= 10;
            }
        } else {
            Log.w(TAG, "Skipped ID3 tag with unsupported majorVersion=" + majorVersion);
            return null;
        }
        boolean isUnsynchronized = (majorVersion >= 4 || (flags & 128) == 0) ? false : false;
        return new Id3Header(majorVersion, isUnsynchronized, framesSize);
    }

    private static boolean validateFrames(ParsableByteArray id3Data, int majorVersion, int frameHeaderSize, boolean unsignedIntFrameSizeHack) {
        int id;
        long frameSize;
        int flags;
        int startPosition = id3Data.getPosition();
        while (true) {
            try {
                if (id3Data.bytesLeft() < frameHeaderSize) {
                    id3Data.setPosition(startPosition);
                    return true;
                }
                if (majorVersion >= 3) {
                    try {
                        id = id3Data.readInt();
                        frameSize = id3Data.readUnsignedInt();
                        flags = id3Data.readUnsignedShort();
                    } catch (Throwable th) {
                        th = th;
                        id3Data.setPosition(startPosition);
                        throw th;
                    }
                } else {
                    id = id3Data.readUnsignedInt24();
                    frameSize = id3Data.readUnsignedInt24();
                    flags = 0;
                }
                if (id == 0 && frameSize == 0 && flags == 0) {
                    id3Data.setPosition(startPosition);
                    return true;
                }
                if (majorVersion == 4 && !unsignedIntFrameSizeHack) {
                    if ((8421504 & frameSize) != 0) {
                        id3Data.setPosition(startPosition);
                        return false;
                    }
                    frameSize = (frameSize & 255) | (((frameSize >> 8) & 255) << 7) | (((frameSize >> 16) & 255) << 14) | (((frameSize >> 24) & 255) << 21);
                }
                boolean hasGroupIdentifier = false;
                boolean hasDataLength = false;
                if (majorVersion == 4) {
                    hasGroupIdentifier = (flags & 64) != 0;
                    hasDataLength = (flags & 1) != 0;
                } else if (majorVersion == 3) {
                    hasGroupIdentifier = (flags & 32) != 0;
                    hasDataLength = (flags & 128) != 0;
                }
                int minimumFrameSize = hasGroupIdentifier ? 0 + 1 : 0;
                if (hasDataLength) {
                    minimumFrameSize += 4;
                }
                if (frameSize < minimumFrameSize) {
                    id3Data.setPosition(startPosition);
                    return false;
                } else if (id3Data.bytesLeft() < frameSize) {
                    id3Data.setPosition(startPosition);
                    return false;
                } else {
                    id3Data.skipBytes((int) frameSize);
                }
            } catch (Throwable th2) {
                th = th2;
            }
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:133:0x01bb, code lost:
        if (r13 == 67) goto L108;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static Id3Frame decodeFrame(int majorVersion, ParsableByteArray id3Data, boolean unsignedIntFrameSizeHack, int frameHeaderSize, FramePredicate framePredicate) {
        int frameSize;
        String str;
        int nextFramePosition;
        int flags;
        boolean isCompressed;
        boolean isEncrypted;
        boolean isUnsynchronized;
        boolean hasDataLength;
        boolean hasGroupIdentifier;
        String str2;
        String str3;
        Id3Frame frame;
        int frameId0 = id3Data.readUnsignedByte();
        int frameId1 = id3Data.readUnsignedByte();
        int frameId2 = id3Data.readUnsignedByte();
        int frameId3 = majorVersion >= 3 ? id3Data.readUnsignedByte() : 0;
        if (majorVersion == 4) {
            int frameSize2 = id3Data.readUnsignedIntToInt();
            frameSize = !unsignedIntFrameSizeHack ? (frameSize2 & 255) | (((frameSize2 >> 8) & 255) << 7) | (((frameSize2 >> 16) & 255) << 14) | (((frameSize2 >> 24) & 255) << 21) : frameSize2;
        } else if (majorVersion == 3) {
            frameSize = id3Data.readUnsignedIntToInt();
        } else {
            int frameSize3 = id3Data.readUnsignedInt24();
            frameSize = frameSize3;
        }
        int flags2 = majorVersion >= 3 ? id3Data.readUnsignedShort() : 0;
        if (frameId0 == 0 && frameId1 == 0 && frameId2 == 0 && frameId3 == 0 && frameSize == 0 && flags2 == 0) {
            id3Data.setPosition(id3Data.limit());
            return null;
        }
        int nextFramePosition2 = id3Data.getPosition() + frameSize;
        if (nextFramePosition2 > id3Data.limit()) {
            Log.w(TAG, "Frame size exceeds remaining tag data");
            id3Data.setPosition(id3Data.limit());
            return null;
        }
        if (framePredicate != null) {
            str = TAG;
            nextFramePosition = nextFramePosition2;
            flags = flags2;
            if (!framePredicate.evaluate(majorVersion, frameId0, frameId1, frameId2, frameId3)) {
                id3Data.setPosition(nextFramePosition);
                return null;
            }
        } else {
            str = TAG;
            nextFramePosition = nextFramePosition2;
            flags = flags2;
        }
        if (majorVersion == 3) {
            int flags3 = flags;
            boolean isCompressed2 = (flags3 & 128) != 0;
            boolean isEncrypted2 = (flags3 & 64) != 0;
            boolean hasGroupIdentifier2 = (flags3 & 32) != 0;
            isCompressed = isCompressed2;
            isEncrypted = isEncrypted2;
            isUnsynchronized = false;
            hasDataLength = isCompressed2;
            hasGroupIdentifier = hasGroupIdentifier2;
        } else {
            int flags4 = flags;
            if (majorVersion == 4) {
                boolean hasGroupIdentifier3 = (flags4 & 64) != 0;
                boolean isCompressed3 = (flags4 & 8) != 0;
                boolean isEncrypted3 = (flags4 & 4) != 0;
                boolean isUnsynchronized2 = (flags4 & 2) != 0;
                boolean hasDataLength2 = (flags4 & 1) != 0;
                isCompressed = isCompressed3;
                isEncrypted = isEncrypted3;
                isUnsynchronized = isUnsynchronized2;
                hasDataLength = hasDataLength2;
                hasGroupIdentifier = hasGroupIdentifier3;
            } else {
                isCompressed = false;
                isEncrypted = false;
                isUnsynchronized = false;
                hasDataLength = false;
                hasGroupIdentifier = false;
            }
        }
        if (isCompressed) {
            str2 = str;
        } else if (isEncrypted) {
            str2 = str;
        } else {
            if (hasGroupIdentifier) {
                frameSize--;
                id3Data.skipBytes(1);
            }
            if (hasDataLength) {
                frameSize -= 4;
                id3Data.skipBytes(4);
            }
            if (isUnsynchronized) {
                frameSize = removeUnsynchronization(id3Data, frameSize);
            }
            try {
                try {
                    if (frameId0 == 84 && frameId1 == 88 && frameId2 == 88 && (majorVersion == 2 || frameId3 == 88)) {
                        frame = decodeTxxxFrame(id3Data, frameSize);
                    } else if (frameId0 == 84) {
                        String id = getFrameId(majorVersion, frameId0, frameId1, frameId2, frameId3);
                        frame = decodeTextInformationFrame(id3Data, frameSize, id);
                    } else if (frameId0 == 87 && frameId1 == 88 && frameId2 == 88 && (majorVersion == 2 || frameId3 == 88)) {
                        frame = decodeWxxxFrame(id3Data, frameSize);
                    } else if (frameId0 == 87) {
                        String id2 = getFrameId(majorVersion, frameId0, frameId1, frameId2, frameId3);
                        frame = decodeUrlLinkFrame(id3Data, frameSize, id2);
                    } else if (frameId0 == 80 && frameId1 == 82 && frameId2 == 73 && frameId3 == 86) {
                        frame = decodePrivFrame(id3Data, frameSize);
                    } else if (frameId0 == 71 && frameId1 == 69 && frameId2 == 79 && (frameId3 == 66 || majorVersion == 2)) {
                        frame = decodeGeobFrame(id3Data, frameSize);
                    } else if (majorVersion == 2) {
                        if (frameId0 == 80 && frameId1 == 73 && frameId2 == 67) {
                            frame = decodeApicFrame(id3Data, frameSize, majorVersion);
                        }
                        if (frameId0 != 67 && frameId1 == 79 && frameId2 == 77 && (frameId3 == 77 || majorVersion == 2)) {
                            frame = decodeCommentFrame(id3Data, frameSize);
                        } else if (frameId0 != 67 && frameId1 == 72 && frameId2 == 65 && frameId3 == 80) {
                            frame = decodeChapterFrame(id3Data, frameSize, majorVersion, unsignedIntFrameSizeHack, frameHeaderSize, framePredicate);
                        } else if (frameId0 != 67 && frameId1 == 84 && frameId2 == 79 && frameId3 == 67) {
                            frame = decodeChapterTOCFrame(id3Data, frameSize, majorVersion, unsignedIntFrameSizeHack, frameHeaderSize, framePredicate);
                        } else if (frameId0 != 77 && frameId1 == 76 && frameId2 == 76 && frameId3 == 84) {
                            frame = decodeMlltFrame(id3Data, frameSize);
                        } else {
                            String id3 = getFrameId(majorVersion, frameId0, frameId1, frameId2, frameId3);
                            frame = decodeBinaryFrame(id3Data, frameSize, id3);
                        }
                    } else {
                        if (frameId0 == 65) {
                            if (frameId1 == 80) {
                                if (frameId2 == 73) {
                                }
                            }
                        }
                        if (frameId0 != 67) {
                        }
                        if (frameId0 != 67) {
                        }
                        if (frameId0 != 67) {
                        }
                        if (frameId0 != 77) {
                        }
                        String id32 = getFrameId(majorVersion, frameId0, frameId1, frameId2, frameId3);
                        frame = decodeBinaryFrame(id3Data, frameSize, id32);
                    }
                    if (frame == null) {
                        str3 = str;
                        try {
                            Log.w(str3, "Failed to decode frame: id=" + getFrameId(majorVersion, frameId0, frameId1, frameId2, frameId3) + ", frameSize=" + frameSize);
                        } catch (UnsupportedEncodingException e) {
                            Log.w(str3, "Unsupported character encoding");
                            id3Data.setPosition(nextFramePosition);
                            return null;
                        }
                    }
                    id3Data.setPosition(nextFramePosition);
                    return frame;
                } catch (Throwable th) {
                    id3Data.setPosition(nextFramePosition);
                    throw th;
                }
            } catch (UnsupportedEncodingException e2) {
                str3 = str;
            }
        }
        Log.w(str2, "Skipping unsupported compressed or encrypted frame");
        id3Data.setPosition(nextFramePosition);
        return null;
    }

    private static TextInformationFrame decodeTxxxFrame(ParsableByteArray id3Data, int frameSize) throws UnsupportedEncodingException {
        if (frameSize < 1) {
            return null;
        }
        int encoding = id3Data.readUnsignedByte();
        String charset = getCharsetName(encoding);
        byte[] data = new byte[frameSize - 1];
        id3Data.readBytes(data, 0, frameSize - 1);
        int descriptionEndIndex = indexOfEos(data, 0, encoding);
        String description = new String(data, 0, descriptionEndIndex, charset);
        int valueStartIndex = delimiterLength(encoding) + descriptionEndIndex;
        int valueEndIndex = indexOfEos(data, valueStartIndex, encoding);
        String value = decodeStringIfValid(data, valueStartIndex, valueEndIndex, charset);
        return new TextInformationFrame("TXXX", description, value);
    }

    private static TextInformationFrame decodeTextInformationFrame(ParsableByteArray id3Data, int frameSize, String id) throws UnsupportedEncodingException {
        if (frameSize < 1) {
            return null;
        }
        int encoding = id3Data.readUnsignedByte();
        String charset = getCharsetName(encoding);
        byte[] data = new byte[frameSize - 1];
        id3Data.readBytes(data, 0, frameSize - 1);
        int valueEndIndex = indexOfEos(data, 0, encoding);
        String value = new String(data, 0, valueEndIndex, charset);
        return new TextInformationFrame(id, null, value);
    }

    private static UrlLinkFrame decodeWxxxFrame(ParsableByteArray id3Data, int frameSize) throws UnsupportedEncodingException {
        if (frameSize < 1) {
            return null;
        }
        int encoding = id3Data.readUnsignedByte();
        String charset = getCharsetName(encoding);
        byte[] data = new byte[frameSize - 1];
        id3Data.readBytes(data, 0, frameSize - 1);
        int descriptionEndIndex = indexOfEos(data, 0, encoding);
        String description = new String(data, 0, descriptionEndIndex, charset);
        int urlStartIndex = delimiterLength(encoding) + descriptionEndIndex;
        int urlEndIndex = indexOfZeroByte(data, urlStartIndex);
        String url = decodeStringIfValid(data, urlStartIndex, urlEndIndex, "ISO-8859-1");
        return new UrlLinkFrame("WXXX", description, url);
    }

    private static UrlLinkFrame decodeUrlLinkFrame(ParsableByteArray id3Data, int frameSize, String id) throws UnsupportedEncodingException {
        byte[] data = new byte[frameSize];
        id3Data.readBytes(data, 0, frameSize);
        int urlEndIndex = indexOfZeroByte(data, 0);
        String url = new String(data, 0, urlEndIndex, "ISO-8859-1");
        return new UrlLinkFrame(id, null, url);
    }

    private static PrivFrame decodePrivFrame(ParsableByteArray id3Data, int frameSize) throws UnsupportedEncodingException {
        byte[] data = new byte[frameSize];
        id3Data.readBytes(data, 0, frameSize);
        int ownerEndIndex = indexOfZeroByte(data, 0);
        String owner = new String(data, 0, ownerEndIndex, "ISO-8859-1");
        int privateDataStartIndex = ownerEndIndex + 1;
        byte[] privateData = copyOfRangeIfValid(data, privateDataStartIndex, data.length);
        return new PrivFrame(owner, privateData);
    }

    private static GeobFrame decodeGeobFrame(ParsableByteArray id3Data, int frameSize) throws UnsupportedEncodingException {
        int encoding = id3Data.readUnsignedByte();
        String charset = getCharsetName(encoding);
        byte[] data = new byte[frameSize - 1];
        id3Data.readBytes(data, 0, frameSize - 1);
        int mimeTypeEndIndex = indexOfZeroByte(data, 0);
        String mimeType = new String(data, 0, mimeTypeEndIndex, "ISO-8859-1");
        int filenameStartIndex = mimeTypeEndIndex + 1;
        int filenameEndIndex = indexOfEos(data, filenameStartIndex, encoding);
        String filename = decodeStringIfValid(data, filenameStartIndex, filenameEndIndex, charset);
        int descriptionStartIndex = delimiterLength(encoding) + filenameEndIndex;
        int descriptionEndIndex = indexOfEos(data, descriptionStartIndex, encoding);
        String description = decodeStringIfValid(data, descriptionStartIndex, descriptionEndIndex, charset);
        int objectDataStartIndex = delimiterLength(encoding) + descriptionEndIndex;
        byte[] objectData = copyOfRangeIfValid(data, objectDataStartIndex, data.length);
        return new GeobFrame(mimeType, filename, description, objectData);
    }

    private static ApicFrame decodeApicFrame(ParsableByteArray id3Data, int frameSize, int majorVersion) throws UnsupportedEncodingException {
        int mimeTypeEndIndex;
        String mimeType;
        int encoding = id3Data.readUnsignedByte();
        String charset = getCharsetName(encoding);
        byte[] data = new byte[frameSize - 1];
        id3Data.readBytes(data, 0, frameSize - 1);
        if (majorVersion == 2) {
            mimeTypeEndIndex = 2;
            mimeType = "image/" + Util.toLowerInvariant(new String(data, 0, 3, "ISO-8859-1"));
            if ("image/jpg".equals(mimeType)) {
                mimeType = "image/jpeg";
            }
        } else {
            mimeTypeEndIndex = indexOfZeroByte(data, 0);
            mimeType = Util.toLowerInvariant(new String(data, 0, mimeTypeEndIndex, "ISO-8859-1"));
            if (mimeType.indexOf(47) == -1) {
                mimeType = "image/" + mimeType;
            }
        }
        int pictureType = data[mimeTypeEndIndex + 1] & UByte.MAX_VALUE;
        int descriptionStartIndex = mimeTypeEndIndex + 2;
        int descriptionEndIndex = indexOfEos(data, descriptionStartIndex, encoding);
        String description = new String(data, descriptionStartIndex, descriptionEndIndex - descriptionStartIndex, charset);
        int pictureDataStartIndex = delimiterLength(encoding) + descriptionEndIndex;
        byte[] pictureData = copyOfRangeIfValid(data, pictureDataStartIndex, data.length);
        return new ApicFrame(mimeType, description, pictureType, pictureData);
    }

    private static CommentFrame decodeCommentFrame(ParsableByteArray id3Data, int frameSize) throws UnsupportedEncodingException {
        if (frameSize < 4) {
            return null;
        }
        int encoding = id3Data.readUnsignedByte();
        String charset = getCharsetName(encoding);
        byte[] data = new byte[3];
        id3Data.readBytes(data, 0, 3);
        String language = new String(data, 0, 3);
        byte[] data2 = new byte[frameSize - 4];
        id3Data.readBytes(data2, 0, frameSize - 4);
        int descriptionEndIndex = indexOfEos(data2, 0, encoding);
        String description = new String(data2, 0, descriptionEndIndex, charset);
        int textStartIndex = delimiterLength(encoding) + descriptionEndIndex;
        int textEndIndex = indexOfEos(data2, textStartIndex, encoding);
        String text = decodeStringIfValid(data2, textStartIndex, textEndIndex, charset);
        return new CommentFrame(language, description, text);
    }

    private static ChapterFrame decodeChapterFrame(ParsableByteArray id3Data, int frameSize, int majorVersion, boolean unsignedIntFrameSizeHack, int frameHeaderSize, FramePredicate framePredicate) throws UnsupportedEncodingException {
        long startOffset;
        long endOffset;
        int framePosition = id3Data.getPosition();
        int chapterIdEndIndex = indexOfZeroByte(id3Data.data, framePosition);
        String chapterId = new String(id3Data.data, framePosition, chapterIdEndIndex - framePosition, "ISO-8859-1");
        id3Data.setPosition(chapterIdEndIndex + 1);
        int startTime = id3Data.readInt();
        int endTime = id3Data.readInt();
        long startOffset2 = id3Data.readUnsignedInt();
        if (startOffset2 != ForkJoinPool.SP_MASK) {
            startOffset = startOffset2;
        } else {
            startOffset = -1;
        }
        long endOffset2 = id3Data.readUnsignedInt();
        if (endOffset2 != ForkJoinPool.SP_MASK) {
            endOffset = endOffset2;
        } else {
            endOffset = -1;
        }
        ArrayList<Id3Frame> subFrames = new ArrayList<>();
        int limit = framePosition + frameSize;
        while (id3Data.getPosition() < limit) {
            Id3Frame frame = decodeFrame(majorVersion, id3Data, unsignedIntFrameSizeHack, frameHeaderSize, framePredicate);
            if (frame != null) {
                subFrames.add(frame);
            }
        }
        Id3Frame[] subFrameArray = new Id3Frame[subFrames.size()];
        subFrames.toArray(subFrameArray);
        return new ChapterFrame(chapterId, startTime, endTime, startOffset, endOffset, subFrameArray);
    }

    private static ChapterTocFrame decodeChapterTOCFrame(ParsableByteArray id3Data, int frameSize, int majorVersion, boolean unsignedIntFrameSizeHack, int frameHeaderSize, FramePredicate framePredicate) throws UnsupportedEncodingException {
        int framePosition = id3Data.getPosition();
        int elementIdEndIndex = indexOfZeroByte(id3Data.data, framePosition);
        String elementId = new String(id3Data.data, framePosition, elementIdEndIndex - framePosition, "ISO-8859-1");
        id3Data.setPosition(elementIdEndIndex + 1);
        int ctocFlags = id3Data.readUnsignedByte();
        boolean isRoot = (ctocFlags & 2) != 0;
        boolean isOrdered = (ctocFlags & 1) != 0;
        int childCount = id3Data.readUnsignedByte();
        String[] children = new String[childCount];
        for (int i = 0; i < childCount; i++) {
            int startIndex = id3Data.getPosition();
            int endIndex = indexOfZeroByte(id3Data.data, startIndex);
            children[i] = new String(id3Data.data, startIndex, endIndex - startIndex, "ISO-8859-1");
            id3Data.setPosition(endIndex + 1);
        }
        ArrayList<Id3Frame> subFrames = new ArrayList<>();
        int limit = framePosition + frameSize;
        while (id3Data.getPosition() < limit) {
            Id3Frame frame = decodeFrame(majorVersion, id3Data, unsignedIntFrameSizeHack, frameHeaderSize, framePredicate);
            if (frame != null) {
                subFrames.add(frame);
            }
        }
        Id3Frame[] subFrameArray = new Id3Frame[subFrames.size()];
        subFrames.toArray(subFrameArray);
        return new ChapterTocFrame(elementId, isRoot, isOrdered, children, subFrameArray);
    }

    private static MlltFrame decodeMlltFrame(ParsableByteArray id3Data, int frameSize) {
        int mpegFramesBetweenReference = id3Data.readUnsignedShort();
        int bytesBetweenReference = id3Data.readUnsignedInt24();
        int millisecondsBetweenReference = id3Data.readUnsignedInt24();
        int bitsForBytesDeviation = id3Data.readUnsignedByte();
        int bitsForMillisecondsDeviation = id3Data.readUnsignedByte();
        ParsableBitArray references = new ParsableBitArray();
        references.reset(id3Data);
        int referencesBits = (frameSize - 10) * 8;
        int bitsPerReference = bitsForBytesDeviation + bitsForMillisecondsDeviation;
        int referencesCount = referencesBits / bitsPerReference;
        int[] bytesDeviations = new int[referencesCount];
        int[] millisecondsDeviations = new int[referencesCount];
        for (int i = 0; i < referencesCount; i++) {
            int bytesDeviation = references.readBits(bitsForBytesDeviation);
            int millisecondsDeviation = references.readBits(bitsForMillisecondsDeviation);
            bytesDeviations[i] = bytesDeviation;
            millisecondsDeviations[i] = millisecondsDeviation;
        }
        return new MlltFrame(mpegFramesBetweenReference, bytesBetweenReference, millisecondsBetweenReference, bytesDeviations, millisecondsDeviations);
    }

    private static BinaryFrame decodeBinaryFrame(ParsableByteArray id3Data, int frameSize, String id) {
        byte[] frame = new byte[frameSize];
        id3Data.readBytes(frame, 0, frameSize);
        return new BinaryFrame(id, frame);
    }

    private static int removeUnsynchronization(ParsableByteArray data, int length) {
        byte[] bytes = data.data;
        for (int i = data.getPosition(); i + 1 < length; i++) {
            if ((bytes[i] & UByte.MAX_VALUE) == 255 && bytes[i + 1] == 0) {
                System.arraycopy(bytes, i + 2, bytes, i + 1, (length - i) - 2);
                length--;
            }
        }
        return length;
    }

    private static String getCharsetName(int encodingByte) {
        switch (encodingByte) {
            case 1:
                return C.UTF16_NAME;
            case 2:
                return "UTF-16BE";
            case 3:
                return "UTF-8";
            default:
                return "ISO-8859-1";
        }
    }

    private static String getFrameId(int majorVersion, int frameId0, int frameId1, int frameId2, int frameId3) {
        return majorVersion == 2 ? String.format(Locale.US, "%c%c%c", Integer.valueOf(frameId0), Integer.valueOf(frameId1), Integer.valueOf(frameId2)) : String.format(Locale.US, "%c%c%c%c", Integer.valueOf(frameId0), Integer.valueOf(frameId1), Integer.valueOf(frameId2), Integer.valueOf(frameId3));
    }

    private static int indexOfEos(byte[] data, int fromIndex, int encoding) {
        int terminationPos = indexOfZeroByte(data, fromIndex);
        if (encoding == 0 || encoding == 3) {
            return terminationPos;
        }
        while (terminationPos < data.length - 1) {
            if (terminationPos % 2 == 0 && data[terminationPos + 1] == 0) {
                return terminationPos;
            }
            terminationPos = indexOfZeroByte(data, terminationPos + 1);
        }
        return data.length;
    }

    private static int indexOfZeroByte(byte[] data, int fromIndex) {
        for (int i = fromIndex; i < data.length; i++) {
            if (data[i] == 0) {
                return i;
            }
        }
        int i2 = data.length;
        return i2;
    }

    private static int delimiterLength(int encodingByte) {
        return (encodingByte == 0 || encodingByte == 3) ? 1 : 2;
    }

    private static byte[] copyOfRangeIfValid(byte[] data, int from, int to) {
        if (to <= from) {
            return Util.EMPTY_BYTE_ARRAY;
        }
        return Arrays.copyOfRange(data, from, to);
    }

    private static String decodeStringIfValid(byte[] data, int from, int to, String charsetName) throws UnsupportedEncodingException {
        if (to <= from || to > data.length) {
            return "";
        }
        return new String(data, from, to - from, charsetName);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes14.dex */
    public static final class Id3Header {
        private final int framesSize;
        private final boolean isUnsynchronized;
        private final int majorVersion;

        public Id3Header(int majorVersion, boolean isUnsynchronized, int framesSize) {
            this.majorVersion = majorVersion;
            this.isUnsynchronized = isUnsynchronized;
            this.framesSize = framesSize;
        }
    }
}
