package com.google.android.exoplayer2.source.hls.playlist;

import android.net.Uri;
import android.util.Base64;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.Format;
import com.google.android.exoplayer2.ParserException;
import com.google.android.exoplayer2.drm.DrmInitData;
import com.google.android.exoplayer2.extractor.mp4.PsshAtomUtil;
import com.google.android.exoplayer2.offline.DownloadAction;
import com.google.android.exoplayer2.source.UnrecognizedInputFormatException;
import com.google.android.exoplayer2.source.hls.playlist.HlsMasterPlaylist;
import com.google.android.exoplayer2.source.hls.playlist.HlsMediaPlaylist;
import com.google.android.exoplayer2.upstream.ParsingLoadable;
import com.google.android.exoplayer2.util.MimeTypes;
import com.google.android.exoplayer2.util.Util;
import com.king.zxing.util.LogUtils;
import com.litesuits.orm.db.assit.SQLBuilder;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Queue;
import java.util.TreeMap;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
/* loaded from: classes11.dex */
public final class HlsPlaylistParser implements ParsingLoadable.Parser<HlsPlaylist> {
    private static final String ATTR_CLOSED_CAPTIONS_NONE = "CLOSED-CAPTIONS=NONE";
    private static final String BOOLEAN_FALSE = "NO";
    private static final String BOOLEAN_TRUE = "YES";
    private static final String KEYFORMAT_IDENTITY = "identity";
    private static final String KEYFORMAT_PLAYREADY = "com.microsoft.playready";
    private static final String KEYFORMAT_WIDEVINE_PSSH_BINARY = "urn:uuid:edef8ba9-79d6-4ace-a3c8-27dcd51d21ed";
    private static final String KEYFORMAT_WIDEVINE_PSSH_JSON = "com.widevine";
    private static final String METHOD_AES_128 = "AES-128";
    private static final String METHOD_NONE = "NONE";
    private static final String METHOD_SAMPLE_AES = "SAMPLE-AES";
    private static final String METHOD_SAMPLE_AES_CENC = "SAMPLE-AES-CENC";
    private static final String METHOD_SAMPLE_AES_CTR = "SAMPLE-AES-CTR";
    private static final String PLAYLIST_HEADER = "#EXTM3U";
    private static final String TAG_BYTERANGE = "#EXT-X-BYTERANGE";
    private static final String TAG_DEFINE = "#EXT-X-DEFINE";
    private static final String TAG_DISCONTINUITY = "#EXT-X-DISCONTINUITY";
    private static final String TAG_DISCONTINUITY_SEQUENCE = "#EXT-X-DISCONTINUITY-SEQUENCE";
    private static final String TAG_ENDLIST = "#EXT-X-ENDLIST";
    private static final String TAG_GAP = "#EXT-X-GAP";
    private static final String TAG_INDEPENDENT_SEGMENTS = "#EXT-X-INDEPENDENT-SEGMENTS";
    private static final String TAG_INIT_SEGMENT = "#EXT-X-MAP";
    private static final String TAG_KEY = "#EXT-X-KEY";
    private static final String TAG_MEDIA = "#EXT-X-MEDIA";
    private static final String TAG_MEDIA_DURATION = "#EXTINF";
    private static final String TAG_MEDIA_SEQUENCE = "#EXT-X-MEDIA-SEQUENCE";
    private static final String TAG_PLAYLIST_TYPE = "#EXT-X-PLAYLIST-TYPE";
    private static final String TAG_PREFIX = "#EXT";
    private static final String TAG_PROGRAM_DATE_TIME = "#EXT-X-PROGRAM-DATE-TIME";
    private static final String TAG_START = "#EXT-X-START";
    private static final String TAG_STREAM_INF = "#EXT-X-STREAM-INF";
    private static final String TAG_TARGET_DURATION = "#EXT-X-TARGETDURATION";
    private static final String TAG_VERSION = "#EXT-X-VERSION";
    private static final String TYPE_AUDIO = "AUDIO";
    private static final String TYPE_CLOSED_CAPTIONS = "CLOSED-CAPTIONS";
    private static final String TYPE_SUBTITLES = "SUBTITLES";
    private static final String TYPE_VIDEO = "VIDEO";
    private final HlsMasterPlaylist masterPlaylist;
    private static final Pattern REGEX_AVERAGE_BANDWIDTH = Pattern.compile("AVERAGE-BANDWIDTH=(\\d+)\\b");
    private static final Pattern REGEX_AUDIO = Pattern.compile("AUDIO=\"(.+?)\"");
    private static final Pattern REGEX_BANDWIDTH = Pattern.compile("[^-]BANDWIDTH=(\\d+)\\b");
    private static final Pattern REGEX_CODECS = Pattern.compile("CODECS=\"(.+?)\"");
    private static final Pattern REGEX_RESOLUTION = Pattern.compile("RESOLUTION=(\\d+x\\d+)");
    private static final Pattern REGEX_FRAME_RATE = Pattern.compile("FRAME-RATE=([\\d\\.]+)\\b");
    private static final Pattern REGEX_TARGET_DURATION = Pattern.compile("#EXT-X-TARGETDURATION:(\\d+)\\b");
    private static final Pattern REGEX_VERSION = Pattern.compile("#EXT-X-VERSION:(\\d+)\\b");
    private static final Pattern REGEX_PLAYLIST_TYPE = Pattern.compile("#EXT-X-PLAYLIST-TYPE:(.+)\\b");
    private static final Pattern REGEX_MEDIA_SEQUENCE = Pattern.compile("#EXT-X-MEDIA-SEQUENCE:(\\d+)\\b");
    private static final Pattern REGEX_MEDIA_DURATION = Pattern.compile("#EXTINF:([\\d\\.]+)\\b");
    private static final Pattern REGEX_MEDIA_TITLE = Pattern.compile("#EXTINF:[\\d\\.]+\\b,(.+)");
    private static final Pattern REGEX_TIME_OFFSET = Pattern.compile("TIME-OFFSET=(-?[\\d\\.]+)\\b");
    private static final Pattern REGEX_BYTERANGE = Pattern.compile("#EXT-X-BYTERANGE:(\\d+(?:@\\d+)?)\\b");
    private static final Pattern REGEX_ATTR_BYTERANGE = Pattern.compile("BYTERANGE=\"(\\d+(?:@\\d+)?)\\b\"");
    private static final Pattern REGEX_METHOD = Pattern.compile("METHOD=(NONE|AES-128|SAMPLE-AES|SAMPLE-AES-CENC|SAMPLE-AES-CTR)\\s*(?:,|$)");
    private static final Pattern REGEX_KEYFORMAT = Pattern.compile("KEYFORMAT=\"(.+?)\"");
    private static final Pattern REGEX_KEYFORMATVERSIONS = Pattern.compile("KEYFORMATVERSIONS=\"(.+?)\"");
    private static final Pattern REGEX_URI = Pattern.compile("URI=\"(.+?)\"");
    private static final Pattern REGEX_IV = Pattern.compile("IV=([^,.*]+)");
    private static final Pattern REGEX_TYPE = Pattern.compile("TYPE=(AUDIO|VIDEO|SUBTITLES|CLOSED-CAPTIONS)");
    private static final Pattern REGEX_LANGUAGE = Pattern.compile("LANGUAGE=\"(.+?)\"");
    private static final Pattern REGEX_NAME = Pattern.compile("NAME=\"(.+?)\"");
    private static final Pattern REGEX_GROUP_ID = Pattern.compile("GROUP-ID=\"(.+?)\"");
    private static final Pattern REGEX_INSTREAM_ID = Pattern.compile("INSTREAM-ID=\"((?:CC|SERVICE)\\d+)\"");
    private static final Pattern REGEX_AUTOSELECT = compileBooleanAttrPattern("AUTOSELECT");
    private static final Pattern REGEX_DEFAULT = compileBooleanAttrPattern("DEFAULT");
    private static final Pattern REGEX_FORCED = compileBooleanAttrPattern("FORCED");
    private static final Pattern REGEX_VALUE = Pattern.compile("VALUE=\"(.+?)\"");
    private static final Pattern REGEX_IMPORT = Pattern.compile("IMPORT=\"(.+?)\"");
    private static final Pattern REGEX_VARIABLE_REFERENCE = Pattern.compile("\\{\\$([a-zA-Z0-9\\-_]+)\\}");

    public HlsPlaylistParser() {
        this(HlsMasterPlaylist.EMPTY);
    }

    public HlsPlaylistParser(HlsMasterPlaylist masterPlaylist) {
        this.masterPlaylist = masterPlaylist;
    }

    /* JADX WARN: Can't rename method to resolve collision */
    @Override // com.google.android.exoplayer2.upstream.ParsingLoadable.Parser
    public HlsPlaylist parse(Uri uri, InputStream inputStream) throws IOException {
        String line;
        BufferedReader reader = new BufferedReader(new InputStreamReader(inputStream));
        Queue<String> extraLines = new ArrayDeque<>();
        try {
            if (checkPlaylistHeader(reader)) {
                while (true) {
                    String line2 = reader.readLine();
                    if (line2 == null) {
                        Util.closeQuietly(reader);
                        throw new ParserException("Failed to parse the playlist, could not identify any tags.");
                    }
                    line = line2.trim();
                    if (!line.isEmpty()) {
                        if (!line.startsWith(TAG_STREAM_INF)) {
                            if (line.startsWith(TAG_TARGET_DURATION) || line.startsWith(TAG_MEDIA_SEQUENCE) || line.startsWith(TAG_MEDIA_DURATION) || line.startsWith(TAG_KEY) || line.startsWith(TAG_BYTERANGE) || line.equals(TAG_DISCONTINUITY) || line.equals(TAG_DISCONTINUITY_SEQUENCE) || line.equals(TAG_ENDLIST)) {
                                break;
                            }
                            extraLines.add(line);
                        } else {
                            extraLines.add(line);
                            return parseMasterPlaylist(new LineIterator(extraLines, reader), uri.toString());
                        }
                    }
                }
                extraLines.add(line);
                return parseMediaPlaylist(this.masterPlaylist, new LineIterator(extraLines, reader), uri.toString());
            }
            throw new UnrecognizedInputFormatException("Input does not start with the #EXTM3U header.", uri);
        } finally {
            Util.closeQuietly(reader);
        }
    }

    private static boolean checkPlaylistHeader(BufferedReader reader) throws IOException {
        int last = reader.read();
        if (last == 239) {
            if (reader.read() != 187 || reader.read() != 191) {
                return false;
            }
            last = reader.read();
        }
        int last2 = skipIgnorableWhitespace(reader, true, last);
        int playlistHeaderLength = PLAYLIST_HEADER.length();
        for (int i = 0; i < playlistHeaderLength; i++) {
            if (last2 != PLAYLIST_HEADER.charAt(i)) {
                return false;
            }
            last2 = reader.read();
        }
        return Util.isLinebreak(skipIgnorableWhitespace(reader, false, last2));
    }

    private static int skipIgnorableWhitespace(BufferedReader reader, boolean skipLinebreaks, int c) throws IOException {
        while (c != -1 && Character.isWhitespace(c) && (skipLinebreaks || !Util.isLinebreak(c))) {
            c = reader.read();
        }
        return c;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARN: Incorrect condition in loop: B:4:0x0039 */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static HlsMasterPlaylist parseMasterPlaylist(LineIterator iterator, String baseUri) throws IOException {
        char c;
        String mimeType;
        int accessibilityChannel;
        List<Format> muxedCaptionFormats;
        int width;
        int height;
        float frameRate;
        List<Format> muxedCaptionFormats2;
        HashSet<String> variantUrls;
        HashSet<String> variantUrls2 = new HashSet<>();
        HashMap<String, String> audioGroupIdToCodecs = new HashMap<>();
        HashMap<String, String> variableDefinitions = new HashMap<>();
        ArrayList<HlsMasterPlaylist.HlsUrl> variants = new ArrayList<>();
        ArrayList<HlsMasterPlaylist.HlsUrl> audios = new ArrayList<>();
        ArrayList<HlsMasterPlaylist.HlsUrl> subtitles = new ArrayList<>();
        ArrayList<String> mediaTags = new ArrayList<>();
        ArrayList<String> tags = new ArrayList<>();
        Format muxedAudioFormat = null;
        List<Format> muxedCaptionFormats3 = null;
        boolean noClosedCaptions = false;
        boolean hasIndependentSegmentsTag = false;
        while (noClosedCaptions) {
            String line = iterator.next();
            if (line.startsWith(TAG_PREFIX)) {
                tags.add(line);
            }
            if (line.startsWith(TAG_DEFINE)) {
                variableDefinitions.put(parseStringAttr(line, REGEX_NAME, variableDefinitions), parseStringAttr(line, REGEX_VALUE, variableDefinitions));
            } else if (line.equals(TAG_INDEPENDENT_SEGMENTS)) {
                hasIndependentSegmentsTag = true;
            } else if (line.startsWith(TAG_MEDIA)) {
                mediaTags.add(line);
            } else if (line.startsWith(TAG_STREAM_INF)) {
                noClosedCaptions |= line.contains(ATTR_CLOSED_CAPTIONS_NONE);
                int bitrate = parseIntAttr(line, REGEX_BANDWIDTH);
                String averageBandwidthString = parseOptionalStringAttr(line, REGEX_AVERAGE_BANDWIDTH, variableDefinitions);
                if (averageBandwidthString != null) {
                    bitrate = Integer.parseInt(averageBandwidthString);
                }
                String codecs = parseOptionalStringAttr(line, REGEX_CODECS, variableDefinitions);
                String resolutionString = parseOptionalStringAttr(line, REGEX_RESOLUTION, variableDefinitions);
                if (resolutionString != null) {
                    String[] widthAndHeight = resolutionString.split("x");
                    int width2 = Integer.parseInt(widthAndHeight[0]);
                    int height2 = Integer.parseInt(widthAndHeight[1]);
                    if (width2 <= 0 || height2 <= 0) {
                        width2 = -1;
                        height2 = -1;
                    }
                    width = width2;
                    height = height2;
                } else {
                    width = -1;
                    height = -1;
                }
                Format muxedAudioFormat2 = muxedAudioFormat;
                String frameRateString = parseOptionalStringAttr(line, REGEX_FRAME_RATE, variableDefinitions);
                if (frameRateString == null) {
                    frameRate = -1.0f;
                } else {
                    float frameRate2 = Float.parseFloat(frameRateString);
                    frameRate = frameRate2;
                }
                String audioGroupId = parseOptionalStringAttr(line, REGEX_AUDIO, variableDefinitions);
                if (audioGroupId == null || codecs == null) {
                    muxedCaptionFormats2 = muxedCaptionFormats3;
                } else {
                    muxedCaptionFormats2 = muxedCaptionFormats3;
                    audioGroupIdToCodecs.put(audioGroupId, Util.getCodecsOfType(codecs, 1));
                }
                String line2 = replaceVariableReferences(iterator.next(), variableDefinitions);
                if (!variantUrls2.add(line2)) {
                    variantUrls = variantUrls2;
                } else {
                    variantUrls = variantUrls2;
                    variants.add(new HlsMasterPlaylist.HlsUrl(line2, Format.createVideoContainerFormat(Integer.toString(variants.size()), null, MimeTypes.APPLICATION_M3U8, null, codecs, bitrate, width, height, frameRate, null, 0)));
                }
                variantUrls2 = variantUrls;
                muxedAudioFormat = muxedAudioFormat2;
                muxedCaptionFormats3 = muxedCaptionFormats2;
            }
            variantUrls2 = variantUrls2;
            muxedAudioFormat = muxedAudioFormat;
            muxedCaptionFormats3 = muxedCaptionFormats3;
        }
        Format muxedAudioFormat3 = muxedAudioFormat;
        List<Format> muxedCaptionFormats4 = muxedCaptionFormats3;
        int i = 0;
        while (i < mediaTags.size()) {
            String line3 = mediaTags.get(i);
            int selectionFlags = parseSelectionFlags(line3);
            String uri = parseOptionalStringAttr(line3, REGEX_URI, variableDefinitions);
            String name = parseStringAttr(line3, REGEX_NAME, variableDefinitions);
            String language = parseOptionalStringAttr(line3, REGEX_LANGUAGE, variableDefinitions);
            String groupId = parseOptionalStringAttr(line3, REGEX_GROUP_ID, variableDefinitions);
            String id = groupId + LogUtils.COLON + name;
            String parseStringAttr = parseStringAttr(line3, REGEX_TYPE, variableDefinitions);
            ArrayList<String> mediaTags2 = mediaTags;
            switch (parseStringAttr.hashCode()) {
                case -959297733:
                    if (parseStringAttr.equals(TYPE_SUBTITLES)) {
                        c = 1;
                        break;
                    }
                    c = 65535;
                    break;
                case -333210994:
                    if (parseStringAttr.equals(TYPE_CLOSED_CAPTIONS)) {
                        c = 2;
                        break;
                    }
                    c = 65535;
                    break;
                case 62628790:
                    if (parseStringAttr.equals(TYPE_AUDIO)) {
                        c = 0;
                        break;
                    }
                    c = 65535;
                    break;
                default:
                    c = 65535;
                    break;
            }
            switch (c) {
                case 0:
                    String codecs2 = audioGroupIdToCodecs.get(groupId);
                    String sampleMimeType = codecs2 != null ? MimeTypes.getMediaMimeType(codecs2) : null;
                    Format format = Format.createAudioContainerFormat(id, name, MimeTypes.APPLICATION_M3U8, sampleMimeType, codecs2, -1, -1, -1, null, selectionFlags, language);
                    if (isMediaTagMuxed(variants, uri)) {
                        muxedAudioFormat3 = format;
                        break;
                    } else {
                        audios.add(new HlsMasterPlaylist.HlsUrl(uri, format));
                        break;
                    }
                case 1:
                    subtitles.add(new HlsMasterPlaylist.HlsUrl(uri, Format.createTextContainerFormat(id, name, MimeTypes.APPLICATION_M3U8, MimeTypes.TEXT_VTT, null, -1, selectionFlags, language)));
                    break;
                case 2:
                    String instreamId = parseStringAttr(line3, REGEX_INSTREAM_ID, variableDefinitions);
                    if (instreamId.startsWith("CC")) {
                        mimeType = MimeTypes.APPLICATION_CEA608;
                        accessibilityChannel = Integer.parseInt(instreamId.substring(2));
                    } else {
                        mimeType = MimeTypes.APPLICATION_CEA708;
                        accessibilityChannel = Integer.parseInt(instreamId.substring(7));
                    }
                    if (muxedCaptionFormats4 == null) {
                        List<Format> muxedCaptionFormats5 = new ArrayList<>();
                        muxedCaptionFormats = muxedCaptionFormats5;
                    } else {
                        muxedCaptionFormats = muxedCaptionFormats4;
                    }
                    muxedCaptionFormats.add(Format.createTextContainerFormat(id, name, null, mimeType, null, -1, selectionFlags, language, accessibilityChannel));
                    muxedCaptionFormats4 = muxedCaptionFormats;
                    break;
            }
            i++;
            mediaTags = mediaTags2;
        }
        if (noClosedCaptions) {
            muxedCaptionFormats4 = Collections.emptyList();
        }
        return new HlsMasterPlaylist(baseUri, tags, variants, audios, subtitles, muxedAudioFormat3, muxedCaptionFormats4, hasIndependentSegmentsTag, variableDefinitions);
    }

    private static int parseSelectionFlags(String line) {
        int flags = 0;
        if (parseOptionalBooleanAttribute(line, REGEX_DEFAULT, false)) {
            flags = 0 | 1;
        }
        if (parseOptionalBooleanAttribute(line, REGEX_FORCED, false)) {
            flags |= 2;
        }
        if (parseOptionalBooleanAttribute(line, REGEX_AUTOSELECT, false)) {
            return flags | 4;
        }
        return flags;
    }

    private static HlsMediaPlaylist parseMediaPlaylist(HlsMasterPlaylist masterPlaylist, LineIterator iterator, String baseUri) throws IOException {
        boolean hasEndTag;
        String segmentEncryptionIV;
        DrmInitData cachedDrmInitData;
        DrmInitData.SchemeData schemeData;
        TreeMap<String, DrmInitData.SchemeData> currentSchemeDatas;
        String str;
        HlsMasterPlaylist hlsMasterPlaylist = masterPlaylist;
        int playlistType = 0;
        long startOffsetUs = C.TIME_UNSET;
        long mediaSequence = 0;
        int version = 1;
        long segmentDurationUs = C.TIME_UNSET;
        boolean hasIndependentSegmentsTag = hlsMasterPlaylist.hasIndependentSegments;
        boolean hasEndTag2 = false;
        HlsMediaPlaylist.Segment initializationSegment = null;
        HashMap<String, String> variableDefinitions = new HashMap<>();
        List<HlsMediaPlaylist.Segment> segments = new ArrayList<>();
        List<String> tags = new ArrayList<>();
        TreeMap<String, DrmInitData.SchemeData> currentSchemeDatas2 = new TreeMap<>();
        int playlistDiscontinuitySequence = 0;
        int relativeDiscontinuitySequence = 0;
        long playlistStartTimeUs = 0;
        long segmentStartTimeUs = 0;
        long segmentByteRangeOffset = 0;
        long segmentByteRangeLength = -1;
        long segmentMediaSequence = 0;
        boolean hasGapTag = false;
        DrmInitData playlistProtectionSchemes = null;
        String encryptionKeyUri = null;
        String encryptionIV = null;
        DrmInitData cachedDrmInitData2 = null;
        String segmentTitle = "";
        long segmentDurationUs2 = 0;
        String segmentTitle2 = null;
        boolean hasDiscontinuitySequence = false;
        while (true) {
            hasEndTag = hasEndTag2;
            if (!iterator.hasNext()) {
                break;
            }
            String line = iterator.next();
            boolean hasIndependentSegmentsTag2 = hasIndependentSegmentsTag;
            if (line.startsWith(TAG_PREFIX)) {
                tags.add(line);
            }
            if (line.startsWith(TAG_PLAYLIST_TYPE)) {
                String playlistTypeString = parseStringAttr(line, REGEX_PLAYLIST_TYPE, variableDefinitions);
                List<String> tags2 = tags;
                if ("VOD".equals(playlistTypeString)) {
                    playlistType = 1;
                } else if ("EVENT".equals(playlistTypeString)) {
                    playlistType = 2;
                }
                tags = tags2;
                hasEndTag2 = hasEndTag;
                hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
            } else {
                List<String> tags3 = tags;
                if (line.startsWith(TAG_START)) {
                    long targetDurationUs = segmentDurationUs;
                    startOffsetUs = (long) (parseDoubleAttr(line, REGEX_TIME_OFFSET) * 1000000.0d);
                    tags = tags3;
                    hasEndTag2 = hasEndTag;
                    hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                    segmentDurationUs = targetDurationUs;
                } else {
                    long targetDurationUs2 = segmentDurationUs;
                    if (line.startsWith(TAG_INIT_SEGMENT)) {
                        String uri = parseStringAttr(line, REGEX_URI, variableDefinitions);
                        String byteRange = parseOptionalStringAttr(line, REGEX_ATTR_BYTERANGE, variableDefinitions);
                        if (byteRange != null) {
                            String[] splitByteRange = byteRange.split("@");
                            segmentByteRangeLength = Long.parseLong(splitByteRange[0]);
                            if (splitByteRange.length > 1) {
                                segmentByteRangeOffset = Long.parseLong(splitByteRange[1]);
                            }
                        }
                        initializationSegment = new HlsMediaPlaylist.Segment(uri, segmentByteRangeOffset, segmentByteRangeLength);
                        segmentByteRangeOffset = 0;
                        segmentByteRangeLength = -1;
                        tags = tags3;
                        hasEndTag2 = hasEndTag;
                        hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                        segmentDurationUs = targetDurationUs2;
                    } else if (line.startsWith(TAG_TARGET_DURATION)) {
                        segmentDurationUs = parseIntAttr(line, REGEX_TARGET_DURATION) * 1000000;
                        tags = tags3;
                        hasEndTag2 = hasEndTag;
                        hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                    } else if (line.startsWith(TAG_MEDIA_SEQUENCE)) {
                        mediaSequence = parseLongAttr(line, REGEX_MEDIA_SEQUENCE);
                        segmentMediaSequence = mediaSequence;
                        tags = tags3;
                        hasEndTag2 = hasEndTag;
                        hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                        segmentDurationUs = targetDurationUs2;
                    } else if (line.startsWith(TAG_VERSION)) {
                        version = parseIntAttr(line, REGEX_VERSION);
                        tags = tags3;
                        hasEndTag2 = hasEndTag;
                        hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                        segmentDurationUs = targetDurationUs2;
                    } else {
                        if (line.startsWith(TAG_DEFINE)) {
                            String importName = parseOptionalStringAttr(line, REGEX_IMPORT, variableDefinitions);
                            if (importName != null) {
                                String value = hlsMasterPlaylist.variableDefinitions.get(importName);
                                if (value != null) {
                                    variableDefinitions.put(importName, value);
                                }
                            } else {
                                variableDefinitions.put(parseStringAttr(line, REGEX_NAME, variableDefinitions), parseStringAttr(line, REGEX_VALUE, variableDefinitions));
                            }
                        } else if (line.startsWith(TAG_MEDIA_DURATION)) {
                            long segmentDurationUs3 = (long) (parseDoubleAttr(line, REGEX_MEDIA_DURATION) * 1000000.0d);
                            segmentTitle = parseOptionalStringAttr(line, REGEX_MEDIA_TITLE, "", variableDefinitions);
                            segmentDurationUs2 = segmentDurationUs3;
                            tags = tags3;
                            hasEndTag2 = hasEndTag;
                            hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                            segmentDurationUs = targetDurationUs2;
                        } else if (line.startsWith(TAG_KEY)) {
                            String method = parseStringAttr(line, REGEX_METHOD, variableDefinitions);
                            String keyFormat = parseOptionalStringAttr(line, REGEX_KEYFORMAT, KEYFORMAT_IDENTITY, variableDefinitions);
                            if (METHOD_NONE.equals(method)) {
                                currentSchemeDatas2.clear();
                                cachedDrmInitData2 = null;
                                encryptionKeyUri = null;
                                encryptionIV = null;
                                currentSchemeDatas = currentSchemeDatas2;
                            } else {
                                String encryptionIV2 = parseOptionalStringAttr(line, REGEX_IV, variableDefinitions);
                                if (KEYFORMAT_IDENTITY.equals(keyFormat)) {
                                    if (!METHOD_AES_128.equals(method)) {
                                        encryptionIV = encryptionIV2;
                                        encryptionKeyUri = null;
                                        currentSchemeDatas = currentSchemeDatas2;
                                    } else {
                                        encryptionIV = encryptionIV2;
                                        encryptionKeyUri = parseStringAttr(line, REGEX_URI, variableDefinitions);
                                        currentSchemeDatas = currentSchemeDatas2;
                                    }
                                } else {
                                    if (segmentTitle2 == null) {
                                        if (METHOD_SAMPLE_AES_CENC.equals(method) || METHOD_SAMPLE_AES_CTR.equals(method)) {
                                            str = C.CENC_TYPE_cenc;
                                        } else {
                                            str = C.CENC_TYPE_cbcs;
                                        }
                                        segmentTitle2 = str;
                                    }
                                    if (KEYFORMAT_PLAYREADY.equals(keyFormat)) {
                                        schemeData = parsePlayReadySchemeData(line, variableDefinitions);
                                    } else {
                                        schemeData = parseWidevineSchemeData(line, keyFormat, variableDefinitions);
                                    }
                                    if (schemeData != null) {
                                        currentSchemeDatas = currentSchemeDatas2;
                                        currentSchemeDatas.put(keyFormat, schemeData);
                                        encryptionKeyUri = null;
                                        cachedDrmInitData2 = null;
                                        encryptionIV = encryptionIV2;
                                    } else {
                                        currentSchemeDatas = currentSchemeDatas2;
                                        encryptionKeyUri = null;
                                        encryptionIV = encryptionIV2;
                                    }
                                }
                            }
                            currentSchemeDatas2 = currentSchemeDatas;
                            tags = tags3;
                            hasEndTag2 = hasEndTag;
                            hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                            segmentDurationUs = targetDurationUs2;
                            hlsMasterPlaylist = masterPlaylist;
                        } else {
                            TreeMap<String, DrmInitData.SchemeData> currentSchemeDatas3 = currentSchemeDatas2;
                            if (line.startsWith(TAG_BYTERANGE)) {
                                String[] splitByteRange2 = parseStringAttr(line, REGEX_BYTERANGE, variableDefinitions).split("@");
                                segmentByteRangeLength = Long.parseLong(splitByteRange2[0]);
                                if (splitByteRange2.length > 1) {
                                    segmentByteRangeOffset = Long.parseLong(splitByteRange2[1]);
                                }
                                currentSchemeDatas2 = currentSchemeDatas3;
                                tags = tags3;
                                hasEndTag2 = hasEndTag;
                                hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                                segmentDurationUs = targetDurationUs2;
                                hlsMasterPlaylist = masterPlaylist;
                            } else if (line.startsWith(TAG_DISCONTINUITY_SEQUENCE)) {
                                hasDiscontinuitySequence = true;
                                playlistDiscontinuitySequence = Integer.parseInt(line.substring(line.indexOf(58) + 1));
                                currentSchemeDatas2 = currentSchemeDatas3;
                                tags = tags3;
                                hasEndTag2 = hasEndTag;
                                hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                                segmentDurationUs = targetDurationUs2;
                                hlsMasterPlaylist = masterPlaylist;
                            } else if (line.equals(TAG_DISCONTINUITY)) {
                                relativeDiscontinuitySequence++;
                                currentSchemeDatas2 = currentSchemeDatas3;
                                tags = tags3;
                                hasEndTag2 = hasEndTag;
                                hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                                segmentDurationUs = targetDurationUs2;
                                hlsMasterPlaylist = masterPlaylist;
                            } else if (line.startsWith(TAG_PROGRAM_DATE_TIME)) {
                                if (playlistStartTimeUs != 0) {
                                    currentSchemeDatas2 = currentSchemeDatas3;
                                } else {
                                    long programDatetimeUs = C.msToUs(Util.parseXsDateTime(line.substring(line.indexOf(58) + 1)));
                                    playlistStartTimeUs = programDatetimeUs - segmentStartTimeUs;
                                    currentSchemeDatas2 = currentSchemeDatas3;
                                    tags = tags3;
                                    hasEndTag2 = hasEndTag;
                                    hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                                    segmentDurationUs = targetDurationUs2;
                                    hlsMasterPlaylist = masterPlaylist;
                                }
                            } else if (line.equals(TAG_GAP)) {
                                hasGapTag = true;
                                currentSchemeDatas2 = currentSchemeDatas3;
                                tags = tags3;
                                hasEndTag2 = hasEndTag;
                                hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                                segmentDurationUs = targetDurationUs2;
                                hlsMasterPlaylist = masterPlaylist;
                            } else if (line.equals(TAG_INDEPENDENT_SEGMENTS)) {
                                hasIndependentSegmentsTag = true;
                                currentSchemeDatas2 = currentSchemeDatas3;
                                tags = tags3;
                                hasEndTag2 = hasEndTag;
                                segmentDurationUs = targetDurationUs2;
                                hlsMasterPlaylist = masterPlaylist;
                            } else if (line.equals(TAG_ENDLIST)) {
                                currentSchemeDatas2 = currentSchemeDatas3;
                                hasEndTag2 = true;
                                tags = tags3;
                                hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                                segmentDurationUs = targetDurationUs2;
                                hlsMasterPlaylist = masterPlaylist;
                            } else if (line.startsWith("#")) {
                                currentSchemeDatas2 = currentSchemeDatas3;
                            } else {
                                if (encryptionKeyUri == null) {
                                    segmentEncryptionIV = null;
                                } else if (encryptionIV != null) {
                                    segmentEncryptionIV = encryptionIV;
                                } else {
                                    segmentEncryptionIV = Long.toHexString(segmentMediaSequence);
                                }
                                segmentMediaSequence++;
                                if (segmentByteRangeLength == -1) {
                                    segmentByteRangeOffset = 0;
                                }
                                if (cachedDrmInitData2 != null || currentSchemeDatas3.isEmpty()) {
                                    currentSchemeDatas2 = currentSchemeDatas3;
                                } else {
                                    DrmInitData.SchemeData[] schemeDatas = (DrmInitData.SchemeData[]) currentSchemeDatas3.values().toArray(new DrmInitData.SchemeData[0]);
                                    DrmInitData cachedDrmInitData3 = new DrmInitData(segmentTitle2, schemeDatas);
                                    if (playlistProtectionSchemes != null) {
                                        currentSchemeDatas2 = currentSchemeDatas3;
                                        cachedDrmInitData2 = cachedDrmInitData3;
                                    } else {
                                        DrmInitData.SchemeData[] playlistSchemeDatas = new DrmInitData.SchemeData[schemeDatas.length];
                                        currentSchemeDatas2 = currentSchemeDatas3;
                                        int i = 0;
                                        while (true) {
                                            cachedDrmInitData = cachedDrmInitData3;
                                            if (i >= schemeDatas.length) {
                                                break;
                                            }
                                            playlistSchemeDatas[i] = schemeDatas[i].copyWithData(null);
                                            i++;
                                            cachedDrmInitData3 = cachedDrmInitData;
                                            schemeDatas = schemeDatas;
                                        }
                                        playlistProtectionSchemes = new DrmInitData(segmentTitle2, playlistSchemeDatas);
                                        cachedDrmInitData2 = cachedDrmInitData;
                                    }
                                }
                                segments.add(new HlsMediaPlaylist.Segment(replaceVariableReferences(line, variableDefinitions), initializationSegment, segmentTitle, segmentDurationUs2, relativeDiscontinuitySequence, segmentStartTimeUs, cachedDrmInitData2, encryptionKeyUri, segmentEncryptionIV, segmentByteRangeOffset, segmentByteRangeLength, hasGapTag));
                                segmentStartTimeUs += segmentDurationUs2;
                                segmentDurationUs2 = 0;
                                segmentTitle = "";
                                if (segmentByteRangeLength != -1) {
                                    segmentByteRangeOffset += segmentByteRangeLength;
                                }
                                segmentByteRangeLength = -1;
                                hasGapTag = false;
                                hlsMasterPlaylist = masterPlaylist;
                                tags = tags3;
                                hasEndTag2 = hasEndTag;
                                hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                                segmentDurationUs = targetDurationUs2;
                            }
                        }
                        hlsMasterPlaylist = masterPlaylist;
                        tags = tags3;
                        hasEndTag2 = hasEndTag;
                        hasIndependentSegmentsTag = hasIndependentSegmentsTag2;
                        segmentDurationUs = targetDurationUs2;
                    }
                }
            }
        }
        long targetDurationUs3 = segmentDurationUs;
        return new HlsMediaPlaylist(playlistType, baseUri, tags, startOffsetUs, playlistStartTimeUs, hasDiscontinuitySequence, playlistDiscontinuitySequence, mediaSequence, version, targetDurationUs3, hasIndependentSegmentsTag, hasEndTag, playlistStartTimeUs != 0, playlistProtectionSchemes, segments);
    }

    private static DrmInitData.SchemeData parsePlayReadySchemeData(String line, Map<String, String> variableDefinitions) throws ParserException {
        String keyFormatVersions = parseOptionalStringAttr(line, REGEX_KEYFORMATVERSIONS, "1", variableDefinitions);
        if (!"1".equals(keyFormatVersions)) {
            return null;
        }
        String uriString = parseStringAttr(line, REGEX_URI, variableDefinitions);
        byte[] data = Base64.decode(uriString.substring(uriString.indexOf(44)), 0);
        byte[] psshData = PsshAtomUtil.buildPsshAtom(C.PLAYREADY_UUID, data);
        return new DrmInitData.SchemeData(C.PLAYREADY_UUID, MimeTypes.VIDEO_MP4, psshData);
    }

    private static DrmInitData.SchemeData parseWidevineSchemeData(String line, String keyFormat, Map<String, String> variableDefinitions) throws ParserException {
        if (KEYFORMAT_WIDEVINE_PSSH_BINARY.equals(keyFormat)) {
            String uriString = parseStringAttr(line, REGEX_URI, variableDefinitions);
            return new DrmInitData.SchemeData(C.WIDEVINE_UUID, MimeTypes.VIDEO_MP4, Base64.decode(uriString.substring(uriString.indexOf(44)), 0));
        } else if (KEYFORMAT_WIDEVINE_PSSH_JSON.equals(keyFormat)) {
            try {
                return new DrmInitData.SchemeData(C.WIDEVINE_UUID, DownloadAction.TYPE_HLS, line.getBytes("UTF-8"));
            } catch (UnsupportedEncodingException e) {
                throw new ParserException(e);
            }
        } else {
            return null;
        }
    }

    private static int parseIntAttr(String line, Pattern pattern) throws ParserException {
        return Integer.parseInt(parseStringAttr(line, pattern, Collections.emptyMap()));
    }

    private static long parseLongAttr(String line, Pattern pattern) throws ParserException {
        return Long.parseLong(parseStringAttr(line, pattern, Collections.emptyMap()));
    }

    private static double parseDoubleAttr(String line, Pattern pattern) throws ParserException {
        return Double.parseDouble(parseStringAttr(line, pattern, Collections.emptyMap()));
    }

    private static String parseStringAttr(String line, Pattern pattern, Map<String, String> variableDefinitions) throws ParserException {
        String value = parseOptionalStringAttr(line, pattern, variableDefinitions);
        if (value != null) {
            return value;
        }
        throw new ParserException("Couldn't match " + pattern.pattern() + " in " + line);
    }

    private static String parseOptionalStringAttr(String line, Pattern pattern, Map<String, String> variableDefinitions) {
        return parseOptionalStringAttr(line, pattern, null, variableDefinitions);
    }

    private static String parseOptionalStringAttr(String line, Pattern pattern, String defaultValue, Map<String, String> variableDefinitions) {
        Matcher matcher = pattern.matcher(line);
        String value = matcher.find() ? matcher.group(1) : defaultValue;
        if (variableDefinitions.isEmpty() || value == null) {
            return value;
        }
        return replaceVariableReferences(value, variableDefinitions);
    }

    private static String replaceVariableReferences(String string, Map<String, String> variableDefinitions) {
        Matcher matcher = REGEX_VARIABLE_REFERENCE.matcher(string);
        StringBuffer stringWithReplacements = new StringBuffer();
        while (matcher.find()) {
            String groupName = matcher.group(1);
            if (variableDefinitions.containsKey(groupName)) {
                matcher.appendReplacement(stringWithReplacements, Matcher.quoteReplacement(variableDefinitions.get(groupName)));
            }
        }
        matcher.appendTail(stringWithReplacements);
        return stringWithReplacements.toString();
    }

    private static boolean parseOptionalBooleanAttribute(String line, Pattern pattern, boolean defaultValue) {
        Matcher matcher = pattern.matcher(line);
        if (matcher.find()) {
            return matcher.group(1).equals(BOOLEAN_TRUE);
        }
        return defaultValue;
    }

    private static Pattern compileBooleanAttrPattern(String attribute) {
        return Pattern.compile(attribute + "=(" + BOOLEAN_FALSE + LogUtils.VERTICAL + BOOLEAN_TRUE + SQLBuilder.PARENTHESES_RIGHT);
    }

    private static boolean isMediaTagMuxed(List<HlsMasterPlaylist.HlsUrl> variants, String mediaTagUri) {
        if (mediaTagUri == null) {
            return true;
        }
        for (int i = 0; i < variants.size(); i++) {
            if (mediaTagUri.equals(variants.get(i).url)) {
                return true;
            }
        }
        return false;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes11.dex */
    public static class LineIterator {
        private final Queue<String> extraLines;
        private String next;
        private final BufferedReader reader;

        public LineIterator(Queue<String> extraLines, BufferedReader reader) {
            this.extraLines = extraLines;
            this.reader = reader;
        }

        public boolean hasNext() throws IOException {
            String trim;
            if (this.next != null) {
                return true;
            }
            if (!this.extraLines.isEmpty()) {
                this.next = this.extraLines.poll();
                return true;
            }
            do {
                String readLine = this.reader.readLine();
                this.next = readLine;
                if (readLine != null) {
                    trim = readLine.trim();
                    this.next = trim;
                } else {
                    return false;
                }
            } while (trim.isEmpty());
            return true;
        }

        public String next() throws IOException {
            if (!hasNext()) {
                return null;
            }
            String result = this.next;
            this.next = null;
            return result;
        }
    }
}
