package com.google.android.exoplayer2.trackselection;

import com.google.android.exoplayer2.Format;
import com.google.android.exoplayer2.source.chunk.MediaChunk;
import com.google.android.exoplayer2.source.chunk.MediaChunkIterator;
import com.google.android.exoplayer2.source.chunk.MediaChunkListIterator;
import com.google.android.exoplayer2.trackselection.TrackSelection;
import com.google.android.exoplayer2.util.Assertions;
import java.util.Arrays;
import java.util.List;
/* loaded from: classes12.dex */
public final class TrackSelectionUtil {

    /* loaded from: classes12.dex */
    public interface AdaptiveTrackSelectionFactory {
        TrackSelection createAdaptiveTrackSelection(TrackSelection.Definition definition);
    }

    private TrackSelectionUtil() {
    }

    public static TrackSelection[] createTrackSelectionsForDefinitions(TrackSelection.Definition[] definitions, AdaptiveTrackSelectionFactory adaptiveTrackSelectionFactory) {
        TrackSelection[] selections = new TrackSelection[definitions.length];
        boolean createdAdaptiveTrackSelection = false;
        for (int i = 0; i < definitions.length; i++) {
            TrackSelection.Definition definition = definitions[i];
            if (definition != null) {
                if (definition.tracks.length > 1 && !createdAdaptiveTrackSelection) {
                    createdAdaptiveTrackSelection = true;
                    selections[i] = adaptiveTrackSelectionFactory.createAdaptiveTrackSelection(definition);
                } else {
                    selections[i] = new FixedTrackSelection(definition.group, definition.tracks[0]);
                }
            }
        }
        return selections;
    }

    public static int getAverageBitrate(MediaChunkIterator iterator, long maxDurationUs) {
        long totalDurationUs = 0;
        long totalLength = 0;
        while (true) {
            if (!iterator.next()) {
                break;
            }
            long chunkLength = iterator.getDataSpec().length;
            if (chunkLength == -1) {
                break;
            }
            long chunkDurationUs = iterator.getChunkEndTimeUs() - iterator.getChunkStartTimeUs();
            if (totalDurationUs + chunkDurationUs >= maxDurationUs) {
                totalLength += ((maxDurationUs - totalDurationUs) * chunkLength) / chunkDurationUs;
                totalDurationUs = maxDurationUs;
                break;
            }
            totalDurationUs += chunkDurationUs;
            totalLength += chunkLength;
        }
        if (totalDurationUs == 0) {
            return -1;
        }
        return (int) (((8 * totalLength) * 1000000) / totalDurationUs);
    }

    static int[] getBitratesUsingFutureInfo(MediaChunkIterator[] iterators, Format[] formats, long maxDurationUs, int[] bitrates) {
        int trackCount = iterators.length;
        Assertions.checkArgument(trackCount == formats.length);
        if (trackCount == 0) {
            return new int[0];
        }
        if (bitrates == null) {
            bitrates = new int[trackCount];
        }
        if (maxDurationUs == 0) {
            Arrays.fill(bitrates, -1);
            return bitrates;
        }
        int[] formatBitrates = new int[trackCount];
        float[] bitrateRatios = new float[trackCount];
        boolean needEstimateBitrate = false;
        boolean canEstimateBitrate = false;
        for (int i = 0; i < trackCount; i++) {
            int bitrate = getAverageBitrate(iterators[i], maxDurationUs);
            if (bitrate != -1) {
                int formatBitrate = formats[i].bitrate;
                formatBitrates[i] = formatBitrate;
                if (formatBitrate != -1) {
                    bitrateRatios[i] = bitrate / formatBitrate;
                    canEstimateBitrate = true;
                }
            } else {
                needEstimateBitrate = true;
                formatBitrates[i] = -1;
            }
            bitrates[i] = bitrate;
        }
        if (needEstimateBitrate && canEstimateBitrate) {
            estimateBitrates(bitrates, formats, formatBitrates, bitrateRatios);
        }
        return bitrates;
    }

    static int[] getBitratesUsingPastInfo(List<? extends MediaChunk> queue, Format[] formats, long maxDurationUs, int[] bitrates) {
        if (bitrates == null) {
            bitrates = new int[formats.length];
            Arrays.fill(bitrates, -1);
        }
        if (maxDurationUs == 0) {
            return bitrates;
        }
        int queueAverageBitrate = getAverageQueueBitrate(queue, maxDurationUs);
        if (queueAverageBitrate == -1) {
            return bitrates;
        }
        int queueFormatBitrate = queue.get(queue.size() - 1).trackFormat.bitrate;
        if (queueFormatBitrate != -1) {
            float queueBitrateRatio = queueAverageBitrate / queueFormatBitrate;
            estimateBitrates(bitrates, formats, new int[]{queueFormatBitrate}, new float[]{queueBitrateRatio});
        }
        return bitrates;
    }

    public static int[] getBitratesUsingPastAndFutureInfo(Format[] formats, List<? extends MediaChunk> queue, long maxPastDurationUs, MediaChunkIterator[] iterators, long maxFutureDurationUs, boolean useFormatBitrateAsLowerBound, int[] bitrates) {
        int[] bitrates2 = getBitratesUsingFutureInfo(iterators, formats, maxFutureDurationUs, bitrates);
        getBitratesUsingPastInfo(queue, formats, maxPastDurationUs, bitrates2);
        for (int i = 0; i < bitrates2.length; i++) {
            int bitrate = bitrates2[i];
            if (bitrate == -1 || (useFormatBitrateAsLowerBound && formats[i].bitrate != -1 && bitrate < formats[i].bitrate)) {
                bitrates2[i] = formats[i].bitrate;
            }
        }
        return bitrates2;
    }

    public static int[] getFormatBitrates(Format[] formats, int[] bitrates) {
        int trackCount = formats.length;
        if (bitrates == null) {
            bitrates = new int[trackCount];
        }
        for (int i = 0; i < trackCount; i++) {
            bitrates[i] = formats[i].bitrate;
        }
        return bitrates;
    }

    private static void estimateBitrates(int[] bitrates, Format[] formats, int[] referenceBitrates, float[] referenceBitrateRatios) {
        int formatBitrate;
        for (int i = 0; i < bitrates.length; i++) {
            if (bitrates[i] == -1 && (formatBitrate = formats[i].bitrate) != -1) {
                int closestReferenceBitrateIndex = getClosestBitrateIndex(formatBitrate, referenceBitrates);
                bitrates[i] = (int) (referenceBitrateRatios[closestReferenceBitrateIndex] * formatBitrate);
            }
        }
    }

    private static int getAverageQueueBitrate(List<? extends MediaChunk> queue, long maxDurationUs) {
        if (queue.isEmpty()) {
            return -1;
        }
        MediaChunkListIterator iterator = new MediaChunkListIterator(getSingleFormatSubQueue(queue), true);
        return getAverageBitrate(iterator, maxDurationUs);
    }

    private static List<? extends MediaChunk> getSingleFormatSubQueue(List<? extends MediaChunk> queue) {
        Format queueFormat = queue.get(queue.size() - 1).trackFormat;
        int queueSize = queue.size();
        for (int i = queueSize - 2; i >= 0; i--) {
            if (!queue.get(i).trackFormat.equals(queueFormat)) {
                return queue.subList(i + 1, queueSize);
            }
        }
        return queue;
    }

    private static int getClosestBitrateIndex(int formatBitrate, int[] formatBitrates) {
        int distance;
        int closestDistance = Integer.MAX_VALUE;
        int closestFormat = -1;
        for (int j = 0; j < formatBitrates.length; j++) {
            if (formatBitrates[j] != -1 && (distance = Math.abs(formatBitrates[j] - formatBitrate)) < closestDistance) {
                closestDistance = distance;
                closestFormat = j;
            }
        }
        return closestFormat;
    }
}
