package com.google.android.exoplayer2.upstream.cache;

import android.net.Uri;
import com.google.android.exoplayer2.upstream.DataSource;
import com.google.android.exoplayer2.upstream.DataSpec;
import com.google.android.exoplayer2.upstream.cache.Cache;
import com.google.android.exoplayer2.upstream.cache.ContentMetadata;
import com.google.android.exoplayer2.util.Assertions;
import com.google.android.exoplayer2.util.PriorityTaskManager;
import com.google.android.exoplayer2.util.Util;
import java.io.EOFException;
import java.io.IOException;
import java.util.NavigableSet;
import java.util.concurrent.atomic.AtomicBoolean;
/* loaded from: classes15.dex */
public final class CacheUtil {
    public static final int DEFAULT_BUFFER_SIZE_BYTES = 131072;
    public static final CacheKeyFactory DEFAULT_CACHE_KEY_FACTORY = new CacheKeyFactory() { // from class: com.google.android.exoplayer2.upstream.cache.CacheUtil$$ExternalSyntheticLambda0
        @Override // com.google.android.exoplayer2.upstream.cache.CacheKeyFactory
        public final String buildCacheKey(DataSpec dataSpec) {
            return CacheUtil.lambda$static$0(dataSpec);
        }
    };

    /* loaded from: classes15.dex */
    public static class CachingCounters {
        public volatile long alreadyCachedBytes;
        public volatile long contentLength = -1;
        public volatile long newlyCachedBytes;

        public long totalCachedBytes() {
            return this.alreadyCachedBytes + this.newlyCachedBytes;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public static /* synthetic */ String lambda$static$0(DataSpec dataSpec) {
        return dataSpec.key != null ? dataSpec.key : generateKey(dataSpec.uri);
    }

    public static String generateKey(Uri uri) {
        return uri.toString();
    }

    public static void getCached(DataSpec dataSpec, Cache cache, CacheKeyFactory cacheKeyFactory, CachingCounters counters) {
        long left;
        String key = buildCacheKey(dataSpec, cacheKeyFactory);
        long start = dataSpec.absoluteStreamPosition;
        if (dataSpec.length != -1) {
            left = dataSpec.length;
        } else {
            left = ContentMetadata.CC.getContentLength(cache.getContentMetadata(key));
        }
        counters.contentLength = left;
        counters.alreadyCachedBytes = 0L;
        counters.newlyCachedBytes = 0L;
        long start2 = start;
        long left2 = left;
        while (left2 != 0) {
            long blockLength = cache.getCachedLength(key, start2, left2 != -1 ? left2 : Long.MAX_VALUE);
            if (blockLength > 0) {
                counters.alreadyCachedBytes += blockLength;
            } else {
                blockLength = -blockLength;
                if (blockLength == Long.MAX_VALUE) {
                    return;
                }
            }
            start2 += blockLength;
            left2 -= left2 == -1 ? 0L : blockLength;
        }
    }

    public static void cache(DataSpec dataSpec, Cache cache, CacheKeyFactory cacheKeyFactory, DataSource upstream, CachingCounters counters, AtomicBoolean isCanceled) throws IOException, InterruptedException {
        cache(dataSpec, cache, cacheKeyFactory, new CacheDataSource(cache, upstream), new byte[131072], null, 0, counters, isCanceled, false);
    }

    public static void cache(DataSpec dataSpec, Cache cache, CacheKeyFactory cacheKeyFactory, CacheDataSource dataSource, byte[] buffer, PriorityTaskManager priorityTaskManager, int priority, CachingCounters counters, AtomicBoolean isCanceled, boolean enableEOFException) throws IOException, InterruptedException {
        CachingCounters counters2;
        long contentLength;
        Assertions.checkNotNull(dataSource);
        Assertions.checkNotNull(buffer);
        if (counters != null) {
            getCached(dataSpec, cache, cacheKeyFactory, counters);
            counters2 = counters;
        } else {
            counters2 = new CachingCounters();
        }
        String key = buildCacheKey(dataSpec, cacheKeyFactory);
        long start = dataSpec.absoluteStreamPosition;
        if (dataSpec.length != -1) {
            contentLength = dataSpec.length;
        } else {
            contentLength = ContentMetadata.CC.getContentLength(cache.getContentMetadata(key));
        }
        long start2 = start;
        long left = contentLength;
        while (true) {
            long j = 0;
            if (left != 0) {
                throwExceptionIfInterruptedOrCancelled(isCanceled);
                long read = cache.getCachedLength(key, start2, left != -1 ? left : Long.MAX_VALUE);
                if (read <= 0) {
                    long blockLength = -read;
                    if (readAndDiscard(dataSpec, start2, blockLength, dataSource, buffer, priorityTaskManager, priority, counters2, isCanceled) >= blockLength) {
                        read = blockLength;
                    } else if (enableEOFException && left != -1) {
                        throw new EOFException();
                    } else {
                        return;
                    }
                }
                start2 += read;
                if (left != -1) {
                    j = read;
                }
                left -= j;
            } else {
                return;
            }
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:20:0x0069, code lost:
        if (r26.contentLength != (-1)) goto L28;
     */
    /* JADX WARN: Code restructure failed: missing block: B:21:0x006b, code lost:
        r26.contentLength = r4.absoluteStreamPosition + r7;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private static long readAndDiscard(DataSpec dataSpec, long absoluteStreamPosition, long length, DataSource dataSource, byte[] buffer, PriorityTaskManager priorityTaskManager, int priority, CachingCounters counters, AtomicBoolean isCanceled) throws IOException, InterruptedException {
        long totalRead;
        DataSpec dataSpec2 = dataSpec;
        loop0: while (true) {
            if (priorityTaskManager != null) {
                priorityTaskManager.proceed(priority);
            }
            try {
                throwExceptionIfInterruptedOrCancelled(isCanceled);
                dataSpec2 = new DataSpec(dataSpec2.uri, dataSpec2.httpMethod, dataSpec2.httpBody, absoluteStreamPosition, (dataSpec2.position + absoluteStreamPosition) - dataSpec2.absoluteStreamPosition, -1L, dataSpec2.key, dataSpec2.flags);
                long resolvedLength = dataSource.open(dataSpec2);
                if (counters.contentLength == -1 && resolvedLength != -1) {
                    counters.contentLength = dataSpec2.absoluteStreamPosition + resolvedLength;
                }
                totalRead = 0;
                while (true) {
                    if (totalRead == length) {
                        break loop0;
                    }
                    throwExceptionIfInterruptedOrCancelled(isCanceled);
                    int read = dataSource.read(buffer, 0, length != -1 ? (int) Math.min(buffer.length, length - totalRead) : buffer.length);
                    if (read == -1) {
                        break;
                    }
                    totalRead += read;
                    counters.newlyCachedBytes += read;
                }
            } catch (PriorityTaskManager.PriorityTooLowException e) {
            } finally {
                Util.closeQuietly(dataSource);
            }
        }
        return totalRead;
    }

    public static void remove(DataSpec dataSpec, Cache cache, CacheKeyFactory cacheKeyFactory) {
        remove(cache, buildCacheKey(dataSpec, cacheKeyFactory));
    }

    public static void remove(Cache cache, String key) {
        NavigableSet<CacheSpan> cachedSpans = cache.getCachedSpans(key);
        for (CacheSpan cachedSpan : cachedSpans) {
            try {
                cache.removeSpan(cachedSpan);
            } catch (Cache.CacheException e) {
            }
        }
    }

    private static String buildCacheKey(DataSpec dataSpec, CacheKeyFactory cacheKeyFactory) {
        return (cacheKeyFactory != null ? cacheKeyFactory : DEFAULT_CACHE_KEY_FACTORY).buildCacheKey(dataSpec);
    }

    private static void throwExceptionIfInterruptedOrCancelled(AtomicBoolean isCanceled) throws InterruptedException {
        if (Thread.interrupted() || (isCanceled != null && isCanceled.get())) {
            throw new InterruptedException();
        }
    }

    private CacheUtil() {
    }
}
