package com.google.mlkit.vision.common.internal;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Matrix;
import android.graphics.Rect;
import android.graphics.YuvImage;
import android.media.Image;
import android.os.Build;
import android.util.Log;
import com.google.android.exoplayer2.extractor.ts.TsExtractor;
import com.google.android.gms.common.internal.Preconditions;
import com.google.mlkit.common.MlKitException;
import com.google.mlkit.vision.common.InputImage;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
/* compiled from: com.google.mlkit:vision-common@@17.3.0 */
/* loaded from: classes19.dex */
public class ImageConvertUtils {
    private static final ImageConvertUtils zza = new ImageConvertUtils();

    private ImageConvertUtils() {
    }

    public static ByteBuffer bufferWithBackingArray(ByteBuffer byteBuffer) {
        if (byteBuffer.hasArray()) {
            return byteBuffer;
        }
        byteBuffer.rewind();
        byte[] bArr = new byte[byteBuffer.limit()];
        byteBuffer.get(bArr);
        return ByteBuffer.wrap(bArr);
    }

    public static ImageConvertUtils getInstance() {
        return zza;
    }

    public static Bitmap yv12ToBitmap(ByteBuffer buffer, int width, int height, int rotationDegrees) throws MlKitException {
        byte[] zzb = zzb(yv12ToNv21Buffer(buffer, true).array(), width, height);
        Bitmap decodeByteArray = BitmapFactory.decodeByteArray(zzb, 0, zzb.length);
        return zza(decodeByteArray, rotationDegrees, decodeByteArray.getWidth(), decodeByteArray.getHeight());
    }

    public static ByteBuffer yv12ToNv21Buffer(ByteBuffer yv12Buffer, boolean requestBackingArray) {
        ByteBuffer allocateDirect;
        int i;
        yv12Buffer.rewind();
        int limit = yv12Buffer.limit();
        int i2 = limit / 6;
        if (requestBackingArray) {
            allocateDirect = ByteBuffer.allocate(limit);
        } else {
            allocateDirect = ByteBuffer.allocateDirect(limit);
        }
        int i3 = 0;
        while (true) {
            i = i2 * 4;
            if (i3 >= i) {
                break;
            }
            allocateDirect.put(i3, yv12Buffer.get(i3));
            i3++;
        }
        for (int i4 = 0; i4 < i2 + i2; i4++) {
            allocateDirect.put(i + i4, yv12Buffer.get(((i4 % 2) * i2) + i + (i4 / 2)));
        }
        return allocateDirect;
    }

    public static Bitmap zza(Bitmap bitmap, int i, int i2, int i3) {
        if (i == 0) {
            return Bitmap.createBitmap(bitmap, 0, 0, i2, i3);
        }
        Matrix matrix = new Matrix();
        matrix.postRotate(i);
        return Bitmap.createBitmap(bitmap, 0, 0, i2, i3, matrix, true);
    }

    private static byte[] zzb(byte[] bArr, int i, int i2) throws MlKitException {
        YuvImage yuvImage = new YuvImage(bArr, 17, i, i2, null);
        try {
            ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
            yuvImage.compressToJpeg(new Rect(0, 0, i, i2), 100, byteArrayOutputStream);
            byte[] byteArray = byteArrayOutputStream.toByteArray();
            byteArrayOutputStream.close();
            return byteArray;
        } catch (IOException e) {
            Log.w("ImageConvertUtils", "Error closing ByteArrayOutputStream");
            throw new MlKitException("Image conversion error from NV21 format", 13, e);
        }
    }

    private static final void zzc(Image.Plane plane, int i, int i2, byte[] bArr, int i3, int i4) {
        ByteBuffer buffer = plane.getBuffer();
        buffer.rewind();
        int limit = ((buffer.limit() + plane.getRowStride()) - 1) / plane.getRowStride();
        if (limit == 0) {
            return;
        }
        int i5 = i / (i2 / limit);
        int i6 = 0;
        for (int i7 = 0; i7 < limit; i7++) {
            int i8 = i6;
            for (int i9 = 0; i9 < i5; i9++) {
                bArr[i3] = buffer.get(i8);
                i3 += i4;
                i8 += plane.getPixelStride();
            }
            i6 += plane.getRowStride();
        }
    }

    public byte[] byteBufferToByteArray(ByteBuffer byteBuffer) {
        if (!byteBuffer.hasArray() || byteBuffer.arrayOffset() != 0) {
            byteBuffer.rewind();
            int limit = byteBuffer.limit();
            byte[] bArr = new byte[limit];
            byteBuffer.get(bArr, 0, limit);
            return bArr;
        }
        return byteBuffer.array();
    }

    public ByteBuffer cloneByteBuffer(ByteBuffer byteBuffer) {
        Preconditions.checkNotNull(byteBuffer);
        int capacity = byteBuffer.capacity();
        int position = byteBuffer.position();
        ByteBuffer allocateDirect = byteBuffer.isDirect() ? ByteBuffer.allocateDirect(capacity) : ByteBuffer.allocate(capacity);
        allocateDirect.limit(byteBuffer.limit());
        allocateDirect.put((ByteBuffer) byteBuffer.rewind());
        allocateDirect.position(position);
        byteBuffer.position(position);
        return allocateDirect;
    }

    public Bitmap convertJpegToUpRightBitmap(Image image, int rotationDegrees) {
        Preconditions.checkArgument(image.getFormat() == 256, "Only JPEG is supported now");
        Image.Plane[] planes = image.getPlanes();
        if (planes == null || planes.length != 1) {
            throw new IllegalArgumentException("Unexpected image format, JPEG should have exactly 1 image plane");
        }
        ByteBuffer buffer = planes[0].getBuffer();
        buffer.rewind();
        int remaining = buffer.remaining();
        byte[] bArr = new byte[remaining];
        buffer.get(bArr);
        Bitmap decodeByteArray = BitmapFactory.decodeByteArray(bArr, 0, remaining);
        return zza(decodeByteArray, rotationDegrees, decodeByteArray.getWidth(), decodeByteArray.getHeight());
    }

    public ByteBuffer convertToNv21Buffer(InputImage inputImage, boolean requestBackingArray) throws MlKitException {
        Bitmap bitmap;
        ByteBuffer allocateDirect;
        switch (inputImage.getFormat()) {
            case -1:
                Bitmap bitmap2 = (Bitmap) Preconditions.checkNotNull(inputImage.getBitmapInternal());
                if (Build.VERSION.SDK_INT >= 26 && bitmap2.getConfig() == Bitmap.Config.HARDWARE) {
                    bitmap = bitmap2.copy(Bitmap.Config.ARGB_8888, bitmap2.isMutable());
                } else {
                    bitmap = bitmap2;
                }
                int width = bitmap.getWidth();
                int height = bitmap.getHeight();
                int i = width * height;
                int[] iArr = new int[i];
                bitmap.getPixels(iArr, 0, width, 0, 0, width, height);
                int ceil = (int) Math.ceil(height / 2.0d);
                int ceil2 = ((ceil + ceil) * ((int) Math.ceil(width / 2.0d))) + i;
                if (requestBackingArray) {
                    allocateDirect = ByteBuffer.allocate(ceil2);
                } else {
                    allocateDirect = ByteBuffer.allocateDirect(ceil2);
                }
                int i2 = 0;
                int i3 = 0;
                for (int i4 = 0; i4 < height; i4++) {
                    int i5 = 0;
                    while (i5 < width) {
                        int i6 = iArr[i3];
                        int i7 = i6 >> 16;
                        int i8 = i6 >> 8;
                        int i9 = i6 & 255;
                        int i10 = i2 + 1;
                        int i11 = i7 & 255;
                        int i12 = i8 & 255;
                        allocateDirect.put(i2, (byte) Math.min(255, (((((i11 * 66) + (i12 * TsExtractor.TS_STREAM_TYPE_AC3)) + (i9 * 25)) + 128) >> 8) + 16));
                        if (i4 % 2 == 0 && i3 % 2 == 0) {
                            int i13 = i11 * 112;
                            int i14 = i + 1;
                            allocateDirect.put(i, (byte) Math.min(255, ((((i13 - (i12 * 94)) - (i9 * 18)) + 128) >> 8) + 128));
                            i = i14 + 1;
                            allocateDirect.put(i14, (byte) Math.min(255, (((((i11 * (-38)) - (i12 * 74)) + (i9 * 112)) + 128) >> 8) + 128));
                        }
                        i3++;
                        i5++;
                        i2 = i10;
                    }
                }
                return allocateDirect;
            case 17:
                if (requestBackingArray) {
                    return bufferWithBackingArray((ByteBuffer) Preconditions.checkNotNull(inputImage.getByteBuffer()));
                }
                return (ByteBuffer) Preconditions.checkNotNull(inputImage.getByteBuffer());
            case 35:
                return yuv420ThreePlanesToNV21((Image.Plane[]) Preconditions.checkNotNull(inputImage.getPlanes()), inputImage.getWidth(), inputImage.getHeight());
            case InputImage.IMAGE_FORMAT_YV12 /* 842094169 */:
                return yv12ToNv21Buffer((ByteBuffer) Preconditions.checkNotNull(inputImage.getByteBuffer()), requestBackingArray);
            default:
                throw new MlKitException("Unsupported image format", 13);
        }
    }

    public Bitmap convertToUpRightBitmap(InputImage inputImage) throws MlKitException {
        switch (inputImage.getFormat()) {
            case -1:
                return zza((Bitmap) Preconditions.checkNotNull(inputImage.getBitmapInternal()), inputImage.getRotationDegrees(), inputImage.getWidth(), inputImage.getHeight());
            case 17:
                return nv21ToBitmap((ByteBuffer) Preconditions.checkNotNull(inputImage.getByteBuffer()), inputImage.getWidth(), inputImage.getHeight(), inputImage.getRotationDegrees());
            case 35:
                return nv21ToBitmap(yuv420ThreePlanesToNV21((Image.Plane[]) Preconditions.checkNotNull(inputImage.getPlanes()), inputImage.getWidth(), inputImage.getHeight()), inputImage.getWidth(), inputImage.getHeight(), inputImage.getRotationDegrees());
            case InputImage.IMAGE_FORMAT_YV12 /* 842094169 */:
                return yv12ToBitmap((ByteBuffer) Preconditions.checkNotNull(inputImage.getByteBuffer()), inputImage.getWidth(), inputImage.getHeight(), inputImage.getRotationDegrees());
            default:
                throw new MlKitException("Unsupported image format", 13);
        }
    }

    public Bitmap getUpRightBitmap(InputImage inputImage) throws MlKitException {
        Bitmap bitmapInternal = inputImage.getBitmapInternal();
        if (bitmapInternal != null) {
            return zza(bitmapInternal, inputImage.getRotationDegrees(), inputImage.getWidth(), inputImage.getHeight());
        }
        return convertToUpRightBitmap(inputImage);
    }

    public Bitmap nv21ToBitmap(ByteBuffer buffer, int width, int height, int rotationDegrees) throws MlKitException {
        byte[] zzb = zzb(byteBufferToByteArray(buffer), width, height);
        Bitmap decodeByteArray = BitmapFactory.decodeByteArray(zzb, 0, zzb.length);
        return zza(decodeByteArray, rotationDegrees, decodeByteArray.getWidth(), decodeByteArray.getHeight());
    }

    public ByteBuffer yuv420ThreePlanesToNV21(Image.Plane[] yuv420888planes, int width, int height) {
        int i = width * height;
        int i2 = i / 4;
        byte[] bArr = new byte[i2 + i2 + i];
        ByteBuffer buffer = yuv420888planes[1].getBuffer();
        ByteBuffer buffer2 = yuv420888planes[2].getBuffer();
        int position = buffer2.position();
        int limit = buffer.limit();
        buffer2.position(position + 1);
        buffer.limit(limit - 1);
        int i3 = (i + i) / 4;
        boolean z = buffer2.remaining() == i3 + (-2) && buffer2.compareTo(buffer) == 0;
        buffer2.position(position);
        buffer.limit(limit);
        if (z) {
            yuv420888planes[0].getBuffer().get(bArr, 0, i);
            ByteBuffer buffer3 = yuv420888planes[1].getBuffer();
            yuv420888planes[2].getBuffer().get(bArr, i, 1);
            buffer3.get(bArr, i + 1, i3 - 1);
        } else {
            zzc(yuv420888planes[0], width, height, bArr, 0, 1);
            zzc(yuv420888planes[1], width, height, bArr, i + 1, 2);
            zzc(yuv420888planes[2], width, height, bArr, i, 2);
        }
        return ByteBuffer.wrap(bArr);
    }
}
