package com.google.mlkit.vision.common.internal;

import android.content.ContentResolver;
import android.graphics.Bitmap;
import android.graphics.Matrix;
import android.media.Image;
import android.net.Uri;
import android.provider.MediaStore;
import androidx.exifinterface.media.ExifInterface;
import com.google.android.gms.common.internal.GmsLogger;
import com.google.android.gms.common.internal.Preconditions;
import com.google.android.gms.dynamic.IObjectWrapper;
import com.google.android.gms.dynamic.ObjectWrapper;
import com.google.mlkit.common.MlKitException;
import com.google.mlkit.vision.common.InputImage;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;
import java.nio.ByteBuffer;
/* compiled from: com.google.mlkit:vision-common@@17.3.0 */
/* loaded from: classes19.dex */
public class ImageUtils {
    private static final GmsLogger zza = new GmsLogger("MLKitImageUtils", "");
    private static final ImageUtils zzb = new ImageUtils();

    private ImageUtils() {
    }

    public static ImageUtils getInstance() {
        return zzb;
    }

    public IObjectWrapper getImageDataWrapper(InputImage inputImage) throws MlKitException {
        switch (inputImage.getFormat()) {
            case -1:
                return ObjectWrapper.wrap((Bitmap) Preconditions.checkNotNull(inputImage.getBitmapInternal()));
            case 17:
            case InputImage.IMAGE_FORMAT_YV12 /* 842094169 */:
                return ObjectWrapper.wrap((ByteBuffer) Preconditions.checkNotNull(inputImage.getByteBuffer()));
            case 35:
                return ObjectWrapper.wrap(inputImage.getMediaImage());
            default:
                int format = inputImage.getFormat();
                throw new MlKitException("Unsupported image format: " + format, 3);
        }
    }

    public int getMobileVisionImageFormat(InputImage input) {
        return input.getFormat();
    }

    public int getMobileVisionImageSize(InputImage input) {
        if (input.getFormat() == -1) {
            return ((Bitmap) Preconditions.checkNotNull(input.getBitmapInternal())).getAllocationByteCount();
        }
        if (input.getFormat() == 17 || input.getFormat() == 842094169) {
            return ((ByteBuffer) Preconditions.checkNotNull(input.getByteBuffer())).limit();
        }
        if (input.getFormat() != 35) {
            return 0;
        }
        return (((Image.Plane[]) Preconditions.checkNotNull(input.getPlanes()))[0].getBuffer().limit() * 3) / 2;
    }

    public Matrix getUprightRotationMatrix(int width, int height, int rotation) {
        if (rotation == 0) {
            return null;
        }
        Matrix matrix = new Matrix();
        matrix.postTranslate((-width) / 2.0f, (-height) / 2.0f);
        matrix.postRotate(rotation * 90);
        int i = rotation % 2;
        int i2 = i != 0 ? height : width;
        if (i == 0) {
            width = height;
        }
        matrix.postTranslate(i2 / 2.0f, width / 2.0f);
        return matrix;
    }

    /* JADX WARN: Removed duplicated region for block: B:33:0x006e  */
    /* JADX WARN: Removed duplicated region for block: B:34:0x006f A[Catch: FileNotFoundException -> 0x00da, TryCatch #5 {FileNotFoundException -> 0x00da, blocks: (B:3:0x0002, B:5:0x0008, B:7:0x0016, B:35:0x0075, B:36:0x008a, B:47:0x00c1, B:49:0x00cb, B:38:0x008f, B:39:0x0094, B:40:0x009c, B:41:0x00a1, B:42:0x00a9, B:43:0x00ae, B:45:0x00b6, B:34:0x006f, B:31:0x0059, B:52:0x00d2, B:53:0x00d9), top: B:61:0x0002 }] */
    /* JADX WARN: Removed duplicated region for block: B:37:0x008d  */
    /* JADX WARN: Removed duplicated region for block: B:38:0x008f A[Catch: FileNotFoundException -> 0x00da, TryCatch #5 {FileNotFoundException -> 0x00da, blocks: (B:3:0x0002, B:5:0x0008, B:7:0x0016, B:35:0x0075, B:36:0x008a, B:47:0x00c1, B:49:0x00cb, B:38:0x008f, B:39:0x0094, B:40:0x009c, B:41:0x00a1, B:42:0x00a9, B:43:0x00ae, B:45:0x00b6, B:34:0x006f, B:31:0x0059, B:52:0x00d2, B:53:0x00d9), top: B:61:0x0002 }] */
    /* JADX WARN: Removed duplicated region for block: B:39:0x0094 A[Catch: FileNotFoundException -> 0x00da, TryCatch #5 {FileNotFoundException -> 0x00da, blocks: (B:3:0x0002, B:5:0x0008, B:7:0x0016, B:35:0x0075, B:36:0x008a, B:47:0x00c1, B:49:0x00cb, B:38:0x008f, B:39:0x0094, B:40:0x009c, B:41:0x00a1, B:42:0x00a9, B:43:0x00ae, B:45:0x00b6, B:34:0x006f, B:31:0x0059, B:52:0x00d2, B:53:0x00d9), top: B:61:0x0002 }] */
    /* JADX WARN: Removed duplicated region for block: B:40:0x009c A[Catch: FileNotFoundException -> 0x00da, TryCatch #5 {FileNotFoundException -> 0x00da, blocks: (B:3:0x0002, B:5:0x0008, B:7:0x0016, B:35:0x0075, B:36:0x008a, B:47:0x00c1, B:49:0x00cb, B:38:0x008f, B:39:0x0094, B:40:0x009c, B:41:0x00a1, B:42:0x00a9, B:43:0x00ae, B:45:0x00b6, B:34:0x006f, B:31:0x0059, B:52:0x00d2, B:53:0x00d9), top: B:61:0x0002 }] */
    /* JADX WARN: Removed duplicated region for block: B:41:0x00a1 A[Catch: FileNotFoundException -> 0x00da, TryCatch #5 {FileNotFoundException -> 0x00da, blocks: (B:3:0x0002, B:5:0x0008, B:7:0x0016, B:35:0x0075, B:36:0x008a, B:47:0x00c1, B:49:0x00cb, B:38:0x008f, B:39:0x0094, B:40:0x009c, B:41:0x00a1, B:42:0x00a9, B:43:0x00ae, B:45:0x00b6, B:34:0x006f, B:31:0x0059, B:52:0x00d2, B:53:0x00d9), top: B:61:0x0002 }] */
    /* JADX WARN: Removed duplicated region for block: B:42:0x00a9 A[Catch: FileNotFoundException -> 0x00da, TryCatch #5 {FileNotFoundException -> 0x00da, blocks: (B:3:0x0002, B:5:0x0008, B:7:0x0016, B:35:0x0075, B:36:0x008a, B:47:0x00c1, B:49:0x00cb, B:38:0x008f, B:39:0x0094, B:40:0x009c, B:41:0x00a1, B:42:0x00a9, B:43:0x00ae, B:45:0x00b6, B:34:0x006f, B:31:0x0059, B:52:0x00d2, B:53:0x00d9), top: B:61:0x0002 }] */
    /* JADX WARN: Removed duplicated region for block: B:43:0x00ae A[Catch: FileNotFoundException -> 0x00da, TryCatch #5 {FileNotFoundException -> 0x00da, blocks: (B:3:0x0002, B:5:0x0008, B:7:0x0016, B:35:0x0075, B:36:0x008a, B:47:0x00c1, B:49:0x00cb, B:38:0x008f, B:39:0x0094, B:40:0x009c, B:41:0x00a1, B:42:0x00a9, B:43:0x00ae, B:45:0x00b6, B:34:0x006f, B:31:0x0059, B:52:0x00d2, B:53:0x00d9), top: B:61:0x0002 }] */
    /* JADX WARN: Removed duplicated region for block: B:45:0x00b6 A[Catch: FileNotFoundException -> 0x00da, TryCatch #5 {FileNotFoundException -> 0x00da, blocks: (B:3:0x0002, B:5:0x0008, B:7:0x0016, B:35:0x0075, B:36:0x008a, B:47:0x00c1, B:49:0x00cb, B:38:0x008f, B:39:0x0094, B:40:0x009c, B:41:0x00a1, B:42:0x00a9, B:43:0x00ae, B:45:0x00b6, B:34:0x006f, B:31:0x0059, B:52:0x00d2, B:53:0x00d9), top: B:61:0x0002 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    public final Bitmap zza(ContentResolver contentResolver, Uri uri) throws IOException {
        ExifInterface exifInterface;
        Matrix matrix;
        Bitmap createBitmap;
        try {
            Bitmap bitmap = MediaStore.Images.Media.getBitmap(contentResolver, uri);
            if (bitmap == null) {
                throw new IOException("The image Uri could not be resolved.");
            }
            int i = 0;
            if ("content".equals(uri.getScheme()) || "file".equals(uri.getScheme())) {
                try {
                    InputStream openInputStream = contentResolver.openInputStream(uri);
                    exifInterface = openInputStream != null ? new ExifInterface(openInputStream) : null;
                    if (openInputStream != null) {
                        try {
                            openInputStream.close();
                        } catch (IOException e) {
                            e = e;
                            zza.e("MLKitImageUtils", "failed to open file to read rotation meta data: ".concat(String.valueOf(String.valueOf(uri))), e);
                            if (exifInterface == null) {
                            }
                            Matrix matrix2 = new Matrix();
                            int width = bitmap.getWidth();
                            int height = bitmap.getHeight();
                            switch (i) {
                            }
                            return matrix == null ? bitmap : bitmap;
                        }
                    }
                } catch (IOException e2) {
                    e = e2;
                    exifInterface = null;
                }
                if (exifInterface == null) {
                    i = exifInterface.getAttributeInt(ExifInterface.TAG_ORIENTATION, 1);
                }
            }
            Matrix matrix22 = new Matrix();
            int width2 = bitmap.getWidth();
            int height2 = bitmap.getHeight();
            switch (i) {
                case 2:
                    Matrix matrix3 = new Matrix();
                    matrix3.postScale(-1.0f, 1.0f);
                    matrix = matrix3;
                    break;
                case 3:
                    matrix22.postRotate(180.0f);
                    matrix = matrix22;
                    break;
                case 4:
                    matrix22.postScale(1.0f, -1.0f);
                    matrix = matrix22;
                    break;
                case 5:
                    matrix22.postRotate(90.0f);
                    matrix22.postScale(-1.0f, 1.0f);
                    matrix = matrix22;
                    break;
                case 6:
                    matrix22.postRotate(90.0f);
                    matrix = matrix22;
                    break;
                case 7:
                    matrix22.postRotate(-90.0f);
                    matrix22.postScale(-1.0f, 1.0f);
                    matrix = matrix22;
                    break;
                case 8:
                    matrix22.postRotate(-90.0f);
                    matrix = matrix22;
                    break;
                default:
                    matrix = null;
                    break;
            }
            if (matrix == null && bitmap != (createBitmap = Bitmap.createBitmap(bitmap, 0, 0, width2, height2, matrix, true))) {
                bitmap.recycle();
                return createBitmap;
            }
        } catch (FileNotFoundException e3) {
            zza.e("MLKitImageUtils", "Could not open file: ".concat(String.valueOf(String.valueOf(uri))), e3);
            throw e3;
        }
    }
}
