package com.qiniu.android.dns;

import com.qiniu.android.dns.http.DomainNotOwn;
import com.qiniu.android.dns.local.Hosts;
import com.qiniu.android.dns.util.LruCache;
import java.io.IOException;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.ArrayList;
import java.util.Date;
import java.util.TimeZone;
import java.util.concurrent.atomic.AtomicInteger;
/* loaded from: classes2.dex */
public final class DnsManager {
    private final LruCache<String, Record[]> cache;
    private final Hosts hosts;
    private volatile int index;
    private volatile NetworkInfo info;
    public QueryErrorHandler queryErrorHandler;
    private final IResolver[] resolvers;
    private final RecordSorter sorter;

    /* loaded from: classes2.dex */
    public interface QueryErrorHandler {
        void queryError(Exception exc, String str);
    }

    public DnsManager(NetworkInfo info, IResolver[] resolvers) {
        this(info, resolvers, null);
    }

    public DnsManager(NetworkInfo info, IResolver[] resolvers, RecordSorter sorter) {
        this.hosts = new Hosts();
        this.info = null;
        this.index = 0;
        this.info = info == null ? NetworkInfo.normal : info;
        this.resolvers = (IResolver[]) resolvers.clone();
        this.cache = new LruCache<>();
        this.sorter = sorter == null ? new DummySorter() : sorter;
    }

    private static Record[] trimCname(Record[] records) {
        ArrayList<Record> a2 = new ArrayList<>(records.length);
        for (Record r : records) {
            if (r != null && (r.isA() || r.isAAAA())) {
                a2.add(r);
            }
        }
        return (Record[]) a2.toArray(new Record[a2.size()]);
    }

    private static String[] records2Ip(Record[] records) {
        if (records == null || records.length == 0) {
            return null;
        }
        ArrayList<String> a2 = new ArrayList<>(records.length);
        for (Record r : records) {
            a2.add(r.value);
        }
        if (a2.size() == 0) {
            return null;
        }
        return (String[]) a2.toArray(new String[a2.size()]);
    }

    private static Record[] filterInvalidRecords(Record[] records) {
        if (records == null || records.length == 0) {
            return null;
        }
        ArrayList<Record> ret = new ArrayList<>(records.length);
        for (Record r : records) {
            if (r != null && r.value != null && r.value.length() > 0 && !r.isExpired()) {
                ret.add(r);
            }
        }
        if (ret.size() == 0) {
            return null;
        }
        return (Record[]) ret.toArray(new Record[ret.size()]);
    }

    public static boolean validIP(String ip) {
        if (ip == null || ip.length() < 7 || ip.length() > 15 || ip.contains("-")) {
            return false;
        }
        try {
            int y = ip.indexOf(46);
            if (y != -1 && Integer.parseInt(ip.substring(0, y)) > 255) {
                return false;
            }
            int y2 = y + 1;
            int x = ip.indexOf(46, y2);
            if (x != -1 && Integer.parseInt(ip.substring(y2, x)) > 255) {
                return false;
            }
            int x2 = x + 1;
            int y3 = ip.indexOf(46, x2);
            if (y3 != -1 && Integer.parseInt(ip.substring(x2, y3)) > 255 && Integer.parseInt(ip.substring(y3 + 1, ip.length() - 1)) > 255) {
                if (ip.charAt(ip.length() - 1) != '.') {
                    return false;
                }
            }
            return true;
        } catch (NumberFormatException e) {
            return false;
        }
    }

    public static boolean needHttpDns() {
        try {
            TimeZone zone = TimeZone.getDefault();
            String id = zone.getID();
            if (!"Asia/Shanghai".equals(id) && !"Asia/Chongqing".equals(id) && !"Asia/Harbin".equals(id)) {
                if (!"Asia/Urumqi".equals(id)) {
                    return false;
                }
            }
            return true;
        } catch (Exception e) {
            return false;
        }
    }

    public Record[] queryRecords(String domain) throws IOException {
        return queryRecords(new Domain(domain));
    }

    public Record[] queryRecords(Domain domain) throws IOException {
        if (domain == null) {
            throw new IOException("null domain");
        }
        if (domain.domain == null || domain.domain.trim().length() == 0) {
            throw new IOException("empty domain " + domain.domain);
        }
        if (validIP(domain.domain)) {
            Record record = new Record(domain.domain, 1, -1, new Date().getTime(), 0);
            return new Record[]{record};
        }
        Record[] records = queryRecordInternal(domain);
        return this.sorter.sort(records);
    }

    /* JADX WARN: Code restructure failed: missing block: B:68:0x00ca, code lost:
        if (r0.length != 0) goto L38;
     */
    /* JADX WARN: Code restructure failed: missing block: B:70:0x00cd, code lost:
        r0 = trimCname(r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:71:0x00d2, code lost:
        if (r0.length == 0) goto L50;
     */
    /* JADX WARN: Code restructure failed: missing block: B:72:0x00d4, code lost:
        r2 = r12.cache;
     */
    /* JADX WARN: Code restructure failed: missing block: B:73:0x00d6, code lost:
        monitor-enter(r2);
     */
    /* JADX WARN: Code restructure failed: missing block: B:74:0x00d7, code lost:
        r12.cache.put(r13.domain, r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:75:0x00de, code lost:
        monitor-exit(r2);
     */
    /* JADX WARN: Code restructure failed: missing block: B:76:0x00df, code lost:
        return r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:81:0x00ea, code lost:
        throw new java.net.UnknownHostException("no A/AAAA records");
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private Record[] queryRecordInternal(Domain domain) throws IOException {
        Record[] rs;
        Record[] ret;
        if (domain.hostsFirst && (ret = filterInvalidRecords(this.hosts.query(domain, this.info))) != null && ret.length > 0) {
            return ret;
        }
        synchronized (this.cache) {
            if (this.info.equals(NetworkInfo.normal) && Network.isNetworkChanged()) {
                this.cache.clear();
                synchronized (this.resolvers) {
                    this.index = 0;
                }
            } else {
                Record[] records = filterInvalidRecords(this.cache.get(domain.domain));
                if (records != null && records.length > 0) {
                    return records;
                }
            }
            Record[] records2 = null;
            IOException lastE = null;
            int firstOk = this.index;
            int i = 0;
            while (true) {
                IResolver[] iResolverArr = this.resolvers;
                if (i >= iResolverArr.length) {
                    break;
                }
                int pos = (firstOk + i) % iResolverArr.length;
                NetworkInfo before = this.info;
                String ip = Network.getIp();
                try {
                    records2 = this.resolvers[pos].resolve(domain, this.info);
                } catch (DomainNotOwn e) {
                } catch (IOException e2) {
                    lastE = e2;
                    e2.printStackTrace();
                    QueryErrorHandler queryErrorHandler = this.queryErrorHandler;
                    if (queryErrorHandler != null) {
                        queryErrorHandler.queryError(e2, domain.domain);
                    }
                } catch (Exception e22) {
                    lastE = new IOException(e22);
                    e22.printStackTrace();
                    QueryErrorHandler queryErrorHandler2 = this.queryErrorHandler;
                    if (queryErrorHandler2 != null) {
                        queryErrorHandler2.queryError(e22, domain.domain);
                    }
                }
                String ip2 = Network.getIp();
                if (this.info != before || ((records2 != null && records2.length != 0) || !ip.equals(ip2))) {
                    break;
                }
                synchronized (this.resolvers) {
                    if (this.index == firstOk) {
                        this.index++;
                        if (this.index == this.resolvers.length) {
                            this.index = 0;
                        }
                    }
                }
                i++;
            }
            if (!domain.hostsFirst && (rs = filterInvalidRecords(this.hosts.query(domain, this.info))) != null && rs.length != 0) {
                return rs;
            }
            if (lastE != null) {
                throw lastE;
            }
            IOException e3 = new UnknownHostException(domain.domain);
            QueryErrorHandler queryErrorHandler3 = this.queryErrorHandler;
            if (queryErrorHandler3 != null) {
                queryErrorHandler3.queryError(e3, domain.domain);
            }
            throw e3;
        }
    }

    public InetAddress[] queryInetAdress(Domain domain) throws IOException {
        Record[] records = queryRecords(domain);
        String[] ips = records2Ip(records);
        if (ips == null || ips.length == 0) {
            return null;
        }
        InetAddress[] addresses = new InetAddress[ips.length];
        for (int i = 0; i < ips.length; i++) {
            addresses[i] = InetAddress.getByName(ips[i]);
        }
        return addresses;
    }

    public void onNetworkChange(NetworkInfo info) {
        clearCache();
        this.info = info == null ? NetworkInfo.normal : info;
        synchronized (this.resolvers) {
            this.index = 0;
        }
    }

    private void clearCache() {
        synchronized (this.cache) {
            this.cache.clear();
        }
    }

    public DnsManager putHosts(String domain, Record record, int provider) {
        Record recordNew = new Record(record.value, record.type, record.ttl, record.timeStamp, 1, record.server);
        this.hosts.put(domain, new Hosts.Value(recordNew, provider));
        return this;
    }

    public DnsManager putHosts(String domain, int type, String ip, int provider) {
        putHosts(domain, new Record(ip, type, -1, new Date().getTime() / 1000, 1), provider);
        return this;
    }

    public DnsManager putHosts(String domain, int type, String ip) {
        putHosts(domain, type, ip, 0);
        return this;
    }

    public DnsManager putHosts(String domain, String ipv4) {
        putHosts(domain, 1, ipv4);
        return this;
    }

    /* loaded from: classes2.dex */
    private static class DummySorter implements RecordSorter {
        private AtomicInteger pos;

        private DummySorter() {
            this.pos = new AtomicInteger();
        }

        @Override // com.qiniu.android.dns.RecordSorter
        public Record[] sort(Record[] records) {
            return records;
        }
    }
}
