package com.qiniu.android.dns.dns;

import com.qiniu.android.dns.Domain;
import com.qiniu.android.dns.IResolver;
import com.qiniu.android.dns.NetworkInfo;
import com.qiniu.android.dns.Record;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Queue;
import java.util.concurrent.Callable;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.Future;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.TimeUnit;
/* loaded from: classes2.dex */
public abstract class DnsResolver implements IResolver {
    private final ExecutorService executorService;
    private final int recordType;
    private final String[] servers;
    protected final int timeout;
    private static ScheduledExecutorService timeoutExecutorService = Executors.newSingleThreadScheduledExecutor();
    private static ExecutorService defaultExecutorService = Executors.newFixedThreadPool(4);

    abstract DnsResponse request(RequestCanceller requestCanceller, String str, String str2, int i) throws IOException;

    public DnsResolver(String server) {
        this(server, 1, 10);
    }

    public DnsResolver(String server, int timeout) {
        this(server, 1, timeout);
    }

    public DnsResolver(String server, int recordType, int timeout) {
        this(server == null ? null : new String[]{server}, recordType, timeout, null);
    }

    public DnsResolver(String[] servers, int recordType, int timeout) {
        this.recordType = recordType;
        this.timeout = timeout > 0 ? timeout : 10;
        this.servers = servers;
        this.executorService = null;
    }

    public DnsResolver(String[] servers, int recordType, int timeout, ExecutorService executorService) {
        if (servers != null && servers.length > 1 && executorService == null) {
            executorService = defaultExecutorService;
        }
        this.recordType = recordType;
        this.timeout = timeout > 0 ? timeout : 10;
        this.servers = servers;
        this.executorService = executorService;
    }

    @Override // com.qiniu.android.dns.IResolver
    public Record[] resolve(Domain domain, NetworkInfo info) throws IOException {
        DnsResponse response = lookupHost(domain.domain);
        if (response == null) {
            throw new IOException("response is null");
        }
        List<Record> answers = response.getAnswerArray();
        if (answers == null || answers.size() == 0) {
            return null;
        }
        List<Record> records = new ArrayList<>();
        for (Record record : answers) {
            if (record.isA() || record.isCname() || record.isAAAA() || record.type == this.recordType) {
                records.add(record);
            }
        }
        return (Record[]) records.toArray(new Record[0]);
    }

    private DnsResponse lookupHost(String host) throws IOException {
        return request(host, this.recordType);
    }

    private DnsResponse request(final String host, final int recordType) throws IOException {
        String[] strArr = this.servers;
        if (strArr == null || strArr.length == 0) {
            throw new IOException("server can not empty");
        }
        if (host == null || host.length() == 0) {
            throw new IOException("host can not empty");
        }
        final RequestCanceller canceller = new RequestCanceller();
        String[] strArr2 = this.servers;
        if (strArr2.length == 1 || this.executorService == null) {
            DnsResponse response = null;
            for (String server : strArr2) {
                response = request(canceller, server, host, recordType);
                if (response != null) {
                    break;
                }
            }
            return response;
        }
        final ResponseComposition responseComposition = new ResponseComposition();
        timeoutExecutorService.schedule(new Callable<Object>() { // from class: com.qiniu.android.dns.dns.DnsResolver.1
            @Override // java.util.concurrent.Callable
            public Object call() throws Exception {
                synchronized (responseComposition) {
                    responseComposition.notify();
                    responseComposition.exception = new IOException("resolver timeout for server:" + DnsResolver.this.servers + " host:" + host);
                }
                return null;
            }
        }, this.timeout, TimeUnit.SECONDS);
        List<Future<?>> futures = new ArrayList<>();
        String[] strArr3 = this.servers;
        int i = 0;
        for (int length = strArr3.length; i < length; length = length) {
            final String server2 = strArr3[i];
            String[] strArr4 = strArr3;
            Future<?> future = this.executorService.submit(new Runnable() { // from class: com.qiniu.android.dns.dns.DnsResolver.2
                @Override // java.lang.Runnable
                public void run() {
                    DnsResponse response2 = null;
                    IOException exception = null;
                    try {
                        response2 = DnsResolver.this.request(canceller, server2, host, recordType);
                    } catch (Exception e) {
                        e.printStackTrace();
                        exception = new IOException(e);
                    }
                    synchronized (responseComposition) {
                        responseComposition.completedCount++;
                        if (responseComposition.response == null) {
                            responseComposition.response = response2;
                        }
                        if (responseComposition.exception == null) {
                            responseComposition.exception = exception;
                        }
                        if (responseComposition.completedCount == DnsResolver.this.servers.length || responseComposition.response != null) {
                            responseComposition.notify();
                        }
                    }
                }
            });
            futures.add(future);
            i++;
            strArr3 = strArr4;
        }
        synchronized (responseComposition) {
            try {
                responseComposition.wait();
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
        canceller.cancel();
        if (responseComposition.exception != null && responseComposition.response == null) {
            throw responseComposition.exception;
        }
        return responseComposition.response;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes2.dex */
    public static class ResponseComposition {
        int completedCount = 0;
        IOException exception;
        DnsResponse response;

        ResponseComposition() {
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes2.dex */
    public static class RequestCanceller {
        Queue<Runnable> cancelActions = new ConcurrentLinkedQueue();

        RequestCanceller() {
        }

        /* JADX INFO: Access modifiers changed from: package-private */
        public void addCancelAction(Runnable cancelAction) {
            if (cancelAction != null) {
                this.cancelActions.add(cancelAction);
            }
        }

        void cancel() {
            for (Runnable cancelAction : this.cancelActions) {
                if (cancelAction != null) {
                    cancelAction.run();
                }
            }
        }
    }
}
