package com.qiniu.android.dns.dns;

import com.google.android.exoplayer2.extractor.ts.PsExtractor;
import com.king.zxing.util.LogUtils;
import com.qiniu.android.dns.Record;
import java.io.IOException;
import java.net.IDN;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import kotlin.UByte;
/* loaded from: classes2.dex */
class DnsResponse extends DnsMessage {
    private int aa;
    private List<Record> additionalArray;
    private List<Record> answerArray;
    private List<Record> authorityArray;
    private int rCode;
    private byte[] recordData;
    private DnsRequest request;
    private String server;
    private int source;
    private long timestamp;

    /* JADX INFO: Access modifiers changed from: package-private */
    public DnsResponse(String server, int source, DnsRequest request, byte[] recordData) throws IOException {
        if (recordData == null || recordData.length == 0) {
            throw new IOException("response data is empty");
        }
        this.server = server;
        this.source = source;
        this.request = request;
        this.recordData = recordData;
        this.timestamp = new Date().getTime() / 1000;
        parse();
    }

    private void parse() throws IOException {
        if (this.recordData.length < 12) {
            throw new IOException("response data too small");
        }
        parseHeader();
        int index = parseQuestion();
        RecordResource answer = new RecordResource("answer", readRecordDataInt16(6), index);
        parseResourceRecord(answer);
        this.answerArray = answer.records;
        int index2 = index + answer.length;
        RecordResource authority = new RecordResource("authority", readRecordDataInt16(8), index2);
        parseResourceRecord(authority);
        this.authorityArray = authority.records;
        RecordResource additional = new RecordResource("additional", readRecordDataInt16(10), index2 + authority.length);
        parseResourceRecord(additional);
        this.additionalArray = additional.records;
    }

    private void parseHeader() throws IOException {
        this.messageId = readRecordDataInt16(0);
        if (this.messageId != this.request.messageId) {
            throw new IOException("question id error");
        }
        int field0 = readRecordDataInt8(2);
        int qr = readRecordDataInt8(2) & 128;
        if (qr == 0) {
            throw new IOException("not a response data");
        }
        this.opCode = (field0 >> 3) & 7;
        this.aa = (field0 >> 2) & 1;
        this.rd = field0 & 1;
        int field1 = readRecordDataInt8(3);
        this.ra = (field1 >> 7) & 1;
        this.rCode = field1 & 15;
    }

    private int parseQuestion() throws IOException {
        int index = 12;
        for (int qdCount = readRecordDataInt16(4); qdCount > 0; qdCount--) {
            RecordName recordName = getNameFrom(index);
            if (recordName != null) {
                index += recordName.skipLength + 4;
            } else {
                throw new IOException("read Question error");
            }
        }
        return index;
    }

    private void parseResourceRecord(RecordResource resource) throws IOException {
        int rdLength;
        int index = resource.from;
        for (int count = resource.count; count > 0; count--) {
            RecordName recordName = getNameFrom(index);
            if (recordName == null) {
                throw new IOException("read " + resource.name + " error");
            }
            int index2 = index + recordName.skipLength;
            int type = readRecordDataInt16(index2);
            int index3 = index2 + 2;
            int clazz = readRecordDataInt16(index3);
            int index4 = index3 + 2;
            int ttl = readRecordDataInt32(index4);
            int index5 = index4 + 4;
            int rdLength2 = readRecordDataInt16(index5);
            int index6 = index5 + 2;
            String value = readData(type, index6, rdLength2);
            if (clazz == 1) {
                if (type == 5 || type == this.request.getRecordType()) {
                    rdLength = rdLength2;
                    Record record = new Record(value, type, ttl, this.timestamp, this.source, this.server);
                    resource.addRecord(record);
                } else {
                    rdLength = rdLength2;
                }
            } else {
                rdLength = rdLength2;
            }
            index = index6 + rdLength;
        }
        resource.length = index - resource.from;
    }

    private RecordName getNameFrom(int from) throws IOException {
        int index = from;
        StringBuilder name = new StringBuilder();
        RecordName recordName = new RecordName();
        int maxLoop = 128;
        do {
            int partLength = readRecordDataInt8(index);
            if ((partLength & PsExtractor.AUDIO_STREAM) != 192) {
                if ((partLength & PsExtractor.AUDIO_STREAM) > 0) {
                    return null;
                }
                index++;
                if (partLength > 0) {
                    if (name.length() > 0) {
                        name.append(".");
                    }
                    byte[] nameData = Arrays.copyOfRange(this.recordData, index, index + partLength);
                    name.append(IDN.toUnicode(new String(nameData)));
                    index += partLength;
                }
            } else {
                if (recordName.skipLength < 1) {
                    recordName.skipLength = (index + 2) - from;
                }
                index = ((partLength & 63) << 8) | readRecordDataInt8(index + 1);
            }
            if (partLength <= 0) {
                break;
            }
            maxLoop--;
        } while (maxLoop > 0);
        recordName.name = name.toString();
        if (recordName.skipLength < 1) {
            recordName.skipLength = index - from;
        }
        return recordName;
    }

    private String readData(int recordType, int from, int length) throws IOException {
        switch (recordType) {
            case 1:
                if (length != 4) {
                    return null;
                }
                StringBuilder builder = new StringBuilder();
                builder.append(readRecordDataInt8(from));
                for (int i = 1; i < 4; i++) {
                    builder.append(".");
                    builder.append(readRecordDataInt8(from + i));
                }
                String dataString = builder.toString();
                return dataString;
            case 5:
                if (length <= 1) {
                    return null;
                }
                RecordName name = getNameFrom(from);
                String dataString2 = name.name;
                return dataString2;
            case 16:
                if (length > 0) {
                    int i2 = from + length;
                    byte[] bArr = this.recordData;
                    if (i2 >= bArr.length) {
                        return null;
                    }
                    byte[] data = Arrays.copyOfRange(bArr, from, from + length);
                    String dataValue = new String(data);
                    String dataString3 = IDN.toUnicode(dataValue);
                    return dataString3;
                }
                return null;
            case 28:
                if (length != 16) {
                    return null;
                }
                StringBuilder builder2 = new StringBuilder();
                int i3 = 0;
                while (i3 < 16) {
                    builder2.append(i3 > 0 ? LogUtils.COLON : "");
                    builder2.append(readRecordDataInt8(from + i3));
                    builder2.append(readRecordDataInt8(from + i3 + 1));
                    i3 += 2;
                }
                String dataString4 = builder2.toString();
                return dataString4;
            default:
                return null;
        }
    }

    private int readRecordDataInt8(int from) throws IOException {
        byte[] bArr = this.recordData;
        if (from >= bArr.length) {
            throw new IOException("read response data out of range");
        }
        return bArr[from] & UByte.MAX_VALUE;
    }

    private short readRecordDataInt16(int from) throws IOException {
        int i = from + 1;
        byte[] bArr = this.recordData;
        if (i >= bArr.length) {
            throw new IOException("read response data out of range");
        }
        int b0 = (bArr[from] & UByte.MAX_VALUE) << 8;
        int b1 = bArr[from + 1] & UByte.MAX_VALUE;
        return (short) (b0 + b1);
    }

    private int readRecordDataInt32(int from) throws IOException {
        int i = from + 3;
        byte[] bArr = this.recordData;
        if (i >= bArr.length) {
            throw new IOException("read response data out of range");
        }
        int b0 = (bArr[from] & UByte.MAX_VALUE) << 24;
        int b1 = (bArr[from + 1] & UByte.MAX_VALUE) << 16;
        int b2 = (bArr[from + 2] & UByte.MAX_VALUE) << 8;
        int b3 = bArr[from + 3] & UByte.MAX_VALUE;
        return b0 + b1 + b2 + b3;
    }

    int getAA() {
        return this.aa;
    }

    int getRCode() {
        return this.rCode;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public List<Record> getAnswerArray() {
        return this.answerArray;
    }

    List<Record> getAdditionalArray() {
        return this.additionalArray;
    }

    List<Record> getAuthorityArray() {
        return this.authorityArray;
    }

    public String toString() {
        return String.format(Locale.getDefault(), "{messageId:%d, rd:%d, ra:%d, aa:%d, rCode:%d, server:%s, request:%s, answerArray:%s, authorityArray:%s, additionalArray:%s}", Short.valueOf(this.messageId), Integer.valueOf(this.rd), Integer.valueOf(this.ra), Integer.valueOf(this.aa), Integer.valueOf(this.rCode), this.server, this.request, this.answerArray, this.authorityArray, this.additionalArray);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes2.dex */
    public static class RecordResource {
        private final int count;
        private final int from;
        private int length;
        private final String name;
        private final List<Record> records;

        private RecordResource(String name, int count, int from) {
            this.name = name;
            this.count = count;
            this.from = from;
            this.length = 0;
            this.records = new ArrayList();
        }

        /* JADX INFO: Access modifiers changed from: private */
        public void addRecord(Record record) {
            if (record != null) {
                this.records.add(record);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes2.dex */
    public static class RecordName {
        private String name;
        private int skipLength;

        private RecordName() {
        }
    }
}
