package com.qiniu.android.dns.local;

import android.content.Context;
import android.net.ConnectivityManager;
import android.net.LinkProperties;
import android.net.Network;
import android.net.NetworkRequest;
import com.qiniu.android.dns.Domain;
import com.qiniu.android.dns.IResolver;
import com.qiniu.android.dns.NetworkInfo;
import com.qiniu.android.dns.Record;
import com.qiniu.android.dns.dns.DnsUdpResolver;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.LineNumberReader;
import java.lang.reflect.Method;
import java.net.InetAddress;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
/* loaded from: classes2.dex */
public final class AndroidDnsServer {

    /* loaded from: classes2.dex */
    static class AndroidResolver implements IResolver {
        private List<InetAddress> dnsServers = new ArrayList();
        private boolean networkCallback = false;

        AndroidResolver(Context context) {
            List<InetAddress> addresses = AndroidDnsServer.getByReflection();
            addresses = addresses == null ? AndroidDnsServer.getByCommand() : addresses;
            if (addresses == null) {
                ConnectivityManager connectivityManager = (ConnectivityManager) context.getSystemService("connectivity");
                NetworkRequest.Builder builder = new NetworkRequest.Builder();
                if (connectivityManager != null) {
                    try {
                        connectivityManager.registerNetworkCallback(builder.build(), new ConnectivityManager.NetworkCallback() { // from class: com.qiniu.android.dns.local.AndroidDnsServer.AndroidResolver.1
                            @Override // android.net.ConnectivityManager.NetworkCallback
                            public void onLinkPropertiesChanged(Network network, LinkProperties linkProperties) {
                                if (linkProperties != null) {
                                    AndroidResolver.this.dnsServers.addAll(linkProperties.getDnsServers());
                                }
                                AndroidResolver.this.networkCallback = true;
                            }
                        });
                        return;
                    } catch (Exception e) {
                        e.printStackTrace();
                        return;
                    }
                }
                return;
            }
            this.dnsServers.addAll(addresses);
        }

        @Override // com.qiniu.android.dns.IResolver
        public Record[] resolve(Domain domain, NetworkInfo info) throws IOException {
            if (this.dnsServers.isEmpty() && !this.networkCallback) {
                try {
                    Thread.sleep(1000L);
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
            List<InetAddress> list = this.dnsServers;
            if (list == null || list.isEmpty()) {
                throw new IOException("cant get local dns server");
            }
            InetAddress dnsServer = this.dnsServers.get(0);
            IResolver resolver = new HijackingDetectWrapper(new DnsUdpResolver(dnsServer.getHostName()));
            Record[] records = resolver.resolve(domain, info);
            if (domain.hasCname) {
                boolean cname = false;
                int length = records.length;
                int i = 0;
                while (true) {
                    if (i < length) {
                        if (!records[i].isCname()) {
                            i++;
                        } else {
                            cname = true;
                            break;
                        }
                    } else {
                        break;
                    }
                }
                if (!cname) {
                    throw new DnshijackingException(domain.domain, dnsServer.getHostAddress());
                }
            }
            if (domain.maxTtl != 0) {
                for (Record r : records) {
                    if (!r.isCname() && r.ttl > domain.maxTtl) {
                        throw new DnshijackingException(domain.domain, dnsServer.getHostAddress(), r.ttl);
                    }
                }
            }
            return records;
        }
    }

    public static List<InetAddress> getByCommand() {
        String value;
        try {
            Process process = Runtime.getRuntime().exec("getprop");
            InputStream inputStream = process.getInputStream();
            LineNumberReader lnr = new LineNumberReader(new InputStreamReader(inputStream));
            ArrayList<InetAddress> servers = new ArrayList<>(5);
            while (true) {
                String line = lnr.readLine();
                if (line == null) {
                    break;
                }
                int split = line.indexOf("]: [");
                if (split > 1 && line.length() - 1 > split + 4) {
                    String property = line.substring(1, split);
                    String value2 = line.substring(split + 4, line.length() - 1);
                    if (property.endsWith(".dns") || property.endsWith(".dns1") || property.endsWith(".dns2") || property.endsWith(".dns3") || property.endsWith(".dns4")) {
                        InetAddress ip = InetAddress.getByName(value2);
                        if (ip != null && (value = ip.getHostAddress()) != null && value.length() != 0) {
                            servers.add(ip);
                        }
                    }
                }
            }
            if (servers.size() > 0) {
                return servers;
            }
            return null;
        } catch (IOException e) {
            Logger.getLogger("AndroidDnsServer").log(Level.WARNING, "Exception in findDNSByExec", (Throwable) e);
            return null;
        }
    }

    public static List<InetAddress> getByReflection() {
        ArrayList<InetAddress> servers;
        InetAddress ip;
        String value;
        try {
            Class<?> SystemProperties = Class.forName("android.os.SystemProperties");
            Method method = SystemProperties.getMethod("get", String.class);
            servers = new ArrayList<>(5);
            String[] strArr = {"net.dns1", "net.dns2", "net.dns3", "net.dns4"};
            for (int i = 0; i < 4; i++) {
                String propKey = strArr[i];
                String value2 = (String) method.invoke(null, propKey);
                if (value2 != null && value2.length() != 0 && (ip = InetAddress.getByName(value2)) != null && (value = ip.getHostAddress()) != null && value.length() != 0 && !servers.contains(ip)) {
                    servers.add(ip);
                }
            }
        } catch (Exception e) {
            Logger.getLogger("AndroidDnsServer").log(Level.WARNING, "Exception in findDNSByReflection", (Throwable) e);
        }
        if (servers.size() <= 0) {
            return null;
        }
        return servers;
    }

    public static IResolver defaultResolver(Context context) {
        return new AndroidResolver(context);
    }
}
