package com.serenegiant.usb;

import android.content.Context;
import android.content.res.Resources;
import android.hardware.usb.UsbDevice;
import android.hardware.usb.UsbInterface;
import android.text.TextUtils;
import android.util.Log;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
/* loaded from: classes19.dex */
public final class DeviceFilter {
    private static final String TAG = "DeviceFilter";
    public final boolean isExclude;
    public final int mClass;
    public final String mManufacturerName;
    public final int mProductId;
    public final String mProductName;
    public final int mProtocol;
    public final String mSerialNumber;
    public final int mSubclass;
    public final int mVendorId;

    public DeviceFilter(int vid, int pid, int clasz, int subclass, int protocol, String manufacturer, String product, String serialNum) {
        this(vid, pid, clasz, subclass, protocol, manufacturer, product, serialNum, false);
    }

    public DeviceFilter(int vid, int pid, int clasz, int subclass, int protocol, String manufacturer, String product, String serialNum, boolean isExclude) {
        this.mVendorId = vid;
        this.mProductId = pid;
        this.mClass = clasz;
        this.mSubclass = subclass;
        this.mProtocol = protocol;
        this.mManufacturerName = manufacturer;
        this.mProductName = product;
        this.mSerialNumber = serialNum;
        this.isExclude = isExclude;
    }

    public DeviceFilter(UsbDevice device) {
        this(device, false);
    }

    public DeviceFilter(UsbDevice device, boolean isExclude) {
        this.mVendorId = device.getVendorId();
        this.mProductId = device.getProductId();
        this.mClass = device.getDeviceClass();
        this.mSubclass = device.getDeviceSubclass();
        this.mProtocol = device.getDeviceProtocol();
        this.mManufacturerName = null;
        this.mProductName = null;
        this.mSerialNumber = null;
        this.isExclude = isExclude;
    }

    public static List<DeviceFilter> getDeviceFilters(Context context, int deviceFilterXmlId) {
        XmlPullParser parser = context.getResources().getXml(deviceFilterXmlId);
        List<DeviceFilter> deviceFilters = new ArrayList<>();
        try {
            for (int eventType = parser.getEventType(); eventType != 1; eventType = parser.next()) {
                if (eventType == 2) {
                    DeviceFilter deviceFilter = readEntryOne(context, parser);
                    if (deviceFilter != null) {
                        deviceFilters.add(deviceFilter);
                    }
                }
            }
        } catch (IOException e) {
            Log.d(TAG, "IOException", e);
        } catch (XmlPullParserException e2) {
            Log.d(TAG, "XmlPullParserException", e2);
        }
        return Collections.unmodifiableList(deviceFilters);
    }

    private static final int getAttributeInteger(Context context, XmlPullParser parser, String namespace, String name, int defaultValue) {
        int result = defaultValue;
        try {
            String v = parser.getAttributeValue(namespace, name);
            if (!TextUtils.isEmpty(v) && v.startsWith("@")) {
                String r = v.substring(1);
                int resId = context.getResources().getIdentifier(r, null, context.getPackageName());
                if (resId > 0) {
                    result = context.getResources().getInteger(resId);
                }
                return result;
            }
            int radix = 10;
            if (v != null && v.length() > 2 && v.charAt(0) == '0' && (v.charAt(1) == 'x' || v.charAt(1) == 'X')) {
                radix = 16;
                v = v.substring(2);
            }
            int result2 = Integer.parseInt(v, radix);
            return result2;
        } catch (Resources.NotFoundException e) {
            return defaultValue;
        } catch (NullPointerException e2) {
            return defaultValue;
        } catch (NumberFormatException e3) {
            return defaultValue;
        }
    }

    private static final boolean getAttributeBoolean(Context context, XmlPullParser parser, String namespace, String name, boolean defaultValue) {
        boolean result = defaultValue;
        try {
            String v = parser.getAttributeValue(namespace, name);
            if ("TRUE".equalsIgnoreCase(v)) {
                return true;
            }
            if ("FALSE".equalsIgnoreCase(v)) {
                return false;
            }
            if (!TextUtils.isEmpty(v) && v.startsWith("@")) {
                String r = v.substring(1);
                int resId = context.getResources().getIdentifier(r, null, context.getPackageName());
                if (resId > 0) {
                    result = context.getResources().getBoolean(resId);
                }
                return result;
            }
            int radix = 10;
            if (v != null && v.length() > 2 && v.charAt(0) == '0' && (v.charAt(1) == 'x' || v.charAt(1) == 'X')) {
                radix = 16;
                v = v.substring(2);
            }
            int val = Integer.parseInt(v, radix);
            boolean result2 = val != 0;
            return result2;
        } catch (Resources.NotFoundException e) {
            return defaultValue;
        } catch (NullPointerException e2) {
            return defaultValue;
        } catch (NumberFormatException e3) {
            return defaultValue;
        }
    }

    private static final String getAttributeString(Context context, XmlPullParser parser, String namespace, String name, String defaultValue) {
        try {
            String result = parser.getAttributeValue(namespace, name);
            if (result == null) {
                result = defaultValue;
            }
            if (!TextUtils.isEmpty(result) && result.startsWith("@")) {
                String r = result.substring(1);
                int resId = context.getResources().getIdentifier(r, null, context.getPackageName());
                if (resId > 0) {
                    return context.getResources().getString(resId);
                }
                return result;
            }
            return result;
        } catch (Resources.NotFoundException e) {
            return defaultValue;
        } catch (NullPointerException e2) {
            return defaultValue;
        } catch (NumberFormatException e3) {
            return defaultValue;
        }
    }

    public static DeviceFilter readEntryOne(Context context, XmlPullParser parser) throws XmlPullParserException, IOException {
        int vendorId = -1;
        int productId = -1;
        int deviceClass = -1;
        int deviceSubclass = -1;
        int deviceProtocol = -1;
        boolean exclude = false;
        String manufacturerName = null;
        String productName = null;
        String serialNumber = null;
        boolean hasValue = false;
        int eventType = parser.getEventType();
        while (eventType != 1) {
            String tag = parser.getName();
            if (!TextUtils.isEmpty(tag) && tag.equalsIgnoreCase("usb-device")) {
                if (eventType == 2) {
                    vendorId = getAttributeInteger(context, parser, null, "vendor-id", -1);
                    if (vendorId == -1 && (vendorId = getAttributeInteger(context, parser, null, "vendorId", -1)) == -1) {
                        vendorId = getAttributeInteger(context, parser, null, "venderId", -1);
                    }
                    productId = getAttributeInteger(context, parser, null, "product-id", -1);
                    if (productId == -1) {
                        productId = getAttributeInteger(context, parser, null, "productId", -1);
                    }
                    deviceClass = getAttributeInteger(context, parser, null, "class", -1);
                    deviceSubclass = getAttributeInteger(context, parser, null, "subclass", -1);
                    deviceProtocol = getAttributeInteger(context, parser, null, "protocol", -1);
                    manufacturerName = getAttributeString(context, parser, null, "manufacturer-name", null);
                    if (TextUtils.isEmpty(manufacturerName)) {
                        manufacturerName = getAttributeString(context, parser, null, "manufacture", null);
                    }
                    productName = getAttributeString(context, parser, null, "product-name", null);
                    if (TextUtils.isEmpty(productName)) {
                        productName = getAttributeString(context, parser, null, "product", null);
                    }
                    serialNumber = getAttributeString(context, parser, null, "serial-number", null);
                    if (TextUtils.isEmpty(serialNumber)) {
                        serialNumber = getAttributeString(context, parser, null, "serial", null);
                    }
                    exclude = getAttributeBoolean(context, parser, null, "exclude", false);
                    hasValue = true;
                } else if (eventType == 3 && hasValue) {
                    return new DeviceFilter(vendorId, productId, deviceClass, deviceSubclass, deviceProtocol, manufacturerName, productName, serialNumber, exclude);
                }
            }
            eventType = parser.next();
        }
        return null;
    }

    private boolean matches(int clasz, int subclass, int protocol) {
        int i;
        int i2;
        int i3 = this.mClass;
        return (i3 == -1 || clasz == i3) && ((i = this.mSubclass) == -1 || subclass == i) && ((i2 = this.mProtocol) == -1 || protocol == i2);
    }

    public boolean matches(UsbDevice device) {
        if (this.mVendorId == -1 || device.getVendorId() == this.mVendorId) {
            if (this.mProductId == -1 || device.getProductId() == this.mProductId) {
                if (matches(device.getDeviceClass(), device.getDeviceSubclass(), device.getDeviceProtocol())) {
                    return true;
                }
                int count = device.getInterfaceCount();
                for (int i = 0; i < count; i++) {
                    UsbInterface intf = device.getInterface(i);
                    if (matches(intf.getInterfaceClass(), intf.getInterfaceSubclass(), intf.getInterfaceProtocol())) {
                        return true;
                    }
                }
                return false;
            }
            return false;
        }
        return false;
    }

    public boolean isExclude(UsbDevice device) {
        return this.isExclude && matches(device);
    }

    public boolean matches(DeviceFilter f) {
        String str;
        String str2;
        if (this.isExclude != f.isExclude) {
            return false;
        }
        int i = this.mVendorId;
        if (i == -1 || f.mVendorId == i) {
            int i2 = this.mProductId;
            if (i2 == -1 || f.mProductId == i2) {
                String str3 = f.mManufacturerName;
                if (str3 == null || this.mManufacturerName != null) {
                    if (f.mProductName == null || this.mProductName != null) {
                        if (f.mSerialNumber == null || this.mSerialNumber != null) {
                            String str4 = this.mManufacturerName;
                            if (str4 == null || str3 == null || str4.equals(str3)) {
                                String str5 = this.mProductName;
                                if (str5 == null || (str2 = f.mProductName) == null || str5.equals(str2)) {
                                    String str6 = this.mSerialNumber;
                                    if (str6 == null || (str = f.mSerialNumber) == null || str6.equals(str)) {
                                        return matches(f.mClass, f.mSubclass, f.mProtocol);
                                    }
                                    return false;
                                }
                                return false;
                            }
                            return false;
                        }
                        return false;
                    }
                    return false;
                }
                return false;
            }
            return false;
        }
        return false;
    }

    public boolean equals(Object obj) {
        int i;
        int i2;
        int i3;
        int i4;
        String str;
        String str2;
        String str3;
        String str4;
        String str5;
        String str6;
        String str7;
        int i5 = this.mVendorId;
        if (i5 == -1 || (i = this.mProductId) == -1 || (i2 = this.mClass) == -1 || (i3 = this.mSubclass) == -1 || (i4 = this.mProtocol) == -1) {
            return false;
        }
        if (obj instanceof DeviceFilter) {
            DeviceFilter filter = (DeviceFilter) obj;
            if (filter.mVendorId == i5 && filter.mProductId == i && filter.mClass == i2 && filter.mSubclass == i3 && filter.mProtocol == i4) {
                String str8 = filter.mManufacturerName;
                if ((str8 == null || this.mManufacturerName != null) && ((str8 != null || this.mManufacturerName == null) && (((str = filter.mProductName) == null || this.mProductName != null) && ((str != null || this.mProductName == null) && (((str2 = filter.mSerialNumber) == null || this.mSerialNumber != null) && (str2 != null || this.mSerialNumber == null)))))) {
                    return (str8 == null || (str7 = this.mManufacturerName) == null || str7.equals(str8)) && ((str3 = filter.mProductName) == null || (str6 = this.mProductName) == null || str6.equals(str3)) && (((str4 = filter.mSerialNumber) == null || (str5 = this.mSerialNumber) == null || str5.equals(str4)) && filter.isExclude != this.isExclude);
                }
                return false;
            }
            return false;
        } else if (obj instanceof UsbDevice) {
            UsbDevice device = (UsbDevice) obj;
            return !this.isExclude && device.getVendorId() == this.mVendorId && device.getProductId() == this.mProductId && device.getDeviceClass() == this.mClass && device.getDeviceSubclass() == this.mSubclass && device.getDeviceProtocol() == this.mProtocol;
        } else {
            return false;
        }
    }

    public int hashCode() {
        return ((this.mVendorId << 16) | this.mProductId) ^ (((this.mClass << 16) | (this.mSubclass << 8)) | this.mProtocol);
    }

    public String toString() {
        return "DeviceFilter[mVendorId=" + this.mVendorId + ",mProductId=" + this.mProductId + ",mClass=" + this.mClass + ",mSubclass=" + this.mSubclass + ",mProtocol=" + this.mProtocol + ",mManufacturerName=" + this.mManufacturerName + ",mProductName=" + this.mProductName + ",mSerialNumber=" + this.mSerialNumber + ",isExclude=" + this.isExclude + "]";
    }
}
