package io.reactivex.internal.operators.flowable;

import com.google.android.gms.common.api.internal.zap$$ExternalSyntheticBackportWithForwarding0;
import io.reactivex.Flowable;
import io.reactivex.FlowableSubscriber;
import io.reactivex.disposables.Disposable;
import io.reactivex.exceptions.Exceptions;
import io.reactivex.exceptions.MissingBackpressureException;
import io.reactivex.functions.Function;
import io.reactivex.internal.functions.ObjectHelper;
import io.reactivex.internal.fuseable.QueueSubscription;
import io.reactivex.internal.fuseable.SimplePlainQueue;
import io.reactivex.internal.fuseable.SimpleQueue;
import io.reactivex.internal.queue.SpscArrayQueue;
import io.reactivex.internal.queue.SpscLinkedArrayQueue;
import io.reactivex.internal.subscriptions.SubscriptionHelper;
import io.reactivex.internal.util.AtomicThrowable;
import io.reactivex.internal.util.BackpressureHelper;
import io.reactivex.internal.util.ExceptionHelper;
import io.reactivex.plugins.RxJavaPlugins;
import java.util.concurrent.Callable;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicLong;
import java.util.concurrent.atomic.AtomicReference;
import org.reactivestreams.Publisher;
import org.reactivestreams.Subscriber;
import org.reactivestreams.Subscription;
/* loaded from: classes19.dex */
public final class FlowableFlatMap<T, U> extends AbstractFlowableWithUpstream<T, U> {
    final int bufferSize;
    final boolean delayErrors;
    final Function<? super T, ? extends Publisher<? extends U>> mapper;
    final int maxConcurrency;

    public FlowableFlatMap(Flowable<T> source, Function<? super T, ? extends Publisher<? extends U>> mapper, boolean delayErrors, int maxConcurrency, int bufferSize) {
        super(source);
        this.mapper = mapper;
        this.delayErrors = delayErrors;
        this.maxConcurrency = maxConcurrency;
        this.bufferSize = bufferSize;
    }

    @Override // io.reactivex.Flowable
    protected void subscribeActual(Subscriber<? super U> s) {
        if (FlowableScalarXMap.tryScalarXMapSubscribe(this.source, s, this.mapper)) {
            return;
        }
        this.source.subscribe((FlowableSubscriber) subscribe(s, this.mapper, this.delayErrors, this.maxConcurrency, this.bufferSize));
    }

    public static <T, U> FlowableSubscriber<T> subscribe(Subscriber<? super U> s, Function<? super T, ? extends Publisher<? extends U>> mapper, boolean delayErrors, int maxConcurrency, int bufferSize) {
        return new MergeSubscriber(s, mapper, delayErrors, maxConcurrency, bufferSize);
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes19.dex */
    public static final class MergeSubscriber<T, U> extends AtomicInteger implements FlowableSubscriber<T>, Subscription {
        private static final long serialVersionUID = -2117620485640801370L;
        final Subscriber<? super U> actual;
        final int bufferSize;
        volatile boolean cancelled;
        final boolean delayErrors;
        volatile boolean done;
        final AtomicThrowable errs = new AtomicThrowable();
        long lastId;
        int lastIndex;
        final Function<? super T, ? extends Publisher<? extends U>> mapper;
        final int maxConcurrency;
        volatile SimplePlainQueue<U> queue;
        final AtomicLong requested;
        Subscription s;
        int scalarEmitted;
        final int scalarLimit;
        final AtomicReference<InnerSubscriber<?, ?>[]> subscribers;
        long uniqueId;
        static final InnerSubscriber<?, ?>[] EMPTY = new InnerSubscriber[0];
        static final InnerSubscriber<?, ?>[] CANCELLED = new InnerSubscriber[0];

        MergeSubscriber(Subscriber<? super U> actual, Function<? super T, ? extends Publisher<? extends U>> mapper, boolean delayErrors, int maxConcurrency, int bufferSize) {
            AtomicReference<InnerSubscriber<?, ?>[]> atomicReference = new AtomicReference<>();
            this.subscribers = atomicReference;
            this.requested = new AtomicLong();
            this.actual = actual;
            this.mapper = mapper;
            this.delayErrors = delayErrors;
            this.maxConcurrency = maxConcurrency;
            this.bufferSize = bufferSize;
            this.scalarLimit = Math.max(1, maxConcurrency >> 1);
            atomicReference.lazySet(EMPTY);
        }

        @Override // io.reactivex.FlowableSubscriber, org.reactivestreams.Subscriber
        public void onSubscribe(Subscription s) {
            if (SubscriptionHelper.validate(this.s, s)) {
                this.s = s;
                this.actual.onSubscribe(this);
                if (!this.cancelled) {
                    int i = this.maxConcurrency;
                    if (i == Integer.MAX_VALUE) {
                        s.request(Long.MAX_VALUE);
                    } else {
                        s.request(i);
                    }
                }
            }
        }

        /* JADX WARN: Multi-variable type inference failed */
        @Override // org.reactivestreams.Subscriber
        public void onNext(T t) {
            if (this.done) {
                return;
            }
            try {
                Publisher<? extends U> p = (Publisher) ObjectHelper.requireNonNull(this.mapper.apply(t), "The mapper returned a null Publisher");
                if (p instanceof Callable) {
                    try {
                        Object call = ((Callable) p).call();
                        if (call != null) {
                            tryEmitScalar(call);
                            return;
                        } else if (this.maxConcurrency == Integer.MAX_VALUE || this.cancelled) {
                            return;
                        } else {
                            int i = this.scalarEmitted + 1;
                            this.scalarEmitted = i;
                            int i2 = this.scalarLimit;
                            if (i == i2) {
                                this.scalarEmitted = 0;
                                this.s.request(i2);
                                return;
                            }
                            return;
                        }
                    } catch (Throwable ex) {
                        Exceptions.throwIfFatal(ex);
                        this.errs.addThrowable(ex);
                        drain();
                        return;
                    }
                }
                long j = this.uniqueId;
                this.uniqueId = 1 + j;
                InnerSubscriber<T, U> inner = new InnerSubscriber<>(this, j);
                if (addInner(inner)) {
                    p.subscribe(inner);
                }
            } catch (Throwable e) {
                Exceptions.throwIfFatal(e);
                this.s.cancel();
                onError(e);
            }
        }

        boolean addInner(InnerSubscriber<T, U> inner) {
            InnerSubscriber<?, ?>[] a2;
            InnerSubscriber[] innerSubscriberArr;
            do {
                a2 = this.subscribers.get();
                if (a2 == CANCELLED) {
                    inner.dispose();
                    return false;
                }
                int n = a2.length;
                innerSubscriberArr = new InnerSubscriber[n + 1];
                System.arraycopy(a2, 0, innerSubscriberArr, 0, n);
                innerSubscriberArr[n] = inner;
            } while (!zap$$ExternalSyntheticBackportWithForwarding0.m(this.subscribers, a2, innerSubscriberArr));
            return true;
        }

        void removeInner(InnerSubscriber<T, U> inner) {
            InnerSubscriber<?, ?>[] a2;
            InnerSubscriber<?, ?>[] b;
            do {
                a2 = this.subscribers.get();
                if (a2 == CANCELLED || a2 == EMPTY) {
                    return;
                }
                int n = a2.length;
                int j = -1;
                int i = 0;
                while (true) {
                    if (i >= n) {
                        break;
                    } else if (a2[i] != inner) {
                        i++;
                    } else {
                        j = i;
                        break;
                    }
                }
                if (j < 0) {
                    return;
                }
                if (n == 1) {
                    b = EMPTY;
                } else {
                    InnerSubscriber<?, ?>[] b2 = new InnerSubscriber[n - 1];
                    System.arraycopy(a2, 0, b2, 0, j);
                    System.arraycopy(a2, j + 1, b2, j, (n - j) - 1);
                    b = b2;
                }
            } while (!zap$$ExternalSyntheticBackportWithForwarding0.m(this.subscribers, a2, b));
        }

        SimpleQueue<U> getMainQueue() {
            SimplePlainQueue<U> q = this.queue;
            if (q == null) {
                if (this.maxConcurrency == Integer.MAX_VALUE) {
                    q = new SpscLinkedArrayQueue(this.bufferSize);
                } else {
                    q = new SpscArrayQueue<>(this.maxConcurrency);
                }
                this.queue = q;
            }
            return q;
        }

        void tryEmitScalar(U value) {
            if (get() == 0 && compareAndSet(0, 1)) {
                long r = this.requested.get();
                SimpleQueue<U> q = this.queue;
                if (r != 0 && (q == null || q.isEmpty())) {
                    this.actual.onNext(value);
                    if (r != Long.MAX_VALUE) {
                        this.requested.decrementAndGet();
                    }
                    if (this.maxConcurrency != Integer.MAX_VALUE && !this.cancelled) {
                        int i = this.scalarEmitted + 1;
                        this.scalarEmitted = i;
                        int i2 = this.scalarLimit;
                        if (i == i2) {
                            this.scalarEmitted = 0;
                            this.s.request(i2);
                        }
                    }
                } else {
                    if (q == null) {
                        q = getMainQueue();
                    }
                    if (!q.offer(value)) {
                        onError(new IllegalStateException("Scalar queue full?!"));
                        return;
                    }
                }
                if (decrementAndGet() == 0) {
                    return;
                }
            } else if (!getMainQueue().offer(value)) {
                onError(new IllegalStateException("Scalar queue full?!"));
                return;
            } else if (getAndIncrement() != 0) {
                return;
            }
            drainLoop();
        }

        SimpleQueue<U> getInnerQueue(InnerSubscriber<T, U> inner) {
            SimpleQueue<U> q = inner.queue;
            if (q == null) {
                SimpleQueue<U> q2 = new SpscArrayQueue<>(this.bufferSize);
                inner.queue = q2;
                return q2;
            }
            return q;
        }

        void tryEmit(U value, InnerSubscriber<T, U> inner) {
            if (get() == 0 && compareAndSet(0, 1)) {
                long r = this.requested.get();
                SimpleQueue<U> q = inner.queue;
                if (r != 0 && (q == null || q.isEmpty())) {
                    this.actual.onNext(value);
                    if (r != Long.MAX_VALUE) {
                        this.requested.decrementAndGet();
                    }
                    inner.requestMore(1L);
                } else {
                    if (q == null) {
                        q = getInnerQueue(inner);
                    }
                    if (!q.offer(value)) {
                        onError(new MissingBackpressureException("Inner queue full?!"));
                        return;
                    }
                }
                if (decrementAndGet() == 0) {
                    return;
                }
            } else {
                SimpleQueue<U> q2 = inner.queue;
                if (q2 == null) {
                    q2 = new SpscArrayQueue(this.bufferSize);
                    inner.queue = q2;
                }
                if (!q2.offer(value)) {
                    onError(new MissingBackpressureException("Inner queue full?!"));
                    return;
                } else if (getAndIncrement() != 0) {
                    return;
                }
            }
            drainLoop();
        }

        @Override // org.reactivestreams.Subscriber
        public void onError(Throwable t) {
            if (this.done) {
                RxJavaPlugins.onError(t);
            } else if (this.errs.addThrowable(t)) {
                this.done = true;
                drain();
            } else {
                RxJavaPlugins.onError(t);
            }
        }

        @Override // org.reactivestreams.Subscriber
        public void onComplete() {
            if (this.done) {
                return;
            }
            this.done = true;
            drain();
        }

        @Override // org.reactivestreams.Subscription
        public void request(long n) {
            if (SubscriptionHelper.validate(n)) {
                BackpressureHelper.add(this.requested, n);
                drain();
            }
        }

        @Override // org.reactivestreams.Subscription
        public void cancel() {
            SimpleQueue<U> q;
            if (!this.cancelled) {
                this.cancelled = true;
                this.s.cancel();
                disposeAll();
                if (getAndIncrement() == 0 && (q = this.queue) != null) {
                    q.clear();
                }
            }
        }

        void drain() {
            if (getAndIncrement() == 0) {
                drainLoop();
            }
        }

        /* JADX WARN: Code restructure failed: missing block: B:128:0x01f7, code lost:
            r33.lastIndex = r4;
            r33.lastId = r11[r4].id;
         */
        /* JADX WARN: Code restructure failed: missing block: B:32:0x0075, code lost:
            r9 = r19;
         */
        /* JADX WARN: Removed duplicated region for block: B:162:0x01ed A[SYNTHETIC] */
        /* JADX WARN: Removed duplicated region for block: B:69:0x00f7  */
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        void drainLoop() {
            Subscriber<? super U> child;
            boolean innerCompleted;
            long r;
            int i;
            int i2;
            boolean unbounded;
            long startId;
            int i3;
            long r2;
            long replenishMain;
            long scalarEmission;
            Subscriber<? super U> child2 = this.actual;
            int missed = 1;
            while (!checkTerminate()) {
                SimplePlainQueue<U> svq = this.queue;
                long r3 = this.requested.get();
                boolean unbounded2 = r3 == Long.MAX_VALUE;
                long replenishMain2 = 0;
                long j = 1;
                if (svq != null) {
                    while (true) {
                        U u = (U) null;
                        long scalarEmission2 = 0;
                        while (true) {
                            if (r3 == 0) {
                                replenishMain = replenishMain2;
                                scalarEmission = scalarEmission2;
                                break;
                            }
                            U o = svq.poll();
                            u = o;
                            if (checkTerminate()) {
                                return;
                            }
                            if (u == null) {
                                replenishMain = replenishMain2;
                                scalarEmission = scalarEmission2;
                                break;
                            }
                            child2.onNext(u);
                            scalarEmission2 += j;
                            r3 -= j;
                            replenishMain2 += j;
                        }
                        if (scalarEmission != 0) {
                            if (unbounded2) {
                                r3 = Long.MAX_VALUE;
                            } else {
                                r3 = this.requested.addAndGet(-scalarEmission);
                            }
                        }
                        if (r3 == 0 || u == null) {
                            break;
                        }
                        replenishMain2 = replenishMain;
                        j = 1;
                    }
                }
                boolean d = this.done;
                SimplePlainQueue<U> svq2 = this.queue;
                InnerSubscriber<?, ?>[] inner = this.subscribers.get();
                int n = inner.length;
                if (d && ((svq2 == null || svq2.isEmpty()) && n == 0)) {
                    Throwable ex = this.errs.terminate();
                    if (ex != ExceptionHelper.TERMINATED) {
                        if (ex == null) {
                            child2.onComplete();
                            return;
                        } else {
                            child2.onError(ex);
                            return;
                        }
                    }
                    return;
                }
                boolean innerCompleted2 = false;
                if (n != 0) {
                    long produced = this.lastId;
                    int index = this.lastIndex;
                    if (n > index) {
                        innerCompleted = false;
                        r = r3;
                        if (inner[index].id == produced) {
                            int j2 = index;
                            i = 0;
                            int j3 = j2;
                            while (true) {
                                if (i < n) {
                                    child = child2;
                                    innerCompleted2 = innerCompleted;
                                    break;
                                } else if (checkTerminate()) {
                                    return;
                                } else {
                                    InnerSubscriber<T, U> is = inner[j3];
                                    U u2 = null;
                                    while (!checkTerminate()) {
                                        SimpleQueue<U> q = is.queue;
                                        if (q == null) {
                                            child = child2;
                                            i2 = i;
                                            unbounded = unbounded2;
                                            startId = produced;
                                        } else {
                                            startId = produced;
                                            long startId2 = 0;
                                            long r4 = r;
                                            while (true) {
                                                Object obj = u2;
                                                if (r4 == 0) {
                                                    child = child2;
                                                    u2 = (U) obj;
                                                    break;
                                                }
                                                try {
                                                    u2 = q.poll();
                                                    if (u2 == null) {
                                                        child = child2;
                                                        break;
                                                    }
                                                    child2.onNext(u2);
                                                    if (checkTerminate()) {
                                                        return;
                                                    }
                                                    r4--;
                                                    startId2++;
                                                } catch (Throwable ex2) {
                                                    Exceptions.throwIfFatal(ex2);
                                                    is.dispose();
                                                    child = child2;
                                                    this.errs.addThrowable(ex2);
                                                    if (checkTerminate()) {
                                                        return;
                                                    }
                                                    removeInner(is);
                                                    i3 = i + 1;
                                                    innerCompleted = true;
                                                    unbounded = unbounded2;
                                                    r = r4;
                                                }
                                            }
                                            if (startId2 == 0) {
                                                i2 = i;
                                                unbounded = unbounded2;
                                                r = r4;
                                            } else {
                                                if (!unbounded2) {
                                                    i2 = i;
                                                    unbounded = unbounded2;
                                                    r2 = this.requested.addAndGet(-startId2);
                                                } else {
                                                    i2 = i;
                                                    unbounded = unbounded2;
                                                    r2 = Long.MAX_VALUE;
                                                }
                                                is.requestMore(startId2);
                                                r = r2;
                                            }
                                            if (r != 0 && u2 != null) {
                                                produced = startId;
                                                child2 = child;
                                                unbounded2 = unbounded;
                                                i = i2;
                                            }
                                        }
                                        boolean innerDone = is.done;
                                        SimpleQueue<U> innerQueue = is.queue;
                                        if (innerDone && (innerQueue == null || innerQueue.isEmpty())) {
                                            removeInner(is);
                                            if (checkTerminate()) {
                                                return;
                                            }
                                            replenishMain2++;
                                            innerCompleted = true;
                                        }
                                        if (r == 0) {
                                            innerCompleted2 = innerCompleted;
                                            break;
                                        }
                                        j3++;
                                        if (j3 != n) {
                                            i3 = i2;
                                        } else {
                                            j3 = 0;
                                            i3 = i2;
                                        }
                                        i = i3 + 1;
                                        produced = startId;
                                        child2 = child;
                                        unbounded2 = unbounded;
                                    }
                                    return;
                                }
                            }
                        }
                    } else {
                        innerCompleted = false;
                        r = r3;
                    }
                    if (n <= index) {
                        index = 0;
                    }
                    int j4 = index;
                    int i4 = 0;
                    while (i4 < n) {
                        boolean d2 = d;
                        SimplePlainQueue<U> svq3 = svq2;
                        if (inner[j4].id == produced) {
                            break;
                        }
                        j4++;
                        if (j4 == n) {
                            j4 = 0;
                        }
                        i4++;
                        d = d2;
                        svq2 = svq3;
                    }
                    index = j4;
                    this.lastIndex = j4;
                    this.lastId = inner[j4].id;
                    int j22 = index;
                    i = 0;
                    int j32 = j22;
                    while (true) {
                        if (i < n) {
                        }
                        i = i3 + 1;
                        produced = startId;
                        child2 = child;
                        unbounded2 = unbounded;
                    }
                } else {
                    child = child2;
                }
                if (replenishMain2 != 0 && !this.cancelled) {
                    this.s.request(replenishMain2);
                }
                if (!innerCompleted2) {
                    missed = addAndGet(-missed);
                    if (missed != 0) {
                        child2 = child;
                    } else {
                        return;
                    }
                } else {
                    child2 = child;
                }
            }
        }

        boolean checkTerminate() {
            if (this.cancelled) {
                clearScalarQueue();
                return true;
            } else if (!this.delayErrors && this.errs.get() != null) {
                clearScalarQueue();
                Throwable ex = this.errs.terminate();
                if (ex != ExceptionHelper.TERMINATED) {
                    this.actual.onError(ex);
                }
                return true;
            } else {
                return false;
            }
        }

        void clearScalarQueue() {
            SimpleQueue<U> q = this.queue;
            if (q != null) {
                q.clear();
            }
        }

        void disposeAll() {
            InnerSubscriber<?, ?>[] a2 = this.subscribers.get();
            InnerSubscriber<?, ?>[] innerSubscriberArr = CANCELLED;
            if (a2 != innerSubscriberArr) {
                InnerSubscriber<?, ?>[] a3 = this.subscribers.getAndSet(innerSubscriberArr);
                InnerSubscriber<?, ?>[] a4 = a3;
                if (a4 != innerSubscriberArr) {
                    for (InnerSubscriber<?, ?> inner : a4) {
                        inner.dispose();
                    }
                    Throwable ex = this.errs.terminate();
                    if (ex != null && ex != ExceptionHelper.TERMINATED) {
                        RxJavaPlugins.onError(ex);
                    }
                }
            }
        }

        void innerError(InnerSubscriber<T, U> inner, Throwable t) {
            InnerSubscriber<?, ?>[] andSet;
            if (this.errs.addThrowable(t)) {
                inner.done = true;
                if (!this.delayErrors) {
                    this.s.cancel();
                    for (InnerSubscriber<?, ?> a2 : this.subscribers.getAndSet(CANCELLED)) {
                        a2.dispose();
                    }
                }
                drain();
                return;
            }
            RxJavaPlugins.onError(t);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes19.dex */
    public static final class InnerSubscriber<T, U> extends AtomicReference<Subscription> implements FlowableSubscriber<U>, Disposable {
        private static final long serialVersionUID = -4606175640614850599L;
        final int bufferSize;
        volatile boolean done;
        int fusionMode;
        final long id;
        final int limit;
        final MergeSubscriber<T, U> parent;
        long produced;
        volatile SimpleQueue<U> queue;

        InnerSubscriber(MergeSubscriber<T, U> parent, long id) {
            this.id = id;
            this.parent = parent;
            int i = parent.bufferSize;
            this.bufferSize = i;
            this.limit = i >> 2;
        }

        @Override // io.reactivex.FlowableSubscriber, org.reactivestreams.Subscriber
        public void onSubscribe(Subscription s) {
            if (SubscriptionHelper.setOnce(this, s)) {
                if (s instanceof QueueSubscription) {
                    QueueSubscription<U> qs = (QueueSubscription) s;
                    int m = qs.requestFusion(7);
                    if (m == 1) {
                        this.fusionMode = m;
                        this.queue = qs;
                        this.done = true;
                        this.parent.drain();
                        return;
                    } else if (m == 2) {
                        this.fusionMode = m;
                        this.queue = qs;
                    }
                }
                s.request(this.bufferSize);
            }
        }

        @Override // org.reactivestreams.Subscriber
        public void onNext(U t) {
            if (this.fusionMode != 2) {
                this.parent.tryEmit(t, this);
            } else {
                this.parent.drain();
            }
        }

        @Override // org.reactivestreams.Subscriber
        public void onError(Throwable t) {
            lazySet(SubscriptionHelper.CANCELLED);
            this.parent.innerError(this, t);
        }

        @Override // org.reactivestreams.Subscriber
        public void onComplete() {
            this.done = true;
            this.parent.drain();
        }

        void requestMore(long n) {
            if (this.fusionMode != 1) {
                long p = this.produced + n;
                if (p >= this.limit) {
                    this.produced = 0L;
                    get().request(p);
                    return;
                }
                this.produced = p;
            }
        }

        @Override // io.reactivex.disposables.Disposable
        public void dispose() {
            SubscriptionHelper.cancel(this);
        }

        @Override // io.reactivex.disposables.Disposable
        public boolean isDisposed() {
            return get() == SubscriptionHelper.CANCELLED;
        }
    }
}
