package okhttp3.logging;

import java.io.EOFException;
import java.io.IOException;
import java.nio.charset.Charset;
import java.util.concurrent.TimeUnit;
import okhttp3.Connection;
import okhttp3.Headers;
import okhttp3.Interceptor;
import okhttp3.MediaType;
import okhttp3.Request;
import okhttp3.RequestBody;
import okhttp3.Response;
import okhttp3.ResponseBody;
import okhttp3.internal.http.HttpHeaders;
import okhttp3.internal.platform.Platform;
import okio.Buffer;
import okio.BufferedSource;
import okio.GzipSource;
/* loaded from: classes19.dex */
public final class HttpLoggingInterceptor implements Interceptor {
    private static final Charset UTF8 = Charset.forName("UTF-8");
    private volatile Level level;
    private final Logger logger;

    /* loaded from: classes19.dex */
    public enum Level {
        NONE,
        BASIC,
        HEADERS,
        BODY
    }

    /* loaded from: classes19.dex */
    public interface Logger {
        public static final Logger DEFAULT = new Logger() { // from class: okhttp3.logging.HttpLoggingInterceptor.Logger.1
            @Override // okhttp3.logging.HttpLoggingInterceptor.Logger
            public void log(String message) {
                Platform.get().log(4, message, null);
            }
        };

        void log(String str);
    }

    public HttpLoggingInterceptor() {
        this(Logger.DEFAULT);
    }

    public HttpLoggingInterceptor(Logger logger) {
        this.level = Level.NONE;
        this.logger = logger;
    }

    public HttpLoggingInterceptor setLevel(Level level) {
        if (level == null) {
            throw new NullPointerException("level == null. Use Level.NONE instead.");
        }
        this.level = level;
        return this;
    }

    public Level getLevel() {
        return this.level;
    }

    @Override // okhttp3.Interceptor
    public Response intercept(Interceptor.Chain chain) throws IOException {
        String str;
        String requestStartMessage;
        String str2;
        String str3;
        String str4;
        String str5;
        String requestStartMessage2;
        int count;
        Level level = this.level;
        Request request = chain.request();
        if (level == Level.NONE) {
            return chain.proceed(request);
        }
        boolean logBody = level == Level.BODY;
        boolean logHeaders = logBody || level == Level.HEADERS;
        RequestBody requestBody = request.body();
        boolean hasRequestBody = requestBody != null;
        Connection connection = chain.connection();
        String requestStartMessage3 = "--> " + request.method() + ' ' + request.url() + (connection != null ? " " + connection.protocol() : "");
        if (logHeaders || !hasRequestBody) {
            str = "";
            requestStartMessage = requestStartMessage3;
        } else {
            str = "";
            requestStartMessage = requestStartMessage3 + " (" + requestBody.contentLength() + "-byte body)";
        }
        this.logger.log(requestStartMessage);
        if (!logHeaders) {
            str2 = "-byte body)";
            str3 = " (";
            str4 = str;
        } else {
            if (!hasRequestBody) {
                str2 = "-byte body)";
                str5 = " (";
            } else {
                if (requestBody.contentType() != null) {
                    this.logger.log("Content-Type: " + requestBody.contentType());
                }
                if (requestBody.contentLength() != -1) {
                    str2 = "-byte body)";
                    str5 = " (";
                    this.logger.log("Content-Length: " + requestBody.contentLength());
                } else {
                    str2 = "-byte body)";
                    str5 = " (";
                }
            }
            Headers headers = request.headers();
            int i = 0;
            int count2 = headers.size();
            while (i < count2) {
                String name = headers.name(i);
                Connection connection2 = connection;
                if ("Content-Type".equalsIgnoreCase(name) || "Content-Length".equalsIgnoreCase(name)) {
                    requestStartMessage2 = requestStartMessage;
                    count = count2;
                } else {
                    requestStartMessage2 = requestStartMessage;
                    count = count2;
                    this.logger.log(name + ": " + headers.value(i));
                }
                i++;
                connection = connection2;
                requestStartMessage = requestStartMessage2;
                count2 = count;
            }
            if (!logBody) {
                str4 = str;
                str3 = str5;
            } else if (!hasRequestBody) {
                str4 = str;
                str3 = str5;
            } else if (bodyHasUnknownEncoding(request.headers())) {
                this.logger.log("--> END " + request.method() + " (encoded body omitted)");
                str4 = str;
                str3 = str5;
            } else {
                Buffer buffer = new Buffer();
                requestBody.writeTo(buffer);
                Charset charset = UTF8;
                MediaType contentType = requestBody.contentType();
                if (contentType != null) {
                    charset = contentType.charset(UTF8);
                }
                str4 = str;
                this.logger.log(str4);
                if (isPlaintext(buffer)) {
                    this.logger.log(buffer.readString(charset));
                    str3 = str5;
                    this.logger.log("--> END " + request.method() + str3 + requestBody.contentLength() + str2);
                } else {
                    str3 = str5;
                    this.logger.log("--> END " + request.method() + " (binary " + requestBody.contentLength() + "-byte body omitted)");
                }
            }
            this.logger.log("--> END " + request.method());
        }
        long startNs = System.nanoTime();
        try {
            Response response = chain.proceed(request);
            String str6 = str4;
            long tookMs = TimeUnit.NANOSECONDS.toMillis(System.nanoTime() - startNs);
            ResponseBody responseBody = response.body();
            long contentLength = responseBody.contentLength();
            String bodySize = contentLength != -1 ? contentLength + "-byte" : "unknown-length";
            String str7 = str2;
            this.logger.log("<-- " + response.code() + (response.message().isEmpty() ? str6 : ' ' + response.message()) + ' ' + response.request().url() + str3 + tookMs + "ms" + (!logHeaders ? ", " + bodySize + " body" : str6) + ')');
            if (logHeaders) {
                Headers headers2 = response.headers();
                int i2 = 0;
                int count3 = headers2.size();
                while (i2 < count3) {
                    this.logger.log(headers2.name(i2) + ": " + headers2.value(i2));
                    i2++;
                    tookMs = tookMs;
                }
                if (logBody && HttpHeaders.hasBody(response)) {
                    if (bodyHasUnknownEncoding(response.headers())) {
                        this.logger.log("<-- END HTTP (encoded body omitted)");
                    } else {
                        BufferedSource source = responseBody.source();
                        source.request(Long.MAX_VALUE);
                        Buffer buffer2 = source.buffer();
                        Long gzippedLength = null;
                        if ("gzip".equalsIgnoreCase(headers2.get("Content-Encoding"))) {
                            gzippedLength = Long.valueOf(buffer2.size());
                            GzipSource gzippedResponseBody = null;
                            try {
                                gzippedResponseBody = new GzipSource(buffer2.clone());
                                buffer2 = new Buffer();
                                buffer2.writeAll(gzippedResponseBody);
                                gzippedResponseBody.close();
                            } catch (Throwable th) {
                                if (gzippedResponseBody != null) {
                                    gzippedResponseBody.close();
                                }
                                throw th;
                            }
                        }
                        Charset charset2 = UTF8;
                        MediaType contentType2 = responseBody.contentType();
                        if (contentType2 != null) {
                            charset2 = contentType2.charset(UTF8);
                        }
                        if (!isPlaintext(buffer2)) {
                            this.logger.log(str6);
                            this.logger.log("<-- END HTTP (binary " + buffer2.size() + "-byte body omitted)");
                            return response;
                        }
                        if (contentLength != 0) {
                            this.logger.log(str6);
                            this.logger.log(buffer2.clone().readString(charset2));
                        }
                        if (gzippedLength != null) {
                            this.logger.log("<-- END HTTP (" + buffer2.size() + "-byte, " + gzippedLength + "-gzipped-byte body)");
                        } else {
                            this.logger.log("<-- END HTTP (" + buffer2.size() + str7);
                        }
                    }
                }
                this.logger.log("<-- END HTTP");
            }
            return response;
        } catch (Exception e) {
            this.logger.log("<-- HTTP FAILED: " + e);
            throw e;
        }
    }

    static boolean isPlaintext(Buffer buffer) {
        try {
            Buffer prefix = new Buffer();
            long byteCount = buffer.size() < 64 ? buffer.size() : 64L;
            buffer.copyTo(prefix, 0L, byteCount);
            for (int i = 0; i < 16; i++) {
                if (!prefix.exhausted()) {
                    int codePoint = prefix.readUtf8CodePoint();
                    if (Character.isISOControl(codePoint) && !Character.isWhitespace(codePoint)) {
                        return false;
                    }
                } else {
                    return true;
                }
            }
            return true;
        } catch (EOFException e) {
            return false;
        }
    }

    private boolean bodyHasUnknownEncoding(Headers headers) {
        String contentEncoding = headers.get("Content-Encoding");
        return (contentEncoding == null || contentEncoding.equalsIgnoreCase("identity") || contentEncoding.equalsIgnoreCase("gzip")) ? false : true;
    }
}
