package org.webrtc.ali;

import android.graphics.Bitmap;
import android.graphics.SurfaceTexture;
import android.opengl.GLES20;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.view.Surface;
import java.nio.ByteBuffer;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.Locale;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.TimeUnit;
import org.webrtc.ali.EglBase;
import org.webrtc.ali.RendererCommon;
import org.webrtc.ali.VideoRenderer;
/* loaded from: classes19.dex */
public class EglRenderer implements VideoRenderer.Callbacks {
    private static final long LOG_INTERVAL_SEC = 4;
    private static final int MAX_SURFACE_CLEAR_COUNT = 3;
    private static final String TAG = "EglRenderer";
    private GlTextureFrameBuffer bitmapTextureFramebuffer;
    private RendererCommon.GlDrawer drawer;
    private EglBase eglBase;
    private int framesDropped;
    private int framesReceived;
    private int framesRendered;
    private float layoutAspectRatio;
    private long minRenderPeriodNs;
    private boolean mirror;
    private final String name;
    private long nextFrameTimeNs;
    private VideoRenderer.I420Frame pendingFrame;
    private long renderSwapBufferTimeNs;
    private Handler renderThreadHandler;
    private long renderTimeNs;
    private long statisticsStartTimeNs;
    private final Object handlerLock = new Object();
    private final ArrayList<FrameListenerAndParams> frameListeners = new ArrayList<>();
    private final Object fpsReductionLock = new Object();
    private final RendererCommon.YuvUploader yuvUploader = new RendererCommon.YuvUploader();
    private final Object frameLock = new Object();
    private final Object layoutLock = new Object();
    private final Object statisticsLock = new Object();
    private final Runnable renderFrameRunnable = new Runnable() { // from class: org.webrtc.ali.EglRenderer.1
        @Override // java.lang.Runnable
        public void run() {
            EglRenderer.this.renderFrameOnRenderThread();
        }
    };
    private final Runnable logStatisticsRunnable = new Runnable() { // from class: org.webrtc.ali.EglRenderer.2
        @Override // java.lang.Runnable
        public void run() {
            EglRenderer.this.logStatistics();
            synchronized (EglRenderer.this.handlerLock) {
                if (EglRenderer.this.renderThreadHandler != null) {
                    EglRenderer.this.renderThreadHandler.removeCallbacks(EglRenderer.this.logStatisticsRunnable);
                    EglRenderer.this.renderThreadHandler.postDelayed(EglRenderer.this.logStatisticsRunnable, TimeUnit.SECONDS.toMillis(EglRenderer.LOG_INTERVAL_SEC));
                }
            }
        }
    };
    private final EglSurfaceCreation eglSurfaceCreationRunnable = new EglSurfaceCreation();

    /* loaded from: classes19.dex */
    public interface FrameListener {
        void onFrame(Bitmap bitmap);
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes19.dex */
    public static class FrameListenerAndParams {
        public final boolean applyFpsReduction;
        public final RendererCommon.GlDrawer drawer;
        public final FrameListener listener;
        public final float scale;

        public FrameListenerAndParams(FrameListener listener, float scale, RendererCommon.GlDrawer drawer, boolean applyFpsReduction) {
            this.listener = listener;
            this.scale = scale;
            this.drawer = drawer;
            this.applyFpsReduction = applyFpsReduction;
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes19.dex */
    public class EglSurfaceCreation implements Runnable {
        private Object surface;

        private EglSurfaceCreation() {
        }

        public synchronized void setSurface(Object surface) {
            this.surface = surface;
        }

        @Override // java.lang.Runnable
        public synchronized void run() {
            if (this.surface != null && EglRenderer.this.eglBase != null && !EglRenderer.this.eglBase.hasSurface()) {
                Object obj = this.surface;
                if (obj instanceof Surface) {
                    EglRenderer.this.eglBase.createSurface((Surface) this.surface);
                } else if (obj instanceof SurfaceTexture) {
                    EglRenderer.this.eglBase.createSurface((SurfaceTexture) this.surface);
                } else {
                    throw new IllegalStateException("Invalid surface: " + this.surface);
                }
                EglRenderer.this.eglBase.makeCurrent();
                GLES20.glPixelStorei(3317, 1);
            }
        }
    }

    public EglRenderer(String name) {
        this.name = name;
    }

    public void init(final EglBase.Context sharedContext, final int[] configAttributes, RendererCommon.GlDrawer drawer) {
        synchronized (this.handlerLock) {
            if (this.renderThreadHandler != null) {
                throw new IllegalStateException(this.name + "Already initialized");
            }
            logD("Initializing EglRenderer");
            this.drawer = drawer;
            HandlerThread renderThread = new HandlerThread(this.name + TAG);
            renderThread.start();
            Handler handler = new Handler(renderThread.getLooper());
            this.renderThreadHandler = handler;
            ThreadUtils.invokeAtFrontUninterruptibly(handler, new Runnable() { // from class: org.webrtc.ali.EglRenderer.3
                @Override // java.lang.Runnable
                public void run() {
                    if (sharedContext == null) {
                        EglRenderer.this.logD("EglBase10.create context");
                        EglRenderer.this.eglBase = EglBase.createEgl10(configAttributes);
                        return;
                    }
                    EglRenderer.this.logD("EglBase.create shared context");
                    EglRenderer.this.eglBase = EglBase.create(sharedContext, configAttributes);
                }
            });
            this.renderThreadHandler.post(this.eglSurfaceCreationRunnable);
            long currentTimeNs = System.nanoTime();
            resetStatistics(currentTimeNs);
            this.renderThreadHandler.postDelayed(this.logStatisticsRunnable, TimeUnit.SECONDS.toMillis(LOG_INTERVAL_SEC));
        }
    }

    public void createEglSurface(Surface surface) {
        createEglSurfaceInternal(surface);
    }

    public void createEglSurface(SurfaceTexture surfaceTexture) {
        createEglSurfaceInternal(surfaceTexture);
    }

    private void createEglSurfaceInternal(Object surface) {
        this.eglSurfaceCreationRunnable.setSurface(surface);
        postToRenderThread(this.eglSurfaceCreationRunnable);
    }

    public void release() {
        logD("Releasing.");
        final CountDownLatch eglCleanupBarrier = new CountDownLatch(1);
        synchronized (this.handlerLock) {
            Handler handler = this.renderThreadHandler;
            if (handler == null) {
                logD("Already released");
                return;
            }
            handler.removeCallbacks(this.logStatisticsRunnable);
            this.renderThreadHandler.postAtFrontOfQueue(new Runnable() { // from class: org.webrtc.ali.EglRenderer.4
                @Override // java.lang.Runnable
                public void run() {
                    if (EglRenderer.this.drawer != null) {
                        EglRenderer.this.drawer.release();
                        EglRenderer.this.drawer = null;
                    }
                    EglRenderer.this.yuvUploader.release();
                    if (EglRenderer.this.bitmapTextureFramebuffer != null) {
                        EglRenderer.this.bitmapTextureFramebuffer.release();
                        EglRenderer.this.bitmapTextureFramebuffer = null;
                    }
                    if (EglRenderer.this.eglBase != null) {
                        EglRenderer.this.logD("eglBase detach and release.");
                        EglRenderer.this.eglBase.detachCurrent();
                        EglRenderer.this.eglBase.release();
                        EglRenderer.this.eglBase = null;
                    }
                    eglCleanupBarrier.countDown();
                }
            });
            final Looper renderLooper = this.renderThreadHandler.getLooper();
            this.renderThreadHandler.post(new Runnable() { // from class: org.webrtc.ali.EglRenderer.5
                @Override // java.lang.Runnable
                public void run() {
                    EglRenderer.this.logD("Quitting render thread.");
                    renderLooper.quit();
                }
            });
            this.renderThreadHandler = null;
            ThreadUtils.awaitUninterruptibly(eglCleanupBarrier);
            synchronized (this.frameLock) {
                VideoRenderer.I420Frame i420Frame = this.pendingFrame;
                if (i420Frame != null) {
                    VideoRenderer.renderFrameDone(i420Frame);
                    this.pendingFrame = null;
                }
            }
            logD("Releasing done.");
        }
    }

    private void resetStatistics(long currentTimeNs) {
        synchronized (this.statisticsLock) {
            this.statisticsStartTimeNs = currentTimeNs;
            this.framesReceived = 0;
            this.framesDropped = 0;
            this.framesRendered = 0;
            this.renderTimeNs = 0L;
            this.renderSwapBufferTimeNs = 0L;
        }
    }

    public void printStackTrace() {
        synchronized (this.handlerLock) {
            Handler handler = this.renderThreadHandler;
            Thread renderThread = handler == null ? null : handler.getLooper().getThread();
            if (renderThread != null) {
                StackTraceElement[] renderStackTrace = renderThread.getStackTrace();
                if (renderStackTrace.length > 0) {
                    logD("EglRenderer stack trace:");
                    for (StackTraceElement traceElem : renderStackTrace) {
                        logD(traceElem.toString());
                    }
                }
            }
        }
    }

    public void setMirror(boolean mirror) {
        logD("setMirror: " + mirror);
        synchronized (this.layoutLock) {
            this.mirror = mirror;
        }
    }

    public void setLayoutAspectRatio(float layoutAspectRatio) {
        logD("setLayoutAspectRatio: " + layoutAspectRatio);
        synchronized (this.layoutLock) {
            this.layoutAspectRatio = layoutAspectRatio;
        }
    }

    public void setFpsReduction(float fps) {
        logD("setFpsReduction: " + fps);
        synchronized (this.fpsReductionLock) {
            long previousRenderPeriodNs = this.minRenderPeriodNs;
            if (fps <= 0.0f) {
                this.minRenderPeriodNs = Long.MAX_VALUE;
            } else {
                this.minRenderPeriodNs = ((float) TimeUnit.SECONDS.toNanos(1L)) / fps;
            }
            if (this.minRenderPeriodNs != previousRenderPeriodNs) {
                this.nextFrameTimeNs = System.nanoTime();
            }
        }
    }

    public void disableFpsReduction() {
        setFpsReduction(Float.POSITIVE_INFINITY);
    }

    public void pauseVideo() {
        setFpsReduction(0.0f);
    }

    public void addFrameListener(FrameListener listener, float scale) {
        addFrameListener(listener, scale, null, false);
    }

    public void addFrameListener(FrameListener listener, float scale, RendererCommon.GlDrawer drawerParam) {
        addFrameListener(listener, scale, drawerParam, false);
    }

    public void addFrameListener(final FrameListener listener, final float scale, final RendererCommon.GlDrawer drawerParam, final boolean applyFpsReduction) {
        postToRenderThread(new Runnable() { // from class: org.webrtc.ali.EglRenderer.6
            @Override // java.lang.Runnable
            public void run() {
                RendererCommon.GlDrawer listenerDrawer = drawerParam;
                if (listenerDrawer == null) {
                    listenerDrawer = EglRenderer.this.drawer;
                }
                EglRenderer.this.frameListeners.add(new FrameListenerAndParams(listener, scale, listenerDrawer, applyFpsReduction));
            }
        });
    }

    public void removeFrameListener(final FrameListener listener) {
        if (Thread.currentThread() == this.renderThreadHandler.getLooper().getThread()) {
            throw new RuntimeException("removeFrameListener must not be called on the render thread.");
        }
        final CountDownLatch latch = new CountDownLatch(1);
        postToRenderThread(new Runnable() { // from class: org.webrtc.ali.EglRenderer.7
            @Override // java.lang.Runnable
            public void run() {
                latch.countDown();
                Iterator<FrameListenerAndParams> iter = EglRenderer.this.frameListeners.iterator();
                while (iter.hasNext()) {
                    if (iter.next().listener == listener) {
                        iter.remove();
                    }
                }
            }
        });
        ThreadUtils.awaitUninterruptibly(latch);
    }

    @Override // org.webrtc.ali.VideoRenderer.Callbacks
    public void renderFrame(VideoRenderer.I420Frame frame) {
        boolean dropOldFrame;
        synchronized (this.statisticsLock) {
            this.framesReceived++;
        }
        synchronized (this.handlerLock) {
            if (this.renderThreadHandler == null) {
                logD("Dropping frame - Not initialized or already released.");
                VideoRenderer.renderFrameDone(frame);
                return;
            }
            synchronized (this.frameLock) {
                VideoRenderer.I420Frame i420Frame = this.pendingFrame;
                dropOldFrame = i420Frame != null;
                if (dropOldFrame) {
                    VideoRenderer.renderFrameDone(i420Frame);
                }
                this.pendingFrame = frame;
                this.renderThreadHandler.post(this.renderFrameRunnable);
            }
            if (dropOldFrame) {
                synchronized (this.statisticsLock) {
                    this.framesDropped++;
                }
            }
        }
    }

    public void releaseEglSurface(final Runnable completionCallback) {
        this.eglSurfaceCreationRunnable.setSurface(null);
        synchronized (this.handlerLock) {
            Handler handler = this.renderThreadHandler;
            if (handler != null) {
                handler.removeCallbacks(this.eglSurfaceCreationRunnable);
                this.renderThreadHandler.postAtFrontOfQueue(new Runnable() { // from class: org.webrtc.ali.EglRenderer.8
                    @Override // java.lang.Runnable
                    public void run() {
                        if (EglRenderer.this.eglBase != null) {
                            EglRenderer.this.eglBase.detachCurrent();
                            EglRenderer.this.eglBase.releaseSurface();
                        }
                        completionCallback.run();
                    }
                });
                return;
            }
            completionCallback.run();
        }
    }

    private void postToRenderThread(Runnable runnable) {
        synchronized (this.handlerLock) {
            Handler handler = this.renderThreadHandler;
            if (handler != null) {
                handler.post(runnable);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void clearSurfaceOnRenderThread(float r, float g, float b, float a2) {
        EglBase eglBase = this.eglBase;
        if (eglBase != null && eglBase.hasSurface()) {
            logD("clearSurface");
            GLES20.glClearColor(r, g, b, a2);
            GLES20.glClear(16384);
            this.eglBase.swapBuffers();
        }
    }

    public void clearImage() {
        clearImage(0.0f, 0.0f, 0.0f, 0.0f);
    }

    public void clearImage(final float r, final float g, final float b, final float a2) {
        synchronized (this.handlerLock) {
            Handler handler = this.renderThreadHandler;
            if (handler == null) {
                return;
            }
            handler.postAtFrontOfQueue(new Runnable() { // from class: org.webrtc.ali.EglRenderer.9
                @Override // java.lang.Runnable
                public void run() {
                    EglRenderer.this.clearSurfaceOnRenderThread(r, g, b, a2);
                }
            });
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void renderFrameOnRenderThread() {
        boolean shouldRenderFrame;
        float[] layoutMatrix;
        int drawnFrameWidth;
        int drawnFrameHeight;
        float[] drawMatrix;
        VideoRenderer.I420Frame frame;
        int drawnFrameWidth2;
        int drawnFrameHeight2;
        synchronized (this.frameLock) {
            VideoRenderer.I420Frame frame2 = this.pendingFrame;
            if (frame2 == null) {
                return;
            }
            int[] iArr = null;
            this.pendingFrame = null;
            EglBase eglBase = this.eglBase;
            if (eglBase == null || !eglBase.hasSurface()) {
                logD("Dropping frame - No surface");
                VideoRenderer.renderFrameDone(frame2);
                return;
            }
            synchronized (this.fpsReductionLock) {
                long j = this.minRenderPeriodNs;
                if (j == Long.MAX_VALUE) {
                    shouldRenderFrame = false;
                } else if (j <= 0) {
                    shouldRenderFrame = true;
                } else {
                    long currentTimeNs = System.nanoTime();
                    long j2 = this.nextFrameTimeNs;
                    if (currentTimeNs < j2) {
                        logD("Skipping frame rendering - fps reduction is active.");
                        shouldRenderFrame = false;
                    } else {
                        long j3 = j2 + this.minRenderPeriodNs;
                        this.nextFrameTimeNs = j3;
                        this.nextFrameTimeNs = Math.max(j3, currentTimeNs);
                        shouldRenderFrame = true;
                    }
                }
            }
            long startTimeNs = System.nanoTime();
            float[] texMatrix = RendererCommon.rotateTextureMatrix(frame2.samplingMatrix, frame2.rotationDegree);
            synchronized (this.layoutLock) {
                if (this.layoutAspectRatio > 0.0f) {
                    float frameAspectRatio = frame2.rotatedWidth() / frame2.rotatedHeight();
                    layoutMatrix = RendererCommon.getLayoutMatrix(this.mirror, frameAspectRatio, this.layoutAspectRatio);
                    if (frameAspectRatio > this.layoutAspectRatio) {
                        drawnFrameWidth2 = (int) (frame2.rotatedHeight() * this.layoutAspectRatio);
                        drawnFrameHeight2 = frame2.rotatedHeight();
                    } else {
                        drawnFrameWidth2 = frame2.rotatedWidth();
                        drawnFrameHeight2 = (int) (frame2.rotatedWidth() / this.layoutAspectRatio);
                    }
                    drawnFrameWidth = drawnFrameWidth2;
                    drawnFrameHeight = drawnFrameHeight2;
                } else {
                    layoutMatrix = this.mirror ? RendererCommon.horizontalFlipMatrix() : RendererCommon.identityMatrix();
                    int drawnFrameWidth3 = frame2.rotatedWidth();
                    drawnFrameWidth = drawnFrameWidth3;
                    drawnFrameHeight = frame2.rotatedHeight();
                }
                drawMatrix = RendererCommon.multiplyMatrices(texMatrix, layoutMatrix);
            }
            boolean shouldUploadYuvTextures = false;
            if (frame2.yuvFrame && !((shouldUploadYuvTextures = shouldRenderFrame))) {
                Iterator<FrameListenerAndParams> it = this.frameListeners.iterator();
                while (it.hasNext()) {
                    FrameListenerAndParams listenerAndParams = it.next();
                    if (listenerAndParams.scale != 0.0f && (shouldRenderFrame || !listenerAndParams.applyFpsReduction)) {
                        shouldUploadYuvTextures = true;
                        break;
                    }
                }
            }
            if (shouldUploadYuvTextures) {
                iArr = this.yuvUploader.uploadYuvData(frame2.width, frame2.height, frame2.yuvStrides, frame2.yuvPlanes);
            }
            int[] yuvTextures = iArr;
            if (!shouldRenderFrame) {
                frame = frame2;
            } else {
                GLES20.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
                GLES20.glClear(16384);
                if (frame2.yuvFrame) {
                    this.drawer.drawYuv(yuvTextures, drawMatrix, drawnFrameWidth, drawnFrameHeight, 0, 0, this.eglBase.surfaceWidth(), this.eglBase.surfaceHeight());
                } else {
                    this.drawer.drawOes(frame2.textureId, drawMatrix, drawnFrameWidth, drawnFrameHeight, 0, 0, this.eglBase.surfaceWidth(), this.eglBase.surfaceHeight());
                }
                long swapBuffersStartTimeNs = System.nanoTime();
                this.eglBase.swapBuffers();
                long currentTimeNs2 = System.nanoTime();
                synchronized (this.statisticsLock) {
                    try {
                        try {
                            this.framesRendered++;
                            frame = frame2;
                            this.renderTimeNs += currentTimeNs2 - startTimeNs;
                            this.renderSwapBufferTimeNs += currentTimeNs2 - swapBuffersStartTimeNs;
                        } catch (Throwable th) {
                            th = th;
                            throw th;
                        }
                    } catch (Throwable th2) {
                        th = th2;
                    }
                }
            }
            VideoRenderer.I420Frame frame3 = frame;
            notifyCallbacks(frame3, yuvTextures, texMatrix, shouldRenderFrame);
            VideoRenderer.renderFrameDone(frame3);
        }
    }

    private void notifyCallbacks(VideoRenderer.I420Frame frame, int[] yuvTextures, float[] texMatrix, boolean wasRendered) {
        int scaledHeight;
        EglRenderer eglRenderer = this;
        if (eglRenderer.frameListeners.isEmpty()) {
            return;
        }
        float[] bitmapMatrix = RendererCommon.multiplyMatrices(RendererCommon.multiplyMatrices(texMatrix, eglRenderer.mirror ? RendererCommon.horizontalFlipMatrix() : RendererCommon.identityMatrix()), RendererCommon.verticalFlipMatrix());
        Iterator<FrameListenerAndParams> it = eglRenderer.frameListeners.iterator();
        while (it.hasNext()) {
            FrameListenerAndParams listenerAndParams = it.next();
            if (wasRendered || !listenerAndParams.applyFpsReduction) {
                it.remove();
                int scaledWidth = (int) (listenerAndParams.scale * frame.rotatedWidth());
                int scaledHeight2 = (int) (listenerAndParams.scale * frame.rotatedHeight());
                if (scaledWidth == 0 || scaledHeight2 == 0) {
                    listenerAndParams.listener.onFrame(null);
                    eglRenderer = this;
                } else {
                    if (eglRenderer.bitmapTextureFramebuffer == null) {
                        eglRenderer.bitmapTextureFramebuffer = new GlTextureFrameBuffer(6408);
                    }
                    eglRenderer.bitmapTextureFramebuffer.setSize(scaledWidth, scaledHeight2);
                    GLES20.glBindFramebuffer(36160, eglRenderer.bitmapTextureFramebuffer.getFrameBufferId());
                    GLES20.glFramebufferTexture2D(36160, 36064, 3553, eglRenderer.bitmapTextureFramebuffer.getTextureId(), 0);
                    GLES20.glClearColor(0.0f, 0.0f, 0.0f, 0.0f);
                    GLES20.glClear(16384);
                    if (frame.yuvFrame) {
                        scaledHeight = scaledHeight2;
                        listenerAndParams.drawer.drawYuv(yuvTextures, bitmapMatrix, frame.rotatedWidth(), frame.rotatedHeight(), 0, 0, scaledWidth, scaledHeight2);
                    } else {
                        scaledHeight = scaledHeight2;
                        listenerAndParams.drawer.drawOes(frame.textureId, bitmapMatrix, frame.rotatedWidth(), frame.rotatedHeight(), 0, 0, scaledWidth, scaledHeight2);
                    }
                    int scaledHeight3 = scaledHeight;
                    ByteBuffer bitmapBuffer = ByteBuffer.allocateDirect(scaledWidth * scaledHeight3 * 4);
                    GLES20.glViewport(0, 0, scaledWidth, scaledHeight3);
                    GLES20.glReadPixels(0, 0, scaledWidth, scaledHeight3, 6408, 5121, bitmapBuffer);
                    GLES20.glBindFramebuffer(36160, 0);
                    GlUtil.checkNoGLES2Error("EglRenderer.notifyCallbacks");
                    Bitmap bitmap = Bitmap.createBitmap(scaledWidth, scaledHeight3, Bitmap.Config.ARGB_8888);
                    bitmap.copyPixelsFromBuffer(bitmapBuffer);
                    listenerAndParams.listener.onFrame(bitmap);
                    eglRenderer = this;
                }
            }
        }
    }

    private String averageTimeAsString(long sumTimeNs, int count) {
        return count <= 0 ? "NA" : TimeUnit.NANOSECONDS.toMicros(sumTimeNs / count) + " μs";
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void logStatistics() {
        long currentTimeNs = System.nanoTime();
        synchronized (this.statisticsLock) {
            long elapsedTimeNs = currentTimeNs - this.statisticsStartTimeNs;
            if (elapsedTimeNs <= 0) {
                return;
            }
            float renderFps = ((float) (this.framesRendered * TimeUnit.SECONDS.toNanos(1L))) / ((float) elapsedTimeNs);
            logD("Duration: " + TimeUnit.NANOSECONDS.toMillis(elapsedTimeNs) + " ms. Frames received: " + this.framesReceived + ". Dropped: " + this.framesDropped + ". Rendered: " + this.framesRendered + ". Render fps: " + String.format(Locale.US, "%.1f", Float.valueOf(renderFps)) + ". Average render time: " + averageTimeAsString(this.renderTimeNs, this.framesRendered) + ". Average swapBuffer time: " + averageTimeAsString(this.renderSwapBufferTimeNs, this.framesRendered) + ".");
            resetStatistics(currentTimeNs);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void logD(String string) {
        Logging.d(TAG, this.name + string);
    }
}
