package org.webrtc.ali;

import android.graphics.Matrix;
import android.media.MediaCodec;
import android.media.MediaCrypto;
import android.media.MediaFormat;
import android.os.SystemClock;
import android.view.Surface;
import com.google.android.exoplayer2.DefaultRenderersFactory;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Deque;
import java.util.concurrent.LinkedBlockingDeque;
import org.webrtc.ali.EncodedImage;
import org.webrtc.ali.ThreadUtils;
import org.webrtc.ali.VideoDecoder;
import org.webrtc.ali.VideoFrame;
/* loaded from: classes19.dex */
class HardwareVideoDecoder implements VideoDecoder {
    private static final int DEQUEUE_INPUT_TIMEOUT_US = 500000;
    private static final int DEQUEUE_OUTPUT_BUFFER_TIMEOUT_US = 100000;
    private static final int MEDIA_CODEC_RELEASE_TIMEOUT_MS = 5000;
    private static final String MEDIA_FORMAT_KEY_CROP_BOTTOM = "crop-bottom";
    private static final String MEDIA_FORMAT_KEY_CROP_LEFT = "crop-left";
    private static final String MEDIA_FORMAT_KEY_CROP_RIGHT = "crop-right";
    private static final String MEDIA_FORMAT_KEY_CROP_TOP = "crop-top";
    private static final String MEDIA_FORMAT_KEY_SLICE_HEIGHT = "slice-height";
    private static final String MEDIA_FORMAT_KEY_STRIDE = "stride";
    private static final String TAG = "HardwareVideoDecoder";
    private VideoDecoder.Callback callback;
    private final String codecName;
    private final VideoCodecType codecType;
    private int colorFormat;
    private ThreadUtils.ThreadChecker decoderThreadChecker;
    private final Deque<FrameInfo> frameInfos;
    private boolean hasDecodedFirstFrame;
    private int height;
    private boolean keyFrameRequired;
    private Thread outputThread;
    private ThreadUtils.ThreadChecker outputThreadChecker;
    private int sliceHeight;
    private int stride;
    private int width;
    private volatile boolean running = false;
    private volatile Exception shutdownException = null;
    private final Object activeOutputBuffersLock = new Object();
    private int activeOutputBuffers = 0;
    private final Object dimensionLock = new Object();
    private MediaCodec codec = null;

    static /* synthetic */ int access$610(HardwareVideoDecoder x0) {
        int i = x0.activeOutputBuffers;
        x0.activeOutputBuffers = i - 1;
        return i;
    }

    /* JADX INFO: Access modifiers changed from: private */
    /* loaded from: classes19.dex */
    public static class FrameInfo {
        final long decodeStartTimeMs;
        final int rotation;

        FrameInfo(long decodeStartTimeMs, int rotation) {
            this.decodeStartTimeMs = decodeStartTimeMs;
            this.rotation = rotation;
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public HardwareVideoDecoder(String codecName, VideoCodecType codecType, int colorFormat) {
        if (!isSupportedColorFormat(colorFormat)) {
            throw new IllegalArgumentException("Unsupported color format: " + colorFormat);
        }
        this.codecName = codecName;
        this.codecType = codecType;
        this.colorFormat = colorFormat;
        this.frameInfos = new LinkedBlockingDeque();
    }

    @Override // org.webrtc.ali.VideoDecoder
    public VideoCodecStatus initDecode(VideoDecoder.Settings settings, VideoDecoder.Callback callback) {
        this.decoderThreadChecker = new ThreadUtils.ThreadChecker();
        return initDecodeInternal(settings.width, settings.height, callback);
    }

    private VideoCodecStatus initDecodeInternal(int width, int height, VideoDecoder.Callback callback) {
        this.decoderThreadChecker.checkIsOnValidThread();
        if (this.outputThread != null) {
            Logging.e(TAG, "initDecodeInternal called while the codec is already running");
            return VideoCodecStatus.ERROR;
        }
        this.callback = callback;
        this.width = width;
        this.height = height;
        this.stride = width;
        this.sliceHeight = height;
        this.hasDecodedFirstFrame = false;
        this.keyFrameRequired = true;
        try {
            this.codec = MediaCodec.createByCodecName(this.codecName);
            try {
                MediaFormat format = MediaFormat.createVideoFormat(this.codecType.mimeType(), width, height);
                format.setInteger("color-format", this.colorFormat);
                this.codec.configure(format, (Surface) null, (MediaCrypto) null, 0);
                this.codec.start();
                this.running = true;
                Thread createOutputThread = createOutputThread();
                this.outputThread = createOutputThread;
                createOutputThread.start();
                return VideoCodecStatus.OK;
            } catch (IllegalStateException e) {
                Logging.e(TAG, "initDecode failed", e);
                release();
                return VideoCodecStatus.ERROR;
            }
        } catch (IOException | IllegalArgumentException e2) {
            Logging.e(TAG, "Cannot create media decoder " + this.codecName);
            return VideoCodecStatus.ERROR;
        }
    }

    @Override // org.webrtc.ali.VideoDecoder
    public VideoCodecStatus decode(EncodedImage frame, VideoDecoder.DecodeInfo info) {
        int width;
        int height;
        VideoCodecStatus status;
        this.decoderThreadChecker.checkIsOnValidThread();
        if (this.codec == null || this.callback == null) {
            return VideoCodecStatus.UNINITIALIZED;
        }
        if (frame.buffer == null) {
            Logging.e(TAG, "decode() - no input data");
            return VideoCodecStatus.ERR_PARAMETER;
        }
        int size = frame.buffer.remaining();
        if (size == 0) {
            Logging.e(TAG, "decode() - input buffer empty");
            return VideoCodecStatus.ERR_PARAMETER;
        }
        synchronized (this.dimensionLock) {
            width = this.width;
            height = this.height;
        }
        if (frame.encodedWidth * frame.encodedHeight > 0 && ((frame.encodedWidth != width || frame.encodedHeight != height) && (status = reinitDecode(frame.encodedWidth, frame.encodedHeight)) != VideoCodecStatus.OK)) {
            return status;
        }
        if (this.keyFrameRequired) {
            if (frame.frameType != EncodedImage.FrameType.VideoFrameKey) {
                Logging.e(TAG, "decode() - key frame required first");
                return VideoCodecStatus.ERROR;
            } else if (!frame.completeFrame) {
                Logging.e(TAG, "decode() - complete frame required first");
                return VideoCodecStatus.ERROR;
            }
        }
        try {
            int index = this.codec.dequeueInputBuffer(500000L);
            if (index < 0) {
                Logging.e(TAG, "decode() - no HW buffers available; decoder falling behind");
                return VideoCodecStatus.ERROR;
            }
            try {
                ByteBuffer buffer = this.codec.getInputBuffers()[index];
                if (buffer.capacity() < size) {
                    Logging.e(TAG, "decode() - HW buffer too small");
                    return VideoCodecStatus.ERROR;
                }
                buffer.put(frame.buffer);
                this.frameInfos.offer(new FrameInfo(SystemClock.elapsedRealtime(), frame.rotation));
                try {
                    this.codec.queueInputBuffer(index, 0, size, frame.captureTimeMs * 1000, 0);
                    if (this.keyFrameRequired) {
                        this.keyFrameRequired = false;
                    }
                    return VideoCodecStatus.OK;
                } catch (IllegalStateException e) {
                    Logging.e(TAG, "queueInputBuffer failed", e);
                    this.frameInfos.pollLast();
                    return VideoCodecStatus.ERROR;
                }
            } catch (IllegalStateException e2) {
                Logging.e(TAG, "getInputBuffers failed", e2);
                return VideoCodecStatus.ERROR;
            }
        } catch (IllegalStateException e3) {
            Logging.e(TAG, "dequeueInputBuffer failed", e3);
            return VideoCodecStatus.ERROR;
        }
    }

    @Override // org.webrtc.ali.VideoDecoder
    public boolean getPrefersLateDecoding() {
        return true;
    }

    @Override // org.webrtc.ali.VideoDecoder
    public String getImplementationName() {
        return "HardwareVideoDecoder: " + this.codecName;
    }

    /* JADX WARN: Type inference failed for: r1v0, types: [android.media.MediaCodec, java.lang.Thread, org.webrtc.ali.VideoDecoder$Callback] */
    @Override // org.webrtc.ali.VideoDecoder
    public VideoCodecStatus release() {
        try {
            this.running = false;
            if (!ThreadUtils.joinUninterruptibly(this.outputThread, DefaultRenderersFactory.DEFAULT_ALLOWED_VIDEO_JOINING_TIME_MS)) {
                Logging.e(TAG, "Media encoder release timeout", new RuntimeException());
                return VideoCodecStatus.TIMEOUT;
            } else if (this.shutdownException != null) {
                Logging.e(TAG, "Media encoder release error", new RuntimeException(this.shutdownException));
                this.shutdownException = null;
                return VideoCodecStatus.ERROR;
            } else {
                this.codec = null;
                this.callback = null;
                this.outputThread = null;
                this.frameInfos.clear();
                return VideoCodecStatus.OK;
            }
        } finally {
            this.codec = null;
            this.callback = null;
            this.outputThread = null;
            this.frameInfos.clear();
        }
    }

    private VideoCodecStatus reinitDecode(int newWidth, int newHeight) {
        this.decoderThreadChecker.checkIsOnValidThread();
        VideoCodecStatus status = release();
        if (status != VideoCodecStatus.OK) {
            return status;
        }
        return initDecodeInternal(newWidth, newHeight, this.callback);
    }

    private Thread createOutputThread() {
        return new Thread("HardwareVideoDecoder.outputThread") { // from class: org.webrtc.ali.HardwareVideoDecoder.1
            @Override // java.lang.Thread, java.lang.Runnable
            public void run() {
                HardwareVideoDecoder.this.outputThreadChecker = new ThreadUtils.ThreadChecker();
                while (HardwareVideoDecoder.this.running) {
                    HardwareVideoDecoder.this.deliverDecodedFrame();
                }
                HardwareVideoDecoder.this.releaseCodecOnOutputThread();
            }
        };
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void deliverDecodedFrame() {
        Integer decodeTimeMs;
        int rotation;
        int width;
        int height;
        int stride;
        int sliceHeight;
        int stride2;
        VideoFrame.I420Buffer frameBuffer;
        this.outputThreadChecker.checkIsOnValidThread();
        try {
            MediaCodec.BufferInfo info = new MediaCodec.BufferInfo();
            int result = this.codec.dequeueOutputBuffer(info, 100000L);
            if (result == -2) {
                reformat(this.codec.getOutputFormat());
            } else if (result < 0) {
                Logging.v(TAG, "dequeueOutputBuffer returned " + result);
            } else {
                FrameInfo frameInfo = this.frameInfos.poll();
                if (frameInfo == null) {
                    decodeTimeMs = null;
                    rotation = 0;
                } else {
                    Integer decodeTimeMs2 = Integer.valueOf((int) (SystemClock.elapsedRealtime() - frameInfo.decodeStartTimeMs));
                    int rotation2 = frameInfo.rotation;
                    decodeTimeMs = decodeTimeMs2;
                    rotation = rotation2;
                }
                this.hasDecodedFirstFrame = true;
                synchronized (this.dimensionLock) {
                    width = this.width;
                    height = this.height;
                    stride = this.stride;
                    sliceHeight = this.sliceHeight;
                }
                if (info.size < ((width * height) * 3) / 2) {
                    Logging.e(TAG, "Insufficient output buffer size: " + info.size);
                    return;
                }
                if (info.size < ((stride * height) * 3) / 2 && sliceHeight == height && stride > width) {
                    stride2 = (info.size * 2) / (height * 3);
                } else {
                    stride2 = stride;
                }
                ByteBuffer buffer = this.codec.getOutputBuffers()[result];
                buffer.position(info.offset);
                buffer.limit(info.size);
                if (this.colorFormat == 19) {
                    if (sliceHeight % 2 == 0) {
                        frameBuffer = createBufferFromI420(buffer, result, info.offset, stride2, sliceHeight, width, height);
                    } else {
                        VideoFrame.I420Buffer frameBuffer2 = new I420BufferImpl(width, height);
                        copyI420(buffer, info.offset, frameBuffer2, stride2, sliceHeight, width, height);
                        this.codec.releaseOutputBuffer(result, false);
                        frameBuffer = frameBuffer2;
                    }
                } else {
                    VideoFrame.I420Buffer frameBuffer3 = new I420BufferImpl(width, height);
                    nv12ToI420(buffer, info.offset, frameBuffer3, stride2, sliceHeight, width, height);
                    this.codec.releaseOutputBuffer(result, false);
                    frameBuffer = frameBuffer3;
                }
                long presentationTimeNs = info.presentationTimeUs * 1000;
                VideoFrame frame = new VideoFrame(frameBuffer, rotation, presentationTimeNs, new Matrix());
                this.callback.onDecodedFrame(frame, decodeTimeMs, null);
                frame.release();
            }
        } catch (IllegalStateException e) {
            Logging.e(TAG, "deliverDecodedFrame failed", e);
        }
    }

    private void reformat(MediaFormat format) {
        int newWidth;
        int newHeight;
        this.outputThreadChecker.checkIsOnValidThread();
        Logging.d(TAG, "Decoder format changed: " + format.toString());
        if (format.containsKey(MEDIA_FORMAT_KEY_CROP_LEFT) && format.containsKey(MEDIA_FORMAT_KEY_CROP_RIGHT) && format.containsKey(MEDIA_FORMAT_KEY_CROP_BOTTOM) && format.containsKey(MEDIA_FORMAT_KEY_CROP_TOP)) {
            newWidth = (format.getInteger(MEDIA_FORMAT_KEY_CROP_RIGHT) + 1) - format.getInteger(MEDIA_FORMAT_KEY_CROP_LEFT);
            newHeight = (format.getInteger(MEDIA_FORMAT_KEY_CROP_BOTTOM) + 1) - format.getInteger(MEDIA_FORMAT_KEY_CROP_TOP);
        } else {
            newWidth = format.getInteger("width");
            newHeight = format.getInteger("height");
        }
        synchronized (this.dimensionLock) {
            if (this.hasDecodedFirstFrame && (this.width != newWidth || this.height != newHeight)) {
                stopOnOutputThread(new RuntimeException("Unexpected size change. Configured " + this.width + "*" + this.height + ". New " + newWidth + "*" + newHeight));
                return;
            }
            this.width = newWidth;
            this.height = newHeight;
            if (format.containsKey("color-format")) {
                this.colorFormat = format.getInteger("color-format");
                Logging.d(TAG, "Color: 0x" + Integer.toHexString(this.colorFormat));
                if (!isSupportedColorFormat(this.colorFormat)) {
                    stopOnOutputThread(new IllegalStateException("Unsupported color format: " + this.colorFormat));
                    return;
                }
            }
            synchronized (this.dimensionLock) {
                if (format.containsKey(MEDIA_FORMAT_KEY_STRIDE)) {
                    this.stride = format.getInteger(MEDIA_FORMAT_KEY_STRIDE);
                }
                if (format.containsKey(MEDIA_FORMAT_KEY_SLICE_HEIGHT)) {
                    this.sliceHeight = format.getInteger(MEDIA_FORMAT_KEY_SLICE_HEIGHT);
                }
                Logging.d(TAG, "Frame stride and slice height: " + this.stride + " x " + this.sliceHeight);
                this.stride = Math.max(this.width, this.stride);
                this.sliceHeight = Math.max(this.height, this.sliceHeight);
            }
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void releaseCodecOnOutputThread() {
        this.outputThreadChecker.checkIsOnValidThread();
        Logging.d(TAG, "Releasing MediaCodec on output thread");
        waitOutputBuffersReleasedOnOutputThread();
        try {
            this.codec.stop();
        } catch (Exception e) {
            Logging.e(TAG, "Media decoder stop failed", e);
        }
        try {
            this.codec.release();
        } catch (Exception e2) {
            Logging.e(TAG, "Media decoder release failed", e2);
            this.shutdownException = e2;
        }
        this.codec = null;
        this.callback = null;
        this.outputThread = null;
        this.frameInfos.clear();
        Logging.d(TAG, "Release on output thread done");
    }

    private void waitOutputBuffersReleasedOnOutputThread() {
        this.outputThreadChecker.checkIsOnValidThread();
        synchronized (this.activeOutputBuffersLock) {
            while (this.activeOutputBuffers > 0) {
                Logging.d(TAG, "Waiting for all frames to be released.");
                try {
                    this.activeOutputBuffersLock.wait();
                } catch (InterruptedException e) {
                    Logging.e(TAG, "Interrupted while waiting for output buffers to be released.", e);
                    return;
                }
            }
        }
    }

    private void stopOnOutputThread(Exception e) {
        this.outputThreadChecker.checkIsOnValidThread();
        this.running = false;
        this.shutdownException = e;
    }

    private boolean isSupportedColorFormat(int colorFormat) {
        int[] iArr;
        for (int supported : MediaCodecUtils.DECODER_COLOR_FORMATS) {
            if (supported == colorFormat) {
                return true;
            }
        }
        return false;
    }

    private VideoFrame.I420Buffer createBufferFromI420(final ByteBuffer buffer, final int outputBufferIndex, final int offset, final int stride, int sliceHeight, final int width, final int height) {
        final int uvStride = stride / 2;
        int i = (width + 1) / 2;
        final int chromaHeight = (height + 1) / 2;
        final int uPos = offset + (stride * sliceHeight);
        final int vPos = uPos + ((uvStride * sliceHeight) / 2);
        synchronized (this.activeOutputBuffersLock) {
            this.activeOutputBuffers++;
        }
        return new VideoFrame.I420Buffer() { // from class: org.webrtc.ali.HardwareVideoDecoder.2
            private int refCount = 1;

            @Override // org.webrtc.ali.VideoFrame.I420Buffer
            public ByteBuffer getDataY() {
                ByteBuffer data = buffer.slice();
                data.position(offset);
                data.limit(offset + (getStrideY() * height));
                return data;
            }

            @Override // org.webrtc.ali.VideoFrame.I420Buffer
            public ByteBuffer getDataU() {
                ByteBuffer data = buffer.slice();
                data.position(uPos);
                data.limit(uPos + (getStrideU() * chromaHeight));
                return data;
            }

            @Override // org.webrtc.ali.VideoFrame.I420Buffer
            public ByteBuffer getDataV() {
                ByteBuffer data = buffer.slice();
                data.position(vPos);
                data.limit(vPos + (getStrideV() * chromaHeight));
                return data;
            }

            @Override // org.webrtc.ali.VideoFrame.I420Buffer
            public int getStrideY() {
                return stride;
            }

            @Override // org.webrtc.ali.VideoFrame.I420Buffer
            public int getStrideU() {
                return uvStride;
            }

            @Override // org.webrtc.ali.VideoFrame.I420Buffer
            public int getStrideV() {
                return uvStride;
            }

            @Override // org.webrtc.ali.VideoFrame.Buffer
            public int getWidth() {
                return width;
            }

            @Override // org.webrtc.ali.VideoFrame.Buffer
            public int getHeight() {
                return height;
            }

            @Override // org.webrtc.ali.VideoFrame.Buffer
            public VideoFrame.I420Buffer toI420() {
                return this;
            }

            @Override // org.webrtc.ali.VideoFrame.Buffer
            public void retain() {
                this.refCount++;
            }

            @Override // org.webrtc.ali.VideoFrame.Buffer
            public void release() {
                int i2 = this.refCount - 1;
                this.refCount = i2;
                if (i2 == 0) {
                    HardwareVideoDecoder.this.codec.releaseOutputBuffer(outputBufferIndex, false);
                    synchronized (HardwareVideoDecoder.this.activeOutputBuffersLock) {
                        HardwareVideoDecoder.access$610(HardwareVideoDecoder.this);
                        HardwareVideoDecoder.this.activeOutputBuffersLock.notifyAll();
                    }
                }
            }
        };
    }

    private static void copyI420(ByteBuffer src, int offset, VideoFrame.I420Buffer frameBuffer, int stride, int sliceHeight, int width, int height) {
        int uvStride = stride / 2;
        int chromaWidth = (width + 1) / 2;
        int chromaHeight = sliceHeight % 2 == 0 ? (height + 1) / 2 : height / 2;
        int uPos = offset + (stride * sliceHeight);
        int vPos = uPos + ((uvStride * sliceHeight) / 2);
        copyPlane(src, offset, stride, frameBuffer.getDataY(), 0, frameBuffer.getStrideY(), width, height);
        copyPlane(src, uPos, uvStride, frameBuffer.getDataU(), 0, frameBuffer.getStrideU(), chromaWidth, chromaHeight);
        copyPlane(src, vPos, uvStride, frameBuffer.getDataV(), 0, frameBuffer.getStrideV(), chromaWidth, chromaHeight);
        if (sliceHeight % 2 != 0) {
            int strideU = frameBuffer.getStrideU();
            int endU = chromaHeight * strideU;
            copyRow(frameBuffer.getDataU(), endU - strideU, frameBuffer.getDataU(), endU, chromaWidth);
            int strideV = frameBuffer.getStrideV();
            int endV = chromaHeight * strideV;
            copyRow(frameBuffer.getDataV(), endV - strideV, frameBuffer.getDataV(), endV, chromaWidth);
        }
    }

    private static void nv12ToI420(ByteBuffer src, int offset, VideoFrame.I420Buffer frameBuffer, int stride, int sliceHeight, int width, int height) {
        int uvPos = offset + (stride * sliceHeight);
        int chromaWidth = (width + 1) / 2;
        int chromaHeight = (height + 1) / 2;
        copyPlane(src, offset, stride, frameBuffer.getDataY(), 0, frameBuffer.getStrideY(), width, height);
        int dstUPos = 0;
        int dstVPos = 0;
        for (int i = 0; i < chromaHeight; i++) {
            for (int j = 0; j < chromaWidth; j++) {
                frameBuffer.getDataU().put(dstUPos + j, src.get((j * 2) + uvPos));
                frameBuffer.getDataV().put(dstVPos + j, src.get((j * 2) + uvPos + 1));
            }
            int j2 = frameBuffer.getStrideU();
            dstUPos += j2;
            dstVPos += frameBuffer.getStrideV();
            uvPos += stride;
        }
    }

    private static void copyPlane(ByteBuffer src, int srcPos, int srcStride, ByteBuffer dst, int dstPos, int dstStride, int width, int height) {
        for (int i = 0; i < height; i++) {
            copyRow(src, srcPos, dst, dstPos, width);
            srcPos += srcStride;
            dstPos += dstStride;
        }
    }

    private static void copyRow(ByteBuffer src, int srcPos, ByteBuffer dst, int dstPos, int width) {
        for (int i = 0; i < width; i++) {
            dst.put(dstPos + i, src.get(srcPos + i));
        }
    }
}
