package tlschannel.async;

import java.io.IOException;
import java.nio.channels.CancelledKeyException;
import java.nio.channels.ClosedChannelException;
import java.nio.channels.InterruptedByTimeoutException;
import java.nio.channels.ReadPendingException;
import java.nio.channels.SelectionKey;
import java.nio.channels.Selector;
import java.nio.channels.ShutdownChannelGroupException;
import java.nio.channels.SocketChannel;
import java.nio.channels.WritePendingException;
import java.util.Iterator;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Future;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ScheduledThreadPoolExecutor;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.LongAdder;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;
import java.util.function.Consumer;
import java.util.function.IntBinaryOperator;
import java.util.function.LongConsumer;
import java.util.logging.Level;
import java.util.logging.Logger;
import tlschannel.NeedsReadException;
import tlschannel.NeedsTaskException;
import tlschannel.NeedsWriteException;
import tlschannel.TlsChannel;
import tlschannel.impl.ByteBufferSet;
import tlschannel.util.Util;
/* loaded from: classes19.dex */
public class AsynchronousTlsChannelGroup {
    public static final int queueLengthMultiplier = 32;
    public final LongAdder cancelledReads;
    public final LongAdder cancelledWrites;
    public final LongAdder currentReads;
    public final LongAdder currentWrites;
    public final ExecutorService executor;
    public final LongAdder failedReads;
    public final LongAdder failedWrites;
    public final int id;
    public final AtomicBoolean loggedTaskWarning;
    public final ConcurrentLinkedQueue<RegisteredSocket> pendingRegistrations;
    public final ConcurrentHashMap<RegisteredSocket, Boolean> registrations;
    public final LongAdder selectionCount;
    public final Selector selector;
    public final Thread selectorThread;
    public volatile Shutdown shutdown;
    public final LongAdder startedReads;
    public final LongAdder startedWrites;
    public final LongAdder successfulReads;
    public final LongAdder successfulWrites;
    public final ScheduledThreadPoolExecutor timeoutExecutor;
    public static final Logger logger = Logger.getLogger(AsynchronousTlsChannelGroup.class.getName());
    public static final AtomicInteger globalGroupCount = new AtomicInteger();

    /* loaded from: classes19.dex */
    public static abstract class Operation {
        public final ByteBufferSet bufferSet;
        public final Consumer<Throwable> onFailure;
        public final LongConsumer onSuccess;
        public Future<?> timeoutFuture;

        public Operation(ByteBufferSet byteBufferSet, LongConsumer longConsumer, Consumer<Throwable> consumer) {
            this.bufferSet = byteBufferSet;
            this.onSuccess = longConsumer;
            this.onFailure = consumer;
        }
    }

    /* loaded from: classes19.dex */
    public static final class ReadOperation extends Operation {
        public ReadOperation(ByteBufferSet byteBufferSet, LongConsumer longConsumer, Consumer<Throwable> consumer) {
            super(byteBufferSet, longConsumer, consumer);
        }
    }

    /* loaded from: classes19.dex */
    public class RegisteredSocket {
        public SelectionKey key;
        public ReadOperation readOperation;
        public final SocketChannel socketChannel;
        public final TlsChannel tlsChannel;
        public WriteOperation writeOperation;
        public final CountDownLatch registered = new CountDownLatch(1);
        public final Lock readLock = new ReentrantLock();
        public final Lock writeLock = new ReentrantLock();
        public final AtomicInteger pendingOps = new AtomicInteger();

        public RegisteredSocket(TlsChannel tlsChannel, SocketChannel socketChannel) {
            this.tlsChannel = tlsChannel;
            this.socketChannel = socketChannel;
        }

        public void close() {
            SelectionKey selectionKey = this.key;
            if (selectionKey != null) {
                selectionKey.cancel();
            }
            AsynchronousTlsChannelGroup.this.selector.wakeup();
        }
    }

    /* loaded from: classes19.dex */
    public enum Shutdown {
        No,
        Wait,
        Immediate
    }

    /* loaded from: classes19.dex */
    public static final class WriteOperation extends Operation {
        public long consumesBytes;

        public WriteOperation(ByteBufferSet byteBufferSet, LongConsumer longConsumer, Consumer<Throwable> consumer) {
            super(byteBufferSet, longConsumer, consumer);
            this.consumesBytes = 0L;
        }
    }

    public AsynchronousTlsChannelGroup() {
        this(Runtime.getRuntime().availableProcessors());
    }

    public AsynchronousTlsChannelGroup(int i) {
        int andIncrement = globalGroupCount.getAndIncrement();
        this.id = andIncrement;
        this.loggedTaskWarning = new AtomicBoolean();
        ScheduledThreadPoolExecutor scheduledThreadPoolExecutor = new ScheduledThreadPoolExecutor(1, new ThreadFactory() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda6
            @Override // java.util.concurrent.ThreadFactory
            public final Thread newThread(Runnable runnable) {
                Thread a2;
                a2 = AsynchronousTlsChannelGroup.this.a(runnable);
                return a2;
            }
        });
        this.timeoutExecutor = scheduledThreadPoolExecutor;
        Thread thread = new Thread(new Runnable() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda7
            @Override // java.lang.Runnable
            public final void run() {
                AsynchronousTlsChannelGroup.this.loop();
            }
        }, String.format("async-channel-group-%d-selector", Integer.valueOf(andIncrement)));
        this.selectorThread = thread;
        this.pendingRegistrations = new ConcurrentLinkedQueue<>();
        this.shutdown = Shutdown.No;
        this.selectionCount = new LongAdder();
        this.startedReads = new LongAdder();
        this.startedWrites = new LongAdder();
        this.successfulReads = new LongAdder();
        this.successfulWrites = new LongAdder();
        this.failedReads = new LongAdder();
        this.failedWrites = new LongAdder();
        this.cancelledReads = new LongAdder();
        this.cancelledWrites = new LongAdder();
        this.registrations = new ConcurrentHashMap<>();
        this.currentReads = new LongAdder();
        this.currentWrites = new LongAdder();
        try {
            this.selector = Selector.open();
            scheduledThreadPoolExecutor.setRemoveOnCancelPolicy(true);
            this.executor = new ThreadPoolExecutor(i, i, 0L, TimeUnit.MILLISECONDS, new LinkedBlockingQueue(i * 32), new ThreadFactory() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda8
                @Override // java.util.concurrent.ThreadFactory
                public final Thread newThread(Runnable runnable) {
                    Thread b;
                    b = AsynchronousTlsChannelGroup.this.b(runnable);
                    return b;
                }
            }, new ThreadPoolExecutor.CallerRunsPolicy());
            thread.start();
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    public static /* synthetic */ int a(int i, int i2) {
        return i | i2;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ Thread a(Runnable runnable) {
        return new Thread(runnable, String.format("async-channel-group-%d-timeout-thread", Integer.valueOf(this.id)));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(RegisteredSocket registeredSocket, ReadOperation readOperation) {
        try {
            doRead(registeredSocket, readOperation);
        } catch (Throwable th) {
            logger.log(Level.SEVERE, "error in operation", th);
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void a(RegisteredSocket registeredSocket, WriteOperation writeOperation) {
        try {
            doWrite(registeredSocket, writeOperation);
        } catch (Throwable th) {
            logger.log(Level.SEVERE, "error in operation", th);
        }
    }

    public static /* synthetic */ int b(int i, int i2) {
        return i | i2;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ Thread b(Runnable runnable) {
        return new Thread(runnable, String.format("async-channel-group-%d-handler-executor", Integer.valueOf(this.id)));
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void b(RegisteredSocket registeredSocket, ReadOperation readOperation) {
        if (doCancelRead(registeredSocket, readOperation)) {
            readOperation.onFailure.accept(new InterruptedByTimeoutException());
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public /* synthetic */ void b(RegisteredSocket registeredSocket, WriteOperation writeOperation) {
        if (doCancelWrite(registeredSocket, writeOperation)) {
            writeOperation.onFailure.accept(new InterruptedByTimeoutException());
        }
    }

    public static /* synthetic */ int c(int i, int i2) {
        return i | i2;
    }

    private void checkClosings() {
        Iterator it = this.registrations.keySet().iterator();
        while (it.hasNext()) {
            RegisteredSocket registeredSocket = (RegisteredSocket) it.next();
            if (!registeredSocket.key.isValid() || this.shutdown == Shutdown.Immediate) {
                this.registrations.remove(registeredSocket);
                failCurrentRead(registeredSocket);
                failCurrentWrite(registeredSocket);
            }
        }
    }

    private void checkTerminated() {
        if (isTerminated()) {
            throw new ShutdownChannelGroupException();
        }
    }

    public static /* synthetic */ int d(int i, int i2) {
        return i | i2;
    }

    /* JADX WARN: Removed duplicated region for block: B:17:0x0038 A[Catch: IOException -> 0x004d, NeedsWriteException -> 0x0069, NeedsReadException -> 0x0078, all -> 0x0088, TryCatch #3 {IOException -> 0x004d, blocks: (B:8:0x0012, B:15:0x002f, B:17:0x0038, B:18:0x003d), top: B:36:0x0012, outer: #1 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
    */
    private void doRead(RegisteredSocket registeredSocket, ReadOperation readOperation) {
        boolean z;
        registeredSocket.readLock.lock();
        try {
            if (registeredSocket.readOperation == readOperation) {
                try {
                    try {
                        Util.assertTrue(readOperation.bufferSet.hasRemaining());
                        long readHandlingTasks = readHandlingTasks(registeredSocket, readOperation);
                        if (readHandlingTasks <= 0 && readHandlingTasks != -1) {
                            z = false;
                            Util.assertTrue(z);
                            registeredSocket.readOperation = null;
                            if (readOperation.timeoutFuture != null) {
                                readOperation.timeoutFuture.cancel(false);
                            }
                            readOperation.onSuccess.accept(readHandlingTasks);
                            this.successfulReads.increment();
                            this.currentReads.decrement();
                        }
                        z = true;
                        Util.assertTrue(z);
                        registeredSocket.readOperation = null;
                        if (readOperation.timeoutFuture != null) {
                        }
                        readOperation.onSuccess.accept(readHandlingTasks);
                        this.successfulReads.increment();
                        this.currentReads.decrement();
                    } catch (IOException e) {
                        registeredSocket.readOperation = null;
                        if (readOperation.timeoutFuture != null) {
                            readOperation.timeoutFuture.cancel(false);
                        }
                        readOperation.onFailure.accept(e);
                        this.failedReads.increment();
                        this.currentReads.decrement();
                    }
                } catch (NeedsReadException e2) {
                    registeredSocket.pendingOps.accumulateAndGet(1, new IntBinaryOperator() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda10
                        @Override // java.util.function.IntBinaryOperator
                        public final int applyAsInt(int i, int i2) {
                            return AsynchronousTlsChannelGroup.a(i, i2);
                        }
                    });
                    this.selector.wakeup();
                } catch (NeedsWriteException e3) {
                    registeredSocket.pendingOps.accumulateAndGet(4, new IntBinaryOperator() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda9
                        @Override // java.util.function.IntBinaryOperator
                        public final int applyAsInt(int i, int i2) {
                            return AsynchronousTlsChannelGroup.b(i, i2);
                        }
                    });
                    this.selector.wakeup();
                }
            }
        } finally {
            registeredSocket.readLock.unlock();
        }
    }

    /* JADX WARN: Finally extract failed */
    private void doWrite(RegisteredSocket registeredSocket, WriteOperation writeOperation) {
        registeredSocket.writeLock.lock();
        try {
            if (registeredSocket.writeOperation == writeOperation) {
                try {
                    try {
                        long remaining = writeOperation.bufferSet.remaining();
                        try {
                            writeHandlingTasks(registeredSocket, writeOperation);
                            long remaining2 = remaining - writeOperation.bufferSet.remaining();
                            Util.assertTrue(remaining2 >= 0);
                            writeOperation.consumesBytes += remaining2;
                            registeredSocket.writeOperation = null;
                            if (writeOperation.timeoutFuture != null) {
                                writeOperation.timeoutFuture.cancel(false);
                            }
                            writeOperation.onSuccess.accept(writeOperation.consumesBytes);
                            this.successfulWrites.increment();
                            this.currentWrites.decrement();
                        } catch (Throwable th) {
                            long remaining3 = remaining - writeOperation.bufferSet.remaining();
                            Util.assertTrue(remaining3 >= 0);
                            writeOperation.consumesBytes += remaining3;
                            throw th;
                        }
                    } catch (NeedsReadException e) {
                        registeredSocket.pendingOps.accumulateAndGet(1, new IntBinaryOperator() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda3
                            @Override // java.util.function.IntBinaryOperator
                            public final int applyAsInt(int i, int i2) {
                                return AsynchronousTlsChannelGroup.c(i, i2);
                            }
                        });
                        this.selector.wakeup();
                    }
                } catch (NeedsWriteException e2) {
                    registeredSocket.pendingOps.accumulateAndGet(4, new IntBinaryOperator() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda2
                        @Override // java.util.function.IntBinaryOperator
                        public final int applyAsInt(int i, int i2) {
                            return AsynchronousTlsChannelGroup.d(i, i2);
                        }
                    });
                    this.selector.wakeup();
                } catch (IOException e3) {
                    registeredSocket.writeOperation = null;
                    if (writeOperation.timeoutFuture != null) {
                        writeOperation.timeoutFuture.cancel(false);
                    }
                    writeOperation.onFailure.accept(e3);
                    this.failedWrites.increment();
                    this.currentWrites.decrement();
                }
            }
        } finally {
            registeredSocket.writeLock.unlock();
        }
    }

    private void failCurrentRead(RegisteredSocket registeredSocket) {
        registeredSocket.readLock.lock();
        try {
            if (registeredSocket.readOperation != null) {
                registeredSocket.readOperation.onFailure.accept(new ClosedChannelException());
                if (registeredSocket.readOperation.timeoutFuture != null) {
                    registeredSocket.readOperation.timeoutFuture.cancel(false);
                }
                registeredSocket.readOperation = null;
                this.failedReads.increment();
                this.currentReads.decrement();
            }
        } finally {
            registeredSocket.readLock.unlock();
        }
    }

    private void failCurrentWrite(RegisteredSocket registeredSocket) {
        registeredSocket.writeLock.lock();
        try {
            if (registeredSocket.writeOperation != null) {
                registeredSocket.writeOperation.onFailure.accept(new ClosedChannelException());
                if (registeredSocket.writeOperation.timeoutFuture != null) {
                    registeredSocket.writeOperation.timeoutFuture.cancel(false);
                }
                registeredSocket.writeOperation = null;
                this.failedWrites.increment();
                this.currentWrites.decrement();
            }
        } finally {
            registeredSocket.writeLock.unlock();
        }
    }

    /* JADX INFO: Access modifiers changed from: private */
    public void loop() {
        while (true) {
            try {
                if (this.shutdown == Shutdown.No || (this.shutdown == Shutdown.Wait && (!this.pendingRegistrations.isEmpty() || !this.registrations.isEmpty()))) {
                    int select = this.selector.select(100L);
                    this.selectionCount.increment();
                    if (select > 0) {
                        Iterator<SelectionKey> it = this.selector.selectedKeys().iterator();
                        while (it.hasNext()) {
                            SelectionKey next = it.next();
                            it.remove();
                            try {
                                next.interestOps(0);
                                RegisteredSocket registeredSocket = (RegisteredSocket) next.attachment();
                                processRead(registeredSocket);
                                processWrite(registeredSocket);
                            } catch (CancelledKeyException e) {
                            }
                        }
                    }
                    registerPendingSockets();
                    processPendingInterests();
                    checkClosings();
                }
            } catch (IOException e2) {
                logger.log(Level.WARNING, "error closing selector: {0}", e2.getMessage());
            }
        }
        this.executor.shutdown();
        this.timeoutExecutor.shutdownNow();
        this.selector.close();
        checkClosings();
    }

    private void processPendingInterests() {
        for (SelectionKey selectionKey : this.selector.keys()) {
            int andSet = ((RegisteredSocket) selectionKey.attachment()).pendingOps.getAndSet(0);
            if (andSet != 0) {
                try {
                    selectionKey.interestOps(andSet | selectionKey.interestOps());
                } catch (CancelledKeyException e) {
                }
            }
        }
    }

    private void processRead(final RegisteredSocket registeredSocket) {
        registeredSocket.readLock.lock();
        try {
            final ReadOperation readOperation = registeredSocket.readOperation;
            if (readOperation != null) {
                this.executor.execute(new Runnable() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda1
                    @Override // java.lang.Runnable
                    public final void run() {
                        AsynchronousTlsChannelGroup.this.a(registeredSocket, readOperation);
                    }
                });
            }
        } finally {
            registeredSocket.readLock.unlock();
        }
    }

    private void processWrite(final RegisteredSocket registeredSocket) {
        registeredSocket.writeLock.lock();
        try {
            final WriteOperation writeOperation = registeredSocket.writeOperation;
            if (writeOperation != null) {
                this.executor.execute(new Runnable() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda5
                    @Override // java.lang.Runnable
                    public final void run() {
                        AsynchronousTlsChannelGroup.this.a(registeredSocket, writeOperation);
                    }
                });
            }
        } finally {
            registeredSocket.writeLock.unlock();
        }
    }

    private long readHandlingTasks(RegisteredSocket registeredSocket, ReadOperation readOperation) throws IOException {
        while (true) {
            try {
                return registeredSocket.tlsChannel.read(readOperation.bufferSet.array, readOperation.bufferSet.offset, readOperation.bufferSet.length);
            } catch (NeedsTaskException e) {
                warnAboutNeedTask();
                e.getTask().run();
            }
        }
    }

    private void registerPendingSockets() {
        while (true) {
            RegisteredSocket poll = this.pendingRegistrations.poll();
            if (poll == null) {
                return;
            }
            try {
                poll.key = poll.socketChannel.register(this.selector, 0, poll);
                this.registrations.put(poll, true);
            } catch (ClosedChannelException e) {
            } catch (Throwable th) {
                poll.registered.countDown();
                throw th;
            }
            poll.registered.countDown();
        }
    }

    private void waitForSocketRegistration(RegisteredSocket registeredSocket) {
        try {
            registeredSocket.registered.await();
        } catch (InterruptedException e) {
            Thread.currentThread().interrupt();
            throw new RuntimeException(e);
        }
    }

    private void warnAboutNeedTask() {
        if (this.loggedTaskWarning.getAndSet(true)) {
            return;
        }
        logger.log(Level.WARNING, "caught {0}; channels used in asynchronous groups should run tasks themselves; although task is being dealt with anyway, consider configuring channels properly", NeedsTaskException.class.getName());
    }

    private void writeHandlingTasks(RegisteredSocket registeredSocket, WriteOperation writeOperation) throws IOException {
        while (true) {
            try {
                registeredSocket.tlsChannel.write(writeOperation.bufferSet.array, writeOperation.bufferSet.offset, writeOperation.bufferSet.length);
                return;
            } catch (NeedsTaskException e) {
                warnAboutNeedTask();
                e.getTask().run();
            }
        }
    }

    public boolean awaitTermination(long j, TimeUnit timeUnit) throws InterruptedException {
        return this.executor.awaitTermination(j, timeUnit);
    }

    public boolean doCancelRead(RegisteredSocket registeredSocket, ReadOperation readOperation) {
        registeredSocket.readLock.lock();
        try {
            if (readOperation != registeredSocket.readOperation) {
                registeredSocket.readLock.unlock();
                return false;
            }
            registeredSocket.readOperation = null;
            this.cancelledReads.increment();
            this.currentReads.decrement();
            registeredSocket.readLock.unlock();
            return true;
        } catch (Throwable th) {
            registeredSocket.readLock.unlock();
            throw th;
        }
    }

    public boolean doCancelWrite(RegisteredSocket registeredSocket, WriteOperation writeOperation) {
        registeredSocket.writeLock.lock();
        try {
            if (writeOperation != registeredSocket.writeOperation) {
                registeredSocket.writeLock.unlock();
                return false;
            }
            registeredSocket.writeOperation = null;
            this.cancelledWrites.increment();
            this.currentWrites.decrement();
            registeredSocket.writeLock.unlock();
            return true;
        } catch (Throwable th) {
            registeredSocket.writeLock.unlock();
            throw th;
        }
    }

    public long getCancelledReadCount() {
        return this.cancelledReads.longValue();
    }

    public long getCancelledWriteCount() {
        return this.cancelledWrites.longValue();
    }

    public long getCurrentReadCount() {
        return this.currentReads.longValue();
    }

    public long getCurrentRegistrationCount() {
        return this.registrations.mappingCount();
    }

    public long getCurrentWriteCount() {
        return this.currentWrites.longValue();
    }

    public long getFailedReadCount() {
        return this.failedReads.longValue();
    }

    public long getFailedWriteCount() {
        return this.failedWrites.longValue();
    }

    public long getSelectionCount() {
        return this.selectionCount.longValue();
    }

    public long getStartedReadCount() {
        return this.startedReads.longValue();
    }

    public long getStartedWriteCount() {
        return this.startedWrites.longValue();
    }

    public long getSuccessfulReadCount() {
        return this.successfulReads.longValue();
    }

    public long getSuccessfulWriteCount() {
        return this.successfulWrites.longValue();
    }

    public boolean isAlive() {
        return this.selectorThread.isAlive();
    }

    public boolean isShutdown() {
        return this.shutdown != Shutdown.No;
    }

    public boolean isTerminated() {
        return this.executor.isTerminated();
    }

    public RegisteredSocket registerSocket(TlsChannel tlsChannel, SocketChannel socketChannel) {
        if (this.shutdown == Shutdown.No) {
            RegisteredSocket registeredSocket = new RegisteredSocket(tlsChannel, socketChannel);
            this.pendingRegistrations.add(registeredSocket);
            this.selector.wakeup();
            return registeredSocket;
        }
        throw new ShutdownChannelGroupException();
    }

    public void shutdown() {
        this.shutdown = Shutdown.Wait;
        this.selector.wakeup();
    }

    public void shutdownNow() {
        this.shutdown = Shutdown.Immediate;
        this.selector.wakeup();
    }

    public ReadOperation startRead(final RegisteredSocket registeredSocket, ByteBufferSet byteBufferSet, long j, TimeUnit timeUnit, LongConsumer longConsumer, Consumer<Throwable> consumer) throws ReadPendingException {
        checkTerminated();
        Util.assertTrue(byteBufferSet.hasRemaining());
        waitForSocketRegistration(registeredSocket);
        registeredSocket.readLock.lock();
        try {
            if (registeredSocket.readOperation == null) {
                final ReadOperation readOperation = new ReadOperation(byteBufferSet, longConsumer, consumer);
                this.startedReads.increment();
                this.currentReads.increment();
                if (!this.registrations.containsKey(registeredSocket)) {
                    readOperation.onFailure.accept(new ClosedChannelException());
                    this.failedReads.increment();
                    this.currentReads.decrement();
                    return readOperation;
                }
                registeredSocket.pendingOps.set(5);
                if (j != 0) {
                    readOperation.timeoutFuture = this.timeoutExecutor.schedule(new Runnable() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda0
                        @Override // java.lang.Runnable
                        public final void run() {
                            AsynchronousTlsChannelGroup.this.b(registeredSocket, readOperation);
                        }
                    }, j, timeUnit);
                }
                registeredSocket.readOperation = readOperation;
                registeredSocket.readLock.unlock();
                this.selector.wakeup();
                return readOperation;
            }
            throw new ReadPendingException();
        } finally {
            registeredSocket.readLock.unlock();
        }
    }

    public WriteOperation startWrite(final RegisteredSocket registeredSocket, ByteBufferSet byteBufferSet, long j, TimeUnit timeUnit, LongConsumer longConsumer, Consumer<Throwable> consumer) throws WritePendingException {
        checkTerminated();
        Util.assertTrue(byteBufferSet.hasRemaining());
        waitForSocketRegistration(registeredSocket);
        registeredSocket.writeLock.lock();
        try {
            if (registeredSocket.writeOperation == null) {
                final WriteOperation writeOperation = new WriteOperation(byteBufferSet, longConsumer, consumer);
                this.startedWrites.increment();
                this.currentWrites.increment();
                if (!this.registrations.containsKey(registeredSocket)) {
                    writeOperation.onFailure.accept(new ClosedChannelException());
                    this.failedWrites.increment();
                    this.currentWrites.decrement();
                    return writeOperation;
                }
                registeredSocket.pendingOps.set(5);
                if (j != 0) {
                    writeOperation.timeoutFuture = this.timeoutExecutor.schedule(new Runnable() { // from class: tlschannel.async.AsynchronousTlsChannelGroup$$ExternalSyntheticLambda4
                        @Override // java.lang.Runnable
                        public final void run() {
                            AsynchronousTlsChannelGroup.this.b(registeredSocket, writeOperation);
                        }
                    }, j, timeUnit);
                }
                registeredSocket.writeOperation = writeOperation;
                registeredSocket.writeLock.unlock();
                this.selector.wakeup();
                return writeOperation;
            }
            throw new WritePendingException();
        } finally {
            registeredSocket.writeLock.unlock();
        }
    }
}
